@@ -25,31 +25,27 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 	bind stack
 */
 
-#define BDSSIZE		1024
-#define	BDSGETA		40
-
 struct bds_bd {
 	object	bds_sym;	/*  symbol  */
 	object	bds_val;	/*  previous value of the symbol  */
 };
 
-struct bds_bd bind_stack[BDSSIZE + (STACK_OVER +1)* BDSGETA];
 
 typedef struct bds_bd *bds_ptr;
 
-bds_ptr bds_org;
+EXTER bds_ptr bds_org;
 
-bds_ptr bds_limit;
+EXTER bds_ptr bds_limit;
 
-bds_ptr bds_top;		/*  bind stack top  */
+EXTER bds_ptr bds_top;		/*  bind stack top  */
 
 #ifdef KCLOVM
 
 /* for multiprocessing */
-struct bds_bd save_bind_stack[BDSSIZE + BDSGETA + BDSGETA];
-bds_ptr bds_save_org;
-bds_ptr bds_save_limit;
-bds_ptr bds_save_top;
+EXTER struct bds_bd save_bind_stack[BDSSIZE + BDSGETA + BDSGETA];
+EXTER bds_ptr bds_save_org;
+EXTER bds_ptr bds_save_limit;
+EXTER bds_ptr bds_save_top;
 
 #endif
 
@@ -57,10 +53,16 @@ bds_ptr bds_save_top;
 	if (bds_top >= bds_limit)  \
 		bds_overflow()
 
+/* do this so that an interrupt in the middle will leave the VALID
+   part of the bds stack ie (<= bds_top) in a valid state, so
+   that a throw out will be ok */
 #define	bds_bind(sym, val)  \
-	(++bds_top)->bds_sym = (sym);  \
-	bds_top->bds_val = (sym)->s.s_dbind;  \
-	(sym)->s.s_dbind = (val)
+	do {bds_ptr _b = bds_top+1; \
+	      (_b)->bds_sym = (sym);  \
+	_b->bds_val = (sym)->s.s_dbind;  \
+	(sym)->s.s_dbind = (val); bds_top=_b;} while (0)
 
 #define	bds_unwind1  \
 	((bds_top->bds_sym)->s.s_dbind = bds_top->bds_val, --bds_top)
+
+
