@@ -32,29 +32,34 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #endif
 #endif
 
-#include <stdio.h>
-#include <setjmp.h>
-
 #ifdef UNIX
 #include <ctype.h>
 #define	isalphanum(x)	isalnum(x)
 #endif
 
+#ifdef IN_MAIN
+#define EXTER
+#else
+#define EXTER extern 
+#endif
 
+#include "../h/compbas.h"
+#include "../h/enum.h"
 #include "../h/object.h"
 #include "../h/vs.h"
-#include "../h/symbol.h"
 #include "../h/bds.h"
 #include "../h/frame.h"
+#include "../h/stacks.h"
 #include "../h/lex.h"
 #include "../h/eval.h"
-
-#include "../h/att_ext.h"
-/*#ifdef ATT   
-#include "../h/att_ext.h"
-#else
-#include "../h/external.h"
+#ifdef NEED_MP_H
+#include "../h/mp.h"
 #endif
-*/
+
+#include "../h/notcomp.h"
+#include "../h/funlink.h"
+#include "../h/att_ext.h"
+#include "compbas2.h"
+#include "compat.h"
 
 #include "../h/rgbc.h"
