@@ -30,11 +30,7 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #define	TRUE		1	/*  boolean true value  */
 #define	FALSE		0	/*  boolean false value  */
 
-#ifdef SGC
-#define FIRSTWORD     short t;  char s,m
-#else
-#define FIRSTWORD     short t; short m
-#endif
+#define FIRSTWORD unsigned char  t,flag; char s,m
 
 #define	NBPP		4	/*  number of bytes per pointer  */
 
@@ -102,10 +98,12 @@ struct fixnum_struct {
 		FIRSTWORD;
 	fixnum	FIXVAL;		/*  fixnum value  */
 };
-#define	fix(obje)	(obje)->FIX.FIXVAL
+#define	Mfix(obje)	(obje)->FIX.FIXVAL
+#define fix Mfix
 
 #define	SMALL_FIXNUM_LIMIT	1024
 
+EXTER
 struct fixnum_struct small_fixnum_table[2*SMALL_FIXNUM_LIMIT];
 
 #define	small_fixnum(i)  \
@@ -115,13 +113,15 @@ struct shortfloat_struct {
 			FIRSTWORD;
 	shortfloat	SFVAL;	/*  shortfloat value  */
 };
-#define	sf(obje)	(obje)->SF.SFVAL
+#define	Msf(obje)	(obje)->SF.SFVAL
+#define sf Msf
 
 struct longfloat_struct {
 			FIRSTWORD;
 	longfloat	LFVAL;	/*  longfloat value  */
 };
-#define	lf(obje)	(obje)->LF.LFVAL
+#define	Mlf(obje)	(obje)->LF.LFVAL
+#define lf Mlf
 
 struct bignum {
 			FIRSTWORD;
@@ -152,13 +152,10 @@ struct character {
 	unsigned char	ch_bits;	/*  bits  */
 };
 
-#ifdef MV
 
-#endif
 
-#ifdef AV
+EXTER 
 struct character character_table1[256+128];
-#endif
 #define character_table (character_table1+128)
 #define	code_char(c)		(object)(character_table+(c))
 #define	char_code(obje)		(obje)->ch.ch_code
@@ -173,7 +170,8 @@ enum stype {			/*  symbol type  */
 
 #define	Cnil			((object)&Cnil_body)
 #define	Ct			((object)&Ct_body)
-
+#define sLnil Cnil
+#define sLt Ct
 struct symbol {
 		FIRSTWORD;
 	object	s_dbind;	/*  dynamic binding  */
@@ -201,7 +199,7 @@ struct symbol {
 				/*  of enum stype  */
 	short	s_mflag;	/*  macro flag  */
 };
-
+EXTER 
 struct symbol Cnil_body, Ct_body;
 
 struct package {
@@ -234,7 +232,7 @@ struct package {
 /*
 	All the packages are linked through p_link.
 */
-struct package *pack_pointer;	/*  package pointer  */
+EXTER struct package *pack_pointer;	/*  package pointer  */
 
 struct cons {
 		FIRSTWORD;
@@ -276,6 +274,7 @@ enum aelttype {			/*  array element type  */
         aet_uchar,               /* unsigned char */
 	aet_short,              /* signed short */
 	aet_ushort,             /*  unsigned short   */
+	aet_last
 	  };
 
 struct array {			/*  array header  */
@@ -333,6 +332,7 @@ struct ustring {
 };
 
 #define USHORT(x,i) (((unsigned short *)(x)->ust.ust_self)[i])
+#define SHORT(x,i) ((( short *)(x)->ust.ust_self)[i])
 
 struct bitvector {		/*  bitvector header  */
 		FIRSTWORD;
@@ -519,16 +519,29 @@ struct cclosure {		/*  compiled closure header  */
 	object	cc_env;		/*  environment  */
 	object	cc_data;	/*  data the closure uses  */
 				/*  for GBC  */
+	int cc_envdim;
 	object	*cc_turbo;	/*  turbo charger */
 };
+
+struct closure {
+	FIRSTWORD; 
+	object	cl_name;       /* name */
+	object	(*cl_self)();  /* C start address of code */
+	object	cl_data;       /* To object holding VV vector */
+	int cl_argd;           /* description of args + number */
+	int cl_envdim;         /* length of the environment vector */
+	object *cl_env;        /* environment vector referenced by cl_self()*/
+};
+
 struct sfun {
 		FIRSTWORD; 
 	object	sfn_name;       /* name */
-	int	(*sfn_self)();  /* C start address of code */
+	object	(*sfn_self)();  /* C start address of code */
 	object	sfn_data;       /* To object holding VV vector */
 	int sfn_argd;           /* description of args + number */
 
 	      };
+
 struct vfun {
 		FIRSTWORD; 
 	object	vfn_name;       /* name */
@@ -544,26 +557,6 @@ struct cfdata {
      int cfd_fillp;             /* size of self */
      object *cfd_self;          /* body */
    };
-struct fat_string {			/*  vector header  */
-		FIRSTWORD;
-        unsigned fs_raw : 24;     /* tells if the things in leader are raw */
-	unsigned char fs_leader_length;	 /* leader_Length  */
-	int	fs_dim;		/*  dimension  */
-	int	fs_fillp;	/*  fill pointer  */
-				/*  For simple vectors,  */
-				/*  fs_fillp is equal to fs_dim.  */
-#define fs_leader(ar,i) (((object *)((ar)->fs.fs_self))[-(i+1)])
-	fatchar 	*fs_self;	/*  pointer to the vector
-Note the leader starts at (int *) *fs_self - fs_leader_length */
-};
-
-
-struct dclosure {		/*  compiled closure header  */
-		FIRSTWORD;
-	int	(*dc_self)();	/*  entry address  */
-	object	*dc_env;	/*  environment  */
-};
-
 
 struct spice {
 		FIRSTWORD;
@@ -598,8 +591,6 @@ union lispunion {
 	struct hashtable
 			ht;	/*  hash table  */
 	struct array	a;	/*  array  */
-	struct fat_string fs; /* fat string fatchar 's */
-        struct dclosure dc;
 	struct vector	v;	/*  vector  */
 	struct string	st;	/*  string  */
 	struct ustring	ust;
@@ -614,6 +605,7 @@ union lispunion {
 	struct pathname	pn;	/*  path name  */
 	struct cfun	cf;	/*  compiled function  uses value stack] */
 	struct cclosure	cc;	/*  compiled closure  uses value stack */
+	struct closure	cl;	/*  compiled closure  uses c stack */
 	struct sfun     sfn;    /*  simple function */
 	struct vfun     vfn;    /*  function with variable number of args */
 	struct cfdata   cfd;    /* compiled fun data */
@@ -631,52 +623,12 @@ union lispunion {
 */
 struct freelist {
 	FIRSTWORD;
-	object	f_link;
+	object f_link;
 };
+#define FL_LINK(ad) (((struct freelist *)(ad))->f_link)
 
 #define	FREE	(-1)		/*  free object  */
 
-/*
-	Implementation types.
-*/
-enum type {
-	t_cons,
-	t_start = 0 , /* t_cons, */
-	t_fixnum,
-	t_bignum,
-	t_ratio,
-	t_shortfloat,
-	t_longfloat,
-	t_complex,
-	t_character,
-	t_symbol,
-	t_package,
-/*	t_cons,  */
-	t_hashtable,
-	t_array,
-	t_vector,
-	t_string,
-	t_bitvector,
-	t_structure,
-	t_stream,
-	t_random,
-	t_readtable,
-	t_pathname,
-	t_cfun,
-	t_cclosure,
-	t_sfun,
-        t_gfun,
-	t_vfun,
-	t_cfdata,
-	t_spice,
-	t_fat_string,
-        t_dclosure,
-   
-	t_end,
-	t_contiguous,		/*  contiguous block  */
-	t_relocatable,		/*  relocatable block  */
-	t_other			/*  other  */
-};
 /*
 	Type_of.
 */
@@ -716,7 +668,7 @@ struct typemanager {
 /*
 	The table of type managers.
 */
-struct typemanager tm_table[ 32  /* (int) t_relocatable */];
+EXTER struct typemanager tm_table[ 32  /* (int) t_relocatable */];
 
 #define	tm_of(t)	(&(tm_table[(int)tm_table[(int)(t)].tm_type]))
 
@@ -732,12 +684,12 @@ struct contblock {		/*  contiguous block header  */
 /*
 	The pointer to the contiguous blocks.
 */
-struct contblock *cb_pointer;	/*  contblock pointer  */
+EXTER struct contblock *cb_pointer;	/*  contblock pointer  */
 
 /*
 	Variables for memory management.
 */
-int ncb;			/*  number of contblocks  */
+EXTER int ncb;			/*  number of contblocks  */
 /* int ncbpage;			  number of contblock pages  */
 #define ncbpage tm_table[t_contiguous].tm_npage
 #define maxcbpage   tm_table[t_contiguous].tm_maxpage
@@ -745,24 +697,24 @@ int ncb;			/*  number of contblocks  */
   
 
 /* int maxcbpage; maximum number of contblock pages  */
-
+EXTER 
 int holepage;			/*  hole pages  */
 #define nrbpage tm_table[t_relocatable].tm_npage
 #define rbgbccount tm_table[t_relocatable].tm_gbccount
 /* int nrbpage;			  number of relblock pages  */
   
 
-
+EXTER 
 char *rb_start;			/*  relblock start  */
-char *rb_end;			/*  relblock end  */
-char *rb_limit;			/*  relblock limit  */
-char *rb_pointer;		/*  relblock pointer  */
-char *rb_start1;		/*  relblock start in copy space  */
-char *rb_pointer1;		/*  relblock pointer in copy space  */
-
-char *heap_end;			/*  heap end  */
-char *core_end;			/*  core end  */
+EXTER char *rb_end;			/*  relblock end  */
+EXTER char *rb_limit;			/*  relblock limit  */
+EXTER char *rb_pointer;		/*  relblock pointer  */
+EXTER char *rb_start1;		/*  relblock start in copy space  */
+EXTER char *rb_pointer1;		/*  relblock pointer in copy space  */
 
+EXTER char *heap_end;			/*  heap end  */
+EXTER char *core_end;			/*  core end  */
+EXTER 
 char *tmp_alloc;
 
 /* make f allocate enough extra, so that we can round
@@ -787,18 +739,6 @@ char *tmp_alloc;
 #define	INIT_NRBPAGE	50
 #define	RB_GETA		512
 
-/*
-	Endp macro.
-*/
-/*
-#define	endp(obje)	((enum type)((endp_temp = (obje))->d.t) == t_cons ? \
-			 FALSE : endp_temp == Cnil ? TRUE : \
-			 (bool)FEwrong_type_argument(Slist, endp_temp))
-
-object endp_temp;
-*/
-
-#define	endp(obje)	endp1(obje)
 
 #ifdef AV
 #define	STATIC	register
@@ -808,7 +748,7 @@ object endp_temp;
 #endif
 
 #define	TIME_ZONE	(-9)
-
+EXTER 
 int FIXtemp;
 
 /*  For IEEEFLOAT, the double may have exponent in the second word
@@ -830,7 +770,7 @@ int FIXtemp;
 #define	isLower(xxx)	(((xxx)&0200) == 0 && islower(xxx))
 #define	isDigit(xxx)	(((xxx)&0200) == 0 && isdigit(xxx))
 enum ftype {f_object,f_fixnum};
-
+EXTER 
 char *alloca_val;
 /*          ...xx|xx|xxxx|xxxx|   
 		     ret  Narg     */
@@ -848,7 +788,7 @@ char *alloca_val;
 #define ARGTYPE3(x,y,z) (3 | ARGTYPE(0,x) | ARGTYPE(1,y) | ARGTYPE(2,z))
 
 object make_si_sfun();
-object MVloc[10];
+EXTER object MVloc[10];
 
 /* Set new to be an (object *) whose [i]'th elmt is the
    ith elmnt in a va_list
@@ -874,9 +814,29 @@ object MVloc[10];
  Used by the C function to set optionals */
 
 struct call_data { object fun;
-		   int argd;};
-struct call_data fcall;
+		     int argd;
+		     int nvalues;
+		   object    values[20];
+		   double double_return;
+		 };
+EXTER struct call_data fcall;
+
 #define  VFUN_NARGS fcall.argd
+#define RETURN2(x,y) do{object _x = (void *) x; \
+			  fcall.values[2]=y;fcall.nvalues=2; \
+			  return (x) ;} while(0)
+#define RETURN1(x) do{fcall.nvalues=1; return (x) ;} while(0)
+#define RETURN0  do{fcall.nvalues=0; return Cnil ;} while(0)
+
+#define RV(x) (*_p++ = x)
+
+#define RETURNI(n,val1,listvals) RETURN(n,int,val1,listvals)
+#define RETURNO(n,val1,listvals) RETURN(n,object,val1,listvals)
+
+#define RETURN(n,typ,val1,listvals) \
+   do{typ _val1 = val1; object *_p=&fcall.values[1]; listvals; fcall.nvalues= n; return _val1;}while(0)
+#define CALL(n,form) (VFUN_NARGS=n,form)
+	
 
 /* we sometimes have to touch the header of arrays or structures
    to make sure the page is writable */
@@ -888,9 +848,40 @@ struct call_data fcall;
 
 object funcall_cfun();
 object clear_compiler_properties();
-object siSlambda_block_expanded;
+EXTER object sSlambda_block_expanded;
+
+# ifdef __GNUC__ 
+# define assert(ex)\
+{if (!(ex)){(void)fprintf(stderr, \
+		  "Assertion failed: file \"%s\", line %d\n", __FILE__, __LINE__);exit(1);}}
+# else
+# define assert(ex)
+# endif
 
 #ifndef FIX_PATH_STRING
 #define FIX_PATH_STRING(file) file
 #endif
 	
+
+#define CHECK_INTERRUPT   if (signals_pending) raise_pending_signals(sig_safe)
+
+#define BEGIN_NO_INTERRUPT \
+ long old_signals_allowed = signals_allowed; \
+  signals_allowed = 0
+
+#define END_NO_INTERRUPT \
+  signals_allowed = old_signals_allowed
+/* could add:   if (signals_pending)
+   raise_pending_signals(sig_use_signals_allowed_value) */
+
+
+#define END_NO_INTERRUPT_SAFE \
+  signals_allowed = old_signals_allowed; \
+  if (signals_pending) \
+    do{ if(signals_allowed ==0) /* should not get here*/abort(); \
+	  raise_pending_signals(sig_safe)}while(0)
+
+void raise_pending_signals();
+
+EXTER unsigned long signals_allowed, signals_pending  ;
+
