@@ -30,7 +30,7 @@ T7:;
 	base[0]= (V2);
 	base[1]= VV[1];
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk16)();
+	(void) (*Lnk17)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T10;}
@@ -47,7 +47,7 @@ T18:;
 	base[1]= (V2);
 	base[2]= (V7);
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk16)();
+	(void) (*Lnk17)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T22;}
@@ -76,7 +76,7 @@ T41:;
 	base[1]= (V2);
 	base[2]= (V13);
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk16)();
+	(void) (*Lnk17)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T45;}
@@ -138,7 +138,7 @@ static object LI2(V16,va_alist)
 	goto T57;}
 	V17= make_cons((V17),Cnil);
 T57:;
-	V18= (*(LnkLI21))((V18));
+	V18= (*(LnkLI22))((V18));
 	if(!((length((V17)))==(1))){
 	goto T64;}
 	{register object V27;
@@ -174,19 +174,18 @@ T75:;
 	VMR2(V31)}}
 T64:;
 	{register object V32;
-	base[0]= (V18);
-	base[1]= (V22);
-	base[2]= (V24);
-	base[3]= (V25);
-	base[4]= (V26);
-	base[5]= (V19);
-	{object V33;
-	V33= (V17);
-	 vs_top=base+6;
-	 while(!endp(V33))
-	 {vs_push(car(V33));V33=cdr(V33);}
-	vs_base=base+0;}
-	siLmake_pure_array();
+	base[1]= (V18);
+	vs_top=(vs_base=base+1)+1;
+	(void) (*Lnk23)();
+	vs_top=sup;
+	base[0]= vs_base[0];
+	base[1]= (V26);
+	base[2]= (V19);
+	base[3]= (V24);
+	base[4]= (V25);
+	base[5]= (V17);
+	vs_top=(vs_base=base+0)+6;
+	(void) (*Lnk24)();
 	vs_top=sup;
 	V32= vs_base[0];
 	if(((V23))==Cnil){
@@ -196,83 +195,83 @@ T64:;
 	Lerror();
 	vs_top=sup;
 T98:;
-	{register object x= small_fixnum(0),V34= (V17);
-	while(!endp(V34))
-	if(eql(x,V34->c.c_car)){
+	{register object x= small_fixnum(0),V33= (V17);
+	while(!endp(V33))
+	if(eql(x,V33->c.c_car)){
 	goto T102;
-	}else V34=V34->c.c_cdr;}
+	}else V33=V33->c.c_cdr;}
 	if(((V21))==Cnil){
 	goto T102;}
-	{register object V35;
+	{register object V34;
 	base[0]= make_fixnum(length((V17)));
 	base[1]= VV[7];
 	base[2]= small_fixnum(0);
 	vs_top=(vs_base=base+0)+3;
 	Lmake_list();
 	vs_top=sup;
-	V35= vs_base[0];
+	V34= vs_base[0];
 T112:;
 	base[0]= (V32);
-	base[1]= (*(LnkLI22))((V20),(V35));
-	base[2]= (V35);
+	base[1]= (*(LnkLI25))((V20),(V34));
+	base[2]= (V34);
 	vs_top=(vs_base=base+0)+3;
-	(void) (*Lnk23)();
+	(void) (*Lnk26)();
 	vs_top=sup;
-	if(((*(LnkLI24))((V35),(V17)))==Cnil){
+	if(((*(LnkLI27))((V34),(V17)))==Cnil){
 	goto T119;}
 	goto T102;
 T119:;
 	goto T112;}
 T102:;
-	{object V36 = (V32);
-	VMR2(V36)}}}
+	{object V35 = (V32);
+	VMR2(V35)}}}
 	}}
 /*	local entry for function INCREMENT-CURSOR	*/
 
-static object LI3(V39,V40)
+static object LI3(V38,V39)
 
-register object V39;object V40;
+register object V38;object V39;
 {	 VMB3 VMS3 VMV3
 TTL:;
-	if(((V39))!=Cnil){
+	if(((V38))!=Cnil){
 	goto T125;}
-	{object V41 = Ct;
-	VMR3(V41)}
+	{object V40 = Ct;
+	VMR3(V40)}
 T125:;
-	{object V42;
-	V42= (*(LnkLI24))(cdr((V39)),cdr((V40)));
-	if(((V42))==Cnil){
+	{object V41;
+	V41= (*(LnkLI27))(cdr((V38)),cdr((V39)));
+	if(((V41))==Cnil){
 	goto T129;}
-	if(!(((fix(car((V39))))+1)>=(fix(car((V40)))))){
+	if(!(((fix(car((V38))))+1)>=(fix(car((V39)))))){
 	goto T132;}
-	if(type_of((V39))!=t_cons)FEwrong_type_argument(Scons,(V39));
-	((V39))->c.c_car = small_fixnum(0);
-	{object V43 = Ct;
-	VMR3(V43)}
+	if(type_of((V38))!=t_cons)FEwrong_type_argument(Scons,(V38));
+	((V38))->c.c_car = small_fixnum(0);
+	{object V42 = Ct;
+	VMR3(V42)}
 T132:;
-	V44 = make_fixnum((fix(car((V39))))+1);
-	if(type_of((V39))!=t_cons)FEwrong_type_argument(Scons,(V39));
-	((V39))->c.c_car = V44;
-	{object V45 = Cnil;
-	VMR3(V45)}
+	V43 = make_fixnum((fix(car((V38))))+1);
+	if(type_of((V38))!=t_cons)FEwrong_type_argument(Scons,(V38));
+	((V38))->c.c_car = V43;
+	{object V44 = Cnil;
+	VMR3(V44)}
 T129:;
-	{object V46 = Cnil;
-	VMR3(V46)}}
+	{object V45 = Cnil;
+	VMR3(V45)}}
 }
 /*	local entry for function SEQUENCE-CURSOR	*/
 
-static object LI4(V49,V50)
+static object LI4(V48,V49)
 
-object V49;object V50;
+object V48;object V49;
 {	 VMB4 VMS4 VMV4
 TTL:;
-	if(((V50))!=Cnil){
+	if(((V49))!=Cnil){
 	goto T137;}
-	{object V51 = (V49);
-	VMR4(V51)}
+	{object V50 = (V48);
+	VMR4(V50)}
 T137:;
-	V49= elt((V49),fix(car((V50))));
-	V50= cdr((V50));
+	V48= elt((V48),fix(car((V49))));
+	V49= cdr((V49));
 	goto TTL;
 }
 /*	local entry for function VECTOR	*/
@@ -282,769 +281,769 @@ static object LI5(va_alist)
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB5 VMS5 VMV5
-	{object V52;
+	{object V51;
 	narg= narg - 0;
 	va_start(ap);
-	V53 = (ALLOCA_CONS(narg),ON_STACK_LIST_VECTOR(narg,ap));
-	V52= V53;
-	{object V54;
-	V55 = make_fixnum(length((V52)));
-	V54= make_cons(V55,Cnil);
-	{object V56 = (VFUN_NARGS=5,(*(LnkLI25))((V54),VV[8],Ct,VV[9],(V52)));
-	VMR5(V56)}}}
+	V52 = (ALLOCA_CONS(narg),ON_STACK_LIST_VECTOR(narg,ap));
+	V51= V52;
+	{object V53;
+	V54 = make_fixnum(length((V51)));
+	V53= make_cons(V54,Cnil);
+	{object V55 = (VFUN_NARGS=5,(*(LnkLI28))((V53),VV[8],Ct,VV[9],(V51)));
+	VMR5(V55)}}}
 	}
 /*	local entry for function ARRAY-DIMENSIONS	*/
 
-static object LI6(V58)
+static object LI6(V57)
 
-register object V58;
+register object V57;
 {	 VMB6 VMS6 VMV6
 TTL:;
-	{register object V59;
-	register object V60;
-	base[0]= (V58);
+	{register object V58;
+	register object V59;
+	base[0]= (V57);
 	vs_top=(vs_base=base+0)+1;
 	Larray_rank();
 	vs_top=sup;
-	V59= vs_base[0];
-	V60= Cnil;
+	V58= vs_base[0];
+	V59= Cnil;
 T146:;
-	if(!(number_compare((V59),small_fixnum(0))==0)){
+	if(!(number_compare((V58),small_fixnum(0))==0)){
 	goto T147;}
-	{object V61 = (V60);
-	VMR6(V61)}
+	{object V60 = (V59);
+	VMR6(V60)}
 T147:;
-	V59= one_minus((V59));
-	base[0]= (V58);
-	base[1]= (V59);
+	V58= one_minus((V58));
+	base[0]= (V57);
+	base[1]= (V58);
 	vs_top=(vs_base=base+0)+2;
 	Larray_dimension();
 	vs_top=sup;
-	V62= vs_base[0];
-	V60= make_cons(V62,(V60));
+	V61= vs_base[0];
+	V59= make_cons(V61,(V59));
 	goto T146;}
 }
 /*	local entry for function ARRAY-IN-BOUNDS-P	*/
 
-static object LI7(V63,va_alist)
-	object V63;
+static object LI7(V62,va_alist)
+	object V62;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB7 VMS7 VMV7
-	{register object V64;
-	object V65;
+	{register object V63;
+	object V64;
 	if(narg <1) too_few_arguments();
-	V64= V63;
+	V63= V62;
 	narg= narg - 1;
 	va_start(ap);
-	V66 = (ALLOCA_CONS(narg),ON_STACK_LIST_VECTOR(narg,ap));
-	V65= V66;
-	{register object V67;
-	base[1]= (V64);
+	V65 = (ALLOCA_CONS(narg),ON_STACK_LIST_VECTOR(narg,ap));
+	V64= V65;
+	{register object V66;
+	base[1]= (V63);
 	vs_top=(vs_base=base+1)+1;
 	Larray_rank();
 	vs_top=sup;
-	V67= vs_base[0];
-	V68 = make_fixnum(length((V65)));
-	if(!(number_compare((V67),V68)!=0)){
+	V66= vs_base[0];
+	V67 = make_fixnum(length((V64)));
+	if(!(number_compare((V66),V67)!=0)){
 	goto T162;}
 	base[1]= VV[10];
-	base[2]= (V67);
-	base[3]= make_fixnum(length((V65)));
+	base[2]= (V66);
+	base[3]= make_fixnum(length((V64)));
 	vs_top=(vs_base=base+1)+3;
 	Lerror();
 	vs_top=sup;
 T162:;
-	{register object V69;
-	register object V70;
-	V69= small_fixnum(0);
-	V70= (V65);
+	{register object V68;
+	register object V69;
+	V68= small_fixnum(0);
+	V69= (V64);
 T169:;
-	if(!(number_compare((V69),(V67))>=0)){
+	if(!(number_compare((V68),(V66))>=0)){
 	goto T170;}
-	{object V71 = Ct;
-	VMR7(V71)}
+	{object V70 = Ct;
+	VMR7(V70)}
 T170:;
-	if(number_compare(car((V70)),small_fixnum(0))<0){
+	if(number_compare(car((V69)),small_fixnum(0))<0){
 	goto T175;}
-	V72= car((V70));
-	base[1]= (V64);
-	base[2]= (V69);
+	V71= car((V69));
+	base[1]= (V63);
+	base[2]= (V68);
 	vs_top=(vs_base=base+1)+2;
 	Larray_dimension();
 	vs_top=sup;
-	V73= vs_base[0];
-	if(!(number_compare(/* INLINE-ARGS */V72,V73)>=0)){
+	V72= vs_base[0];
+	if(!(number_compare(/* INLINE-ARGS */V71,V72)>=0)){
 	goto T174;}
 T175:;
-	{object V74 = Cnil;
-	VMR7(V74)}
+	{object V73 = Cnil;
+	VMR7(V73)}
 T174:;
-	V69= one_plus((V69));
-	V70= cdr((V70));
+	V68= one_plus((V68));
+	V69= cdr((V69));
 	goto T169;}}}
 	}
 /*	local entry for function ARRAY-ROW-MAJOR-INDEX	*/
 
-static object LI8(V75,va_alist)
-	object V75;
+static object LI8(V74,va_alist)
+	object V74;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB8 VMS8 VMV8
-	{register object V76;
-	object V77;
+	{register object V75;
+	object V76;
 	if(narg <1) too_few_arguments();
-	V76= V75;
+	V75= V74;
 	narg= narg - 1;
 	va_start(ap);
-	V78 = (ALLOCA_CONS(narg),ON_STACK_LIST_VECTOR(narg,ap));
-	V77= V78;
-	{register object V79;
+	V77 = (ALLOCA_CONS(narg),ON_STACK_LIST_VECTOR(narg,ap));
+	V76= V77;
+	{register object V78;
+	register object V79;
 	register object V80;
-	register object V81;
+	V78= small_fixnum(0);
 	V79= small_fixnum(0);
-	V80= small_fixnum(0);
-	V81= (V77);
+	V80= (V76);
 T187:;
-	if(((V81))!=Cnil){
+	if(((V80))!=Cnil){
 	goto T188;}
-	{object V82 = (V80);
-	VMR8(V82)}
+	{object V81 = (V79);
+	VMR8(V81)}
 T188:;
-	{object V83;
-	V83= one_plus((V79));
-	base[0]= (V76);
-	base[1]= (V79);
+	{object V82;
+	V82= one_plus((V78));
+	base[0]= (V75);
+	base[1]= (V78);
 	vs_top=(vs_base=base+0)+2;
 	Larray_dimension();
 	vs_top=sup;
-	V84= vs_base[0];
-	V85= number_times((V80),V84);
-	V80= number_plus(/* INLINE-ARGS */V85,car((V81)));
-	V81= cdr((V81));
-	V79= (V83);}
+	V83= vs_base[0];
+	V84= number_times((V79),V83);
+	V79= number_plus(/* INLINE-ARGS */V84,car((V80)));
+	V80= cdr((V80));
+	V78= (V82);}
 	goto T187;}}
 	}
 /*	local entry for function BIT	*/
 
-static object LI9(V86,va_alist)
-	object V86;
+static object LI9(V85,va_alist)
+	object V85;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB9 VMS9 VMV9
-	{object V87;
-	object V88;
+	{object V86;
+	object V87;
 	if(narg <1) too_few_arguments();
-	V87= V86;
+	V86= V85;
 	narg= narg - 1;
 	va_start(ap);
-	V89 = (ALLOCA_CONS(narg),ON_STACK_LIST_VECTOR(narg,ap));
-	V88= V89;
-	base[0]= (V87);
-	{object V90;
-	V90= (V88);
+	V88 = (ALLOCA_CONS(narg),ON_STACK_LIST_VECTOR(narg,ap));
+	V87= V88;
+	base[0]= (V86);
+	{object V89;
+	V89= (V87);
 	 vs_top=base+1;
-	 while(!endp(V90))
-	 {vs_push(car(V90));V90=cdr(V90);}
+	 while(!endp(V89))
+	 {vs_push(car(V89));V89=cdr(V89);}
 	vs_base=base+0;}
 	Laref();
 	vs_top=sup;
-	{object V91 = vs_base[0];
-	VMR9(V91)}}
+	{object V90 = vs_base[0];
+	VMR9(V90)}}
 	}
 /*	local entry for function SBIT	*/
 
-static object LI10(V92,va_alist)
-	object V92;
+static object LI10(V91,va_alist)
+	object V91;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB10 VMS10 VMV10
-	{object V93;
-	object V94;
+	{object V92;
+	object V93;
 	if(narg <1) too_few_arguments();
-	V93= V92;
+	V92= V91;
 	narg= narg - 1;
 	va_start(ap);
-	V95 = (ALLOCA_CONS(narg),ON_STACK_LIST_VECTOR(narg,ap));
-	V94= V95;
-	base[0]= (V93);
-	{object V96;
-	V96= (V94);
+	V94 = (ALLOCA_CONS(narg),ON_STACK_LIST_VECTOR(narg,ap));
+	V93= V94;
+	base[0]= (V92);
+	{object V95;
+	V95= (V93);
 	 vs_top=base+1;
-	 while(!endp(V96))
-	 {vs_push(car(V96));V96=cdr(V96);}
+	 while(!endp(V95))
+	 {vs_push(car(V95));V95=cdr(V95);}
 	vs_base=base+0;}
 	Laref();
 	vs_top=sup;
-	{object V97 = vs_base[0];
-	VMR10(V97)}}
+	{object V96 = vs_base[0];
+	VMR10(V96)}}
 	}
 /*	local entry for function BIT-AND	*/
 
-static object LI11(V99,V98,va_alist)
-	object V99,V98;
+static object LI11(V98,V97,va_alist)
+	object V98,V97;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB11 VMS11 VMV11
-	{object V100;
+	{object V99;
+	object V100;
 	object V101;
-	object V102;
 	if(narg <2) too_few_arguments();
-	V100= V99;
-	V101= V98;
+	V99= V98;
+	V100= V97;
 	narg = narg - 2;
 	if (narg <= 0) goto T204;
 	else {
 	va_start(ap);
-	V102= va_arg(ap,object);}
+	V101= va_arg(ap,object);}
 	--narg; goto T205;
 T204:;
-	V102= Cnil;
+	V101= Cnil;
 T205:;
 	base[0]= small_fixnum(1);
-	base[1]= (V100);
-	base[2]= (V101);
-	base[3]= (V102);
+	base[1]= (V99);
+	base[2]= (V100);
+	base[3]= (V101);
 	vs_top=(vs_base=base+0)+4;
 	siLbit_array_op();
 	vs_top=sup;
-	{object V103 = vs_base[0];
-	VMR11(V103)}}
+	{object V102 = vs_base[0];
+	VMR11(V102)}}
 	}
 /*	local entry for function BIT-IOR	*/
 
-static object LI12(V105,V104,va_alist)
-	object V105,V104;
+static object LI12(V104,V103,va_alist)
+	object V104,V103;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB12 VMS12 VMV12
-	{object V106;
+	{object V105;
+	object V106;
 	object V107;
-	object V108;
 	if(narg <2) too_few_arguments();
-	V106= V105;
-	V107= V104;
+	V105= V104;
+	V106= V103;
 	narg = narg - 2;
 	if (narg <= 0) goto T211;
 	else {
 	va_start(ap);
-	V108= va_arg(ap,object);}
+	V107= va_arg(ap,object);}
 	--narg; goto T212;
 T211:;
-	V108= Cnil;
+	V107= Cnil;
 T212:;
 	base[0]= small_fixnum(7);
-	base[1]= (V106);
-	base[2]= (V107);
-	base[3]= (V108);
+	base[1]= (V105);
+	base[2]= (V106);
+	base[3]= (V107);
 	vs_top=(vs_base=base+0)+4;
 	siLbit_array_op();
 	vs_top=sup;
-	{object V109 = vs_base[0];
-	VMR12(V109)}}
+	{object V108 = vs_base[0];
+	VMR12(V108)}}
 	}
 /*	local entry for function BIT-XOR	*/
 
-static object LI13(V111,V110,va_alist)
-	object V111,V110;
+static object LI13(V110,V109,va_alist)
+	object V110,V109;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB13 VMS13 VMV13
-	{object V112;
+	{object V111;
+	object V112;
 	object V113;
-	object V114;
 	if(narg <2) too_few_arguments();
-	V112= V111;
-	V113= V110;
+	V111= V110;
+	V112= V109;
 	narg = narg - 2;
 	if (narg <= 0) goto T218;
 	else {
 	va_start(ap);
-	V114= va_arg(ap,object);}
+	V113= va_arg(ap,object);}
 	--narg; goto T219;
 T218:;
-	V114= Cnil;
+	V113= Cnil;
 T219:;
 	base[0]= small_fixnum(6);
-	base[1]= (V112);
-	base[2]= (V113);
-	base[3]= (V114);
+	base[1]= (V111);
+	base[2]= (V112);
+	base[3]= (V113);
 	vs_top=(vs_base=base+0)+4;
 	siLbit_array_op();
 	vs_top=sup;
-	{object V115 = vs_base[0];
-	VMR13(V115)}}
+	{object V114 = vs_base[0];
+	VMR13(V114)}}
 	}
 /*	local entry for function BIT-EQV	*/
 
-static object LI14(V117,V116,va_alist)
-	object V117,V116;
+static object LI14(V116,V115,va_alist)
+	object V116,V115;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB14 VMS14 VMV14
-	{object V118;
+	{object V117;
+	object V118;
 	object V119;
-	object V120;
 	if(narg <2) too_few_arguments();
-	V118= V117;
-	V119= V116;
+	V117= V116;
+	V118= V115;
 	narg = narg - 2;
 	if (narg <= 0) goto T225;
 	else {
 	va_start(ap);
-	V120= va_arg(ap,object);}
+	V119= va_arg(ap,object);}
 	--narg; goto T226;
 T225:;
-	V120= Cnil;
+	V119= Cnil;
 T226:;
 	base[0]= small_fixnum(9);
-	base[1]= (V118);
-	base[2]= (V119);
-	base[3]= (V120);
+	base[1]= (V117);
+	base[2]= (V118);
+	base[3]= (V119);
 	vs_top=(vs_base=base+0)+4;
 	siLbit_array_op();
 	vs_top=sup;
-	{object V121 = vs_base[0];
-	VMR14(V121)}}
+	{object V120 = vs_base[0];
+	VMR14(V120)}}
 	}
 /*	local entry for function BIT-NAND	*/
 
-static object LI15(V123,V122,va_alist)
-	object V123,V122;
+static object LI15(V122,V121,va_alist)
+	object V122,V121;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB15 VMS15 VMV15
-	{object V124;
+	{object V123;
+	object V124;
 	object V125;
-	object V126;
 	if(narg <2) too_few_arguments();
-	V124= V123;
-	V125= V122;
+	V123= V122;
+	V124= V121;
 	narg = narg - 2;
 	if (narg <= 0) goto T232;
 	else {
 	va_start(ap);
-	V126= va_arg(ap,object);}
+	V125= va_arg(ap,object);}
 	--narg; goto T233;
 T232:;
-	V126= Cnil;
+	V125= Cnil;
 T233:;
 	base[0]= small_fixnum(14);
-	base[1]= (V124);
-	base[2]= (V125);
-	base[3]= (V126);
+	base[1]= (V123);
+	base[2]= (V124);
+	base[3]= (V125);
 	vs_top=(vs_base=base+0)+4;
 	siLbit_array_op();
 	vs_top=sup;
-	{object V127 = vs_base[0];
-	VMR15(V127)}}
+	{object V126 = vs_base[0];
+	VMR15(V126)}}
 	}
 /*	local entry for function BIT-NOR	*/
 
-static object LI16(V129,V128,va_alist)
-	object V129,V128;
+static object LI16(V128,V127,va_alist)
+	object V128,V127;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB16 VMS16 VMV16
-	{object V130;
+	{object V129;
+	object V130;
 	object V131;
-	object V132;
 	if(narg <2) too_few_arguments();
-	V130= V129;
-	V131= V128;
+	V129= V128;
+	V130= V127;
 	narg = narg - 2;
 	if (narg <= 0) goto T239;
 	else {
 	va_start(ap);
-	V132= va_arg(ap,object);}
+	V131= va_arg(ap,object);}
 	--narg; goto T240;
 T239:;
-	V132= Cnil;
+	V131= Cnil;
 T240:;
 	base[0]= small_fixnum(8);
-	base[1]= (V130);
-	base[2]= (V131);
-	base[3]= (V132);
+	base[1]= (V129);
+	base[2]= (V130);
+	base[3]= (V131);
 	vs_top=(vs_base=base+0)+4;
 	siLbit_array_op();
 	vs_top=sup;
-	{object V133 = vs_base[0];
-	VMR16(V133)}}
+	{object V132 = vs_base[0];
+	VMR16(V132)}}
 	}
 /*	local entry for function BIT-ANDC1	*/
 
-static object LI17(V135,V134,va_alist)
-	object V135,V134;
+static object LI17(V134,V133,va_alist)
+	object V134,V133;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB17 VMS17 VMV17
-	{object V136;
+	{object V135;
+	object V136;
 	object V137;
-	object V138;
 	if(narg <2) too_few_arguments();
-	V136= V135;
-	V137= V134;
+	V135= V134;
+	V136= V133;
 	narg = narg - 2;
 	if (narg <= 0) goto T246;
 	else {
 	va_start(ap);
-	V138= va_arg(ap,object);}
+	V137= va_arg(ap,object);}
 	--narg; goto T247;
 T246:;
-	V138= Cnil;
+	V137= Cnil;
 T247:;
 	base[0]= small_fixnum(4);
-	base[1]= (V136);
-	base[2]= (V137);
-	base[3]= (V138);
+	base[1]= (V135);
+	base[2]= (V136);
+	base[3]= (V137);
 	vs_top=(vs_base=base+0)+4;
 	siLbit_array_op();
 	vs_top=sup;
-	{object V139 = vs_base[0];
-	VMR17(V139)}}
+	{object V138 = vs_base[0];
+	VMR17(V138)}}
 	}
 /*	local entry for function BIT-ANDC2	*/
 
-static object LI18(V141,V140,va_alist)
-	object V141,V140;
+static object LI18(V140,V139,va_alist)
+	object V140,V139;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB18 VMS18 VMV18
-	{object V142;
+	{object V141;
+	object V142;
 	object V143;
-	object V144;
 	if(narg <2) too_few_arguments();
-	V142= V141;
-	V143= V140;
+	V141= V140;
+	V142= V139;
 	narg = narg - 2;
 	if (narg <= 0) goto T253;
 	else {
 	va_start(ap);
-	V144= va_arg(ap,object);}
+	V143= va_arg(ap,object);}
 	--narg; goto T254;
 T253:;
-	V144= Cnil;
+	V143= Cnil;
 T254:;
 	base[0]= small_fixnum(2);
-	base[1]= (V142);
-	base[2]= (V143);
-	base[3]= (V144);
+	base[1]= (V141);
+	base[2]= (V142);
+	base[3]= (V143);
 	vs_top=(vs_base=base+0)+4;
 	siLbit_array_op();
 	vs_top=sup;
-	{object V145 = vs_base[0];
-	VMR18(V145)}}
+	{object V144 = vs_base[0];
+	VMR18(V144)}}
 	}
 /*	local entry for function BIT-ORC1	*/
 
-static object LI19(V147,V146,va_alist)
-	object V147,V146;
+static object LI19(V146,V145,va_alist)
+	object V146,V145;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB19 VMS19 VMV19
-	{object V148;
+	{object V147;
+	object V148;
 	object V149;
-	object V150;
 	if(narg <2) too_few_arguments();
-	V148= V147;
-	V149= V146;
+	V147= V146;
+	V148= V145;
 	narg = narg - 2;
 	if (narg <= 0) goto T260;
 	else {
 	va_start(ap);
-	V150= va_arg(ap,object);}
+	V149= va_arg(ap,object);}
 	--narg; goto T261;
 T260:;
-	V150= Cnil;
+	V149= Cnil;
 T261:;
 	base[0]= small_fixnum(13);
-	base[1]= (V148);
-	base[2]= (V149);
-	base[3]= (V150);
+	base[1]= (V147);
+	base[2]= (V148);
+	base[3]= (V149);
 	vs_top=(vs_base=base+0)+4;
 	siLbit_array_op();
 	vs_top=sup;
-	{object V151 = vs_base[0];
-	VMR19(V151)}}
+	{object V150 = vs_base[0];
+	VMR19(V150)}}
 	}
 /*	local entry for function BIT-ORC2	*/
 
-static object LI20(V153,V152,va_alist)
-	object V153,V152;
+static object LI20(V152,V151,va_alist)
+	object V152,V151;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB20 VMS20 VMV20
-	{object V154;
+	{object V153;
+	object V154;
 	object V155;
-	object V156;
 	if(narg <2) too_few_arguments();
-	V154= V153;
-	V155= V152;
+	V153= V152;
+	V154= V151;
 	narg = narg - 2;
 	if (narg <= 0) goto T267;
 	else {
 	va_start(ap);
-	V156= va_arg(ap,object);}
+	V155= va_arg(ap,object);}
 	--narg; goto T268;
 T267:;
-	V156= Cnil;
+	V155= Cnil;
 T268:;
 	base[0]= small_fixnum(11);
-	base[1]= (V154);
-	base[2]= (V155);
-	base[3]= (V156);
+	base[1]= (V153);
+	base[2]= (V154);
+	base[3]= (V155);
 	vs_top=(vs_base=base+0)+4;
 	siLbit_array_op();
 	vs_top=sup;
-	{object V157 = vs_base[0];
-	VMR20(V157)}}
+	{object V156 = vs_base[0];
+	VMR20(V156)}}
 	}
 /*	local entry for function BIT-NOT	*/
 
-static object LI21(V158,va_alist)
-	object V158;
+static object LI21(V157,va_alist)
+	object V157;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB21 VMS21 VMV21
-	{object V159;
-	object V160;
+	{object V158;
+	object V159;
 	if(narg <1) too_few_arguments();
-	V159= V158;
+	V158= V157;
 	narg = narg - 1;
 	if (narg <= 0) goto T274;
 	else {
 	va_start(ap);
-	V160= va_arg(ap,object);}
+	V159= va_arg(ap,object);}
 	--narg; goto T275;
 T274:;
-	V160= Cnil;
+	V159= Cnil;
 T275:;
 	base[0]= small_fixnum(12);
-	base[1]= (V159);
-	base[2]= (V159);
-	base[3]= (V160);
+	base[1]= (V158);
+	base[2]= (V158);
+	base[3]= (V159);
 	vs_top=(vs_base=base+0)+4;
 	siLbit_array_op();
 	vs_top=sup;
-	{object V161 = vs_base[0];
-	VMR21(V161)}}
+	{object V160 = vs_base[0];
+	VMR21(V160)}}
 	}
 /*	local entry for function VECTOR-PUSH	*/
 
-static object LI22(V164,V165)
+static object LI22(V163,V164)
 
-object V164;register object V165;
+object V163;register object V164;
 {	 VMB22 VMS22 VMV22
 TTL:;
-	{register int V166;
-	base[0]= (V165);
+	{register int V165;
+	base[0]= (V164);
 	vs_top=(vs_base=base+0)+1;
 	Lfill_pointer();
 	vs_top=sup;
-	V166= fix(vs_base[0]);
-	base[0]= (V165);
+	V165= fix(vs_base[0]);
+	base[0]= (V164);
 	base[1]= small_fixnum(0);
 	vs_top=(vs_base=base+0)+2;
 	Larray_dimension();
 	vs_top=sup;
-	V167= vs_base[0];
-	if(!((V166)<(fix(V167)))){
+	V166= vs_base[0];
+	if(!((V165)<(fix(V166)))){
 	goto T284;}
-	(void)(aset1((V165),V166,(V164)));
-	base[0]= (V165);
-	base[1]= make_fixnum((V166)+1);
+	(void)(aset1((V164),V165,(V163)));
+	base[0]= (V164);
+	base[1]= make_fixnum((V165)+1);
 	vs_top=(vs_base=base+0)+2;
 	siLfill_pointer_set();
 	vs_top=sup;
-	{object V168 = make_fixnum(V166);
-	VMR22(V168)}
+	{object V167 = make_fixnum(V165);
+	VMR22(V167)}
 T284:;
-	{object V169 = Cnil;
-	VMR22(V169)}}
+	{object V168 = Cnil;
+	VMR22(V168)}}
 }
 /*	local entry for function VECTOR-PUSH-EXTEND	*/
 
-static object LI23(V171,V170,va_alist)
-	object V171,V170;
+static object LI23(V170,V169,va_alist)
+	object V170,V169;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB23 VMS23 VMV23
-	{object V172;
-	register object V173;
-	object V174;
+	{object V171;
+	register object V172;
+	object V173;
 	if(narg <2) too_few_arguments();
-	V172= V171;
-	V173= V170;
+	V171= V170;
+	V172= V169;
 	narg = narg - 2;
 	if (narg <= 0) goto T293;
 	else {
 	va_start(ap);
-	V174= va_arg(ap,object);}
+	V173= va_arg(ap,object);}
 	--narg; goto T294;
 T293:;
-	V174= Cnil;
+	V173= Cnil;
 T294:;
-	{register int V175;
-	base[0]= (V173);
+	{register int V174;
+	base[0]= (V172);
 	vs_top=(vs_base=base+0)+1;
 	Lfill_pointer();
 	vs_top=sup;
-	V175= fix(vs_base[0]);
-	base[0]= (V173);
+	V174= fix(vs_base[0]);
+	base[0]= (V172);
 	base[1]= small_fixnum(0);
 	vs_top=(vs_base=base+0)+2;
 	Larray_dimension();
 	vs_top=sup;
-	V176= vs_base[0];
-	if(!((V175)<(fix(V176)))){
+	V175= vs_base[0];
+	if(!((V174)<(fix(V175)))){
 	goto T299;}
-	(void)(aset1((V173),V175,(V172)));
-	base[0]= (V173);
-	base[1]= make_fixnum((V175)+1);
+	(void)(aset1((V172),V174,(V171)));
+	base[0]= (V172);
+	base[1]= make_fixnum((V174)+1);
 	vs_top=(vs_base=base+0)+2;
 	siLfill_pointer_set();
 	vs_top=sup;
-	{object V177 = make_fixnum(V175);
-	VMR23(V177)}
+	{object V176 = make_fixnum(V174);
+	VMR23(V176)}
 T299:;
-	base[0]= (V173);
+	base[0]= (V172);
 	base[1]= small_fixnum(0);
 	vs_top=(vs_base=base+0)+2;
 	Larray_dimension();
 	vs_top=sup;
-	V178= vs_base[0];
-	if((V174)!=Cnil){
-	V179= (V174);
+	V177= vs_base[0];
+	if((V173)!=Cnil){
+	V178= (V173);
 	goto T312;}
-	base[0]= (V173);
-	base[1]= small_fixnum(0);
-	vs_top=(vs_base=base+0)+2;
-	Larray_dimension();
-	vs_top=sup;
-	V180= vs_base[0];
-	if(!((fix(V180))>(0))){
-	goto T314;}
-	base[0]= (V173);
+	base[0]= (V172);
 	base[1]= small_fixnum(0);
 	vs_top=(vs_base=base+0)+2;
 	Larray_dimension();
 	vs_top=sup;
 	V179= vs_base[0];
+	if(!((fix(V179))>(0))){
+	goto T314;}
+	base[0]= (V172);
+	base[1]= small_fixnum(0);
+	vs_top=(vs_base=base+0)+2;
+	Larray_dimension();
+	vs_top=sup;
+	V178= vs_base[0];
 	goto T312;
 T314:;
-	V179= small_fixnum(5);
+	V178= small_fixnum(5);
 T312:;
-	V181= number_plus(V178,V179);
-	V182= make_cons(/* INLINE-ARGS */V181,Cnil);
-	base[0]= (V173);
+	V180= number_plus(V177,V178);
+	V181= make_cons(/* INLINE-ARGS */V180,Cnil);
+	base[0]= (V172);
 	vs_top=(vs_base=base+0)+1;
 	Larray_element_type();
 	vs_top=sup;
-	V183= vs_base[0];
-	V184 = make_fixnum(V175);
-	(void)((VFUN_NARGS=6,(*(LnkLI26))((V173),/* INLINE-ARGS */V182,VV[8],V183,VV[11],V184)));
-	(void)(aset1((V173),V175,(V172)));
-	base[0]= (V173);
-	base[1]= make_fixnum((V175)+1);
+	V182= vs_base[0];
+	V183 = make_fixnum(V174);
+	(void)((VFUN_NARGS=6,(*(LnkLI29))((V172),/* INLINE-ARGS */V181,VV[8],V182,VV[11],V183)));
+	(void)(aset1((V172),V174,(V171)));
+	base[0]= (V172);
+	base[1]= make_fixnum((V174)+1);
 	vs_top=(vs_base=base+0)+2;
 	siLfill_pointer_set();
 	vs_top=sup;
-	{object V185 = make_fixnum(V175);
-	VMR23(V185)}}}
+	{object V184 = make_fixnum(V174);
+	VMR23(V184)}}}
 	}
 /*	local entry for function VECTOR-POP	*/
 
-static object LI24(V187)
+static object LI24(V186)
 
-register object V187;
+register object V186;
 {	 VMB24 VMS24 VMV24
 TTL:;
-	{int V188;
-	base[0]= (V187);
+	{int V187;
+	base[0]= (V186);
 	vs_top=(vs_base=base+0)+1;
 	Lfill_pointer();
 	vs_top=sup;
-	V188= fix(vs_base[0]);
-	if(!((V188)==(0))){
+	V187= fix(vs_base[0]);
+	if(!((V187)==(0))){
 	goto T329;}
 	base[0]= VV[12];
-	base[1]= (V187);
+	base[1]= (V186);
 	vs_top=(vs_base=base+0)+2;
 	Lerror();
 	vs_top=sup;
 T329:;
-	base[0]= (V187);
-	base[1]= make_fixnum((V188)-1);
+	base[0]= (V186);
+	base[1]= make_fixnum((V187)-1);
 	vs_top=(vs_base=base+0)+2;
 	siLfill_pointer_set();
 	vs_top=sup;
-	{object V189 = aref1((V187),(V188)-1);
-	VMR24(V189)}}
+	{object V188 = aref1((V186),(V187)-1);
+	VMR24(V188)}}
 }
 /*	local entry for function ADJUST-ARRAY	*/
 
-static object LI25(V191,V190,va_alist)
-	object V191,V190;
+static object LI25(V190,V189,va_alist)
+	object V190,V189;
 	va_dcl 
 {	
 	va_list ap;
 	int narg = VFUN_NARGS; VMB25 VMS25 VMV25
-	{register object V192;
+	{register object V191;
+	register object V192;
 	register object V193;
 	register object V194;
-	register object V195;
+	object V195;
 	object V196;
 	object V197;
 	object V198;
 	object V199;
 	object V200;
-	object V201;
 	if(narg <2) too_few_arguments();
-	V192= V191;
-	V193= V190;
+	V191= V190;
+	V192= V189;
 	narg= narg - 2;
 	va_start(ap);
-	V202 = (ALLOCA_CONS(narg),ON_STACK_MAKE_LIST(narg));
-	V194= V202;
+	V201 = (ALLOCA_CONS(narg),ON_STACK_MAKE_LIST(narg));
+	V193= V201;
 	{
-	parse_key_rest(V202,narg,Vcs +3,&LI25key,ap);
-	V195=(Vcs[3]);
-	V196=(Vcs[4]);
-	V197=(Vcs[5]);
-	V198=(Vcs[6]);
-	V199=(Vcs[7]);
-	V200=(Vcs[8]);
-	V201=(Vcs[9]);
-	if(!(type_of((V193))==t_fixnum||type_of((V193))==t_bignum)){
+	parse_key_rest(V201,narg,Vcs +3,&LI25key,ap);
+	V194=(Vcs[3]);
+	V195=(Vcs[4]);
+	V196=(Vcs[5]);
+	V197=(Vcs[6]);
+	V198=(Vcs[7]);
+	V199=(Vcs[8]);
+	V200=(Vcs[9]);
+	if(!(type_of((V192))==t_fixnum||type_of((V192))==t_bignum)){
 	goto T337;}
-	V193= make_cons((V193),Cnil);
+	V192= make_cons((V192),Cnil);
 T337:;
-	{register object x= VV[11],V203= (V194);
-	while(!endp(V203))
-	if(eql(x,V203->c.c_car)){
+	{register object x= VV[11],V202= (V193);
+	while(!endp(V202))
+	if(eql(x,V202->c.c_car)){
 	goto T344;
-	}else V203=V203->c.c_cdr;
+	}else V202=V202->c.c_cdr;
 	goto T343;}
 T344:;
-	base[0]= (V192);
+	base[0]= (V191);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk27)();
+	(void) (*Lnk30)();
 	vs_top=sup;
 	if((vs_base[0])!=Cnil){
 	goto T341;}
@@ -1054,140 +1053,147 @@ T344:;
 	vs_top=sup;
 	goto T341;
 T343:;
-	base[0]= (V192);
+	base[0]= (V191);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk27)();
+	(void) (*Lnk30)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T341;}
-	base[0]= (V192);
+	base[0]= (V191);
 	vs_top=(vs_base=base+0)+1;
 	Lfill_pointer();
 	vs_top=sup;
-	V204= vs_base[0];
-	V194= ON_STACK_CONS(V204,(V194));
-	V194= ON_STACK_CONS(VV[11],(V194));
+	V203= vs_base[0];
+	V193= ON_STACK_CONS(V203,(V193));
+	V193= ON_STACK_CONS(VV[11],(V193));
 T341:;
-	base[0]= (V192);
+	base[0]= (V191);
 	vs_top=(vs_base=base+0)+1;
 	Larray_element_type();
 	vs_top=sup;
-	V195= vs_base[0];
-	if(((V195))==(Ct)){
+	V194= vs_base[0];
+	if(((V194))==(Ct)){
 	goto T360;}
-	V194= ON_STACK_CONS((V195),(V194));
-	V194= ON_STACK_CONS(VV[8],(V194));
+	V193= ON_STACK_CONS((V194),(V193));
+	V193= ON_STACK_CONS(VV[8],(V193));
 T360:;
-	{register object V205;
-	base[0]= (V193);
+	{register object V204;
+	base[0]= (V192);
 	base[1]= VV[14];
 	base[2]= Ct;
-	{object V206;
-	V206= (V194);
+	{object V205;
+	V205= (V193);
 	 vs_top=base+3;
-	 while(!endp(V206))
-	 {vs_push(car(V206));V206=cdr(V206);}
+	 while(!endp(V205))
+	 {vs_push(car(V205));V205=cdr(V205);}
 	vs_base=base+0;}
-	(void) (*Lnk25)();
+	(void) (*Lnk28)();
 	vs_top=sup;
-	V205= vs_base[0];
-	if((cdr((V193)))==Cnil){
+	V204= vs_base[0];
+	if((cdr((V192)))==Cnil){
 	goto T372;}
-	V207= cdr((V193));
-	V208= (*(LnkLI28))((V192));
-	if(!(equal(/* INLINE-ARGS */V207,cdr(/* INLINE-ARGS */V208)))){
+	V206= cdr((V192));
+	V207= (*(LnkLI31))((V191));
+	if(!(equal(/* INLINE-ARGS */V206,cdr(/* INLINE-ARGS */V207)))){
 	goto T373;}
-	if(!(((V195))==(VV[15]))){
+	if(!(((V194))==(VV[15]))){
 	goto T372;}
-	base[0]= (V193);
-	vs_top=(vs_base=base+0)+1;
+	base[1]= (V192);
+	vs_top=(vs_base=base+1)+1;
 	Llast();
 	vs_top=sup;
 	V209= vs_base[0];
-	{int V210= fix(car(V209));
-	if(!((0)==((V210>=0&&(8)>0?(V210)%(8):imod(V210,8))))){
-	goto T373;}}
+	base[0]= car(V209);
+	base[1]= symbol_value(VV[16]);
+	vs_top=(vs_base=base+0)+2;
+	Lmod();
+	vs_top=sup;
+	V208= vs_base[0];
+	if(!((0)==(fix(V208)))){
+	goto T373;}
 T372:;
-	base[0]= (V192);
-	base[1]= (V205);
+	base[0]= (V191);
+	base[1]= (V204);
 	base[2]= small_fixnum(0);
 	base[3]= small_fixnum(0);
-	base[5]= (V205);
+	base[5]= (V204);
 	vs_top=(vs_base=base+5)+1;
-	(void) (*Lnk29)();
+	(void) (*Lnk32)();
+	vs_top=sup;
+	V210= vs_base[0];
+	base[5]= (V191);
+	vs_top=(vs_base=base+5)+1;
+	(void) (*Lnk32)();
 	vs_top=sup;
 	V211= vs_base[0];
-	base[5]= (V192);
-	vs_top=(vs_base=base+5)+1;
-	(void) (*Lnk29)();
-	vs_top=sup;
-	V212= vs_base[0];
-	base[4]= (number_compare(V211,V212)<=0?(V211):V212);
+	base[4]= (number_compare(V210,V211)<=0?(V210):V211);
 	vs_top=(vs_base=base+0)+5;
-	(void) (*Lnk30)();
+	(void) (*Lnk33)();
 	vs_top=sup;
 	goto T371;
 T373:;
-	{register object V213;
-	base[0]= make_fixnum(length((V193)));
+	{register object V212;
+	base[0]= make_fixnum(length((V192)));
 	base[1]= VV[7];
 	base[2]= small_fixnum(0);
 	vs_top=(vs_base=base+0)+3;
 	Lmake_list();
 	vs_top=sup;
-	V213= vs_base[0];
-T397:;
-	base[0]= (V192);
-	{object V214;
-	V214= (V213);
+	V212= vs_base[0];
+T400:;
+	base[0]= (V191);
+	{object V213;
+	V213= (V212);
 	 vs_top=base+1;
-	 while(!endp(V214))
-	 {vs_push(car(V214));V214=cdr(V214);}
+	 while(!endp(V213))
+	 {vs_push(car(V213));V213=cdr(V213);}
 	vs_base=base+0;}
-	(void) (*Lnk31)();
+	(void) (*Lnk34)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
-	goto T400;}
-	base[0]= (V205);
-	base[2]= (V192);
-	{object V215;
-	V215= (V213);
+	goto T403;}
+	base[0]= (V204);
+	base[2]= (V191);
+	{object V214;
+	V214= (V212);
 	 vs_top=base+3;
-	 while(!endp(V215))
-	 {vs_push(car(V215));V215=cdr(V215);}
+	 while(!endp(V214))
+	 {vs_push(car(V214));V214=cdr(V214);}
 	vs_base=base+2;}
 	Laref();
 	vs_top=sup;
 	base[1]= vs_base[0];
-	base[2]= (V213);
+	base[2]= (V212);
 	vs_top=(vs_base=base+0)+3;
-	(void) (*Lnk23)();
+	(void) (*Lnk26)();
 	vs_top=sup;
-T400:;
-	if(((*(LnkLI24))((V213),(V193)))==Cnil){
-	goto T410;}
+T403:;
+	if(((*(LnkLI27))((V212),(V192)))==Cnil){
+	goto T413;}
 	goto T371;
-T410:;
-	goto T397;}
+T413:;
+	goto T400;}
 T371:;
-	base[0]= (V192);
-	base[1]= (V205);
+	base[0]= (V191);
+	base[1]= (V204);
 	vs_top=(vs_base=base+0)+2;
 	siLreplace_array();
 	vs_top=sup;
-	{object V216 = vs_base[0];
-	VMR25(V216)}}}
+	{object V215 = vs_base[0];
+	VMR25(V215)}}}
 	}}
-static LnkT31(){ call_or_link(VV[31],&Lnk31);} /* ARRAY-IN-BOUNDS-P */
-static LnkT30(){ call_or_link(VV[30],&Lnk30);} /* COPY-ARRAY-PORTION */
-static LnkT29(){ call_or_link(VV[29],&Lnk29);} /* ARRAY-TOTAL-SIZE */
-static object  LnkTLI28(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[28],&LnkLI28,1,ap);} /* ARRAY-DIMENSIONS */
-static LnkT25(){ call_or_link(VV[25],&Lnk25);} /* MAKE-ARRAY */
-static LnkT27(){ call_or_link(VV[27],&Lnk27);} /* ARRAY-HAS-FILL-POINTER-P */
-static object  LnkTLI26(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[26],&LnkLI26,ap);} /* ADJUST-ARRAY */
-static object  LnkTLI25(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[25],&LnkLI25,ap);} /* MAKE-ARRAY */
-static object  LnkTLI24(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[24],&LnkLI24,2,ap);} /* INCREMENT-CURSOR */
-static LnkT23(){ call_or_link(VV[23],&Lnk23);} /* ASET-BY-CURSOR */
-static object  LnkTLI22(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[22],&LnkLI22,2,ap);} /* SEQUENCE-CURSOR */
-static object  LnkTLI21(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[21],&LnkLI21,1,ap);} /* BEST-ARRAY-ELEMENT-TYPE */
-static LnkT16(){ call_or_link(VV[16],&Lnk16);} /* SUBTYPEP */
+static LnkT34(){ call_or_link(VV[34],&Lnk34);} /* ARRAY-IN-BOUNDS-P */
+static LnkT33(){ call_or_link(VV[33],&Lnk33);} /* COPY-ARRAY-PORTION */
+static LnkT32(){ call_or_link(VV[32],&Lnk32);} /* ARRAY-TOTAL-SIZE */
+static object  LnkTLI31(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[31],&LnkLI31,1,ap);} /* ARRAY-DIMENSIONS */
+static LnkT28(){ call_or_link(VV[28],&Lnk28);} /* MAKE-ARRAY */
+static LnkT30(){ call_or_link(VV[30],&Lnk30);} /* ARRAY-HAS-FILL-POINTER-P */
+static object  LnkTLI29(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[29],&LnkLI29,ap);} /* ADJUST-ARRAY */
+static object  LnkTLI28(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[28],&LnkLI28,ap);} /* MAKE-ARRAY */
+static object  LnkTLI27(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[27],&LnkLI27,2,ap);} /* INCREMENT-CURSOR */
+static LnkT26(){ call_or_link(VV[26],&Lnk26);} /* ASET-BY-CURSOR */
+static object  LnkTLI25(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[25],&LnkLI25,2,ap);} /* SEQUENCE-CURSOR */
+static LnkT24(){ call_or_link(VV[24],&Lnk24);} /* MAKE-ARRAY1 */
+static LnkT23(){ call_or_link(VV[23],&Lnk23);} /* GET-AELTTYPE */
+static object  LnkTLI22(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[22],&LnkLI22,1,ap);} /* BEST-ARRAY-ELEMENT-TYPE */
+static LnkT17(){ call_or_link(VV[17],&Lnk17);} /* SUBTYPEP */
