@@ -58,13 +58,13 @@ static L2()
 TTL:;
 	if((symbol_value(VV[3]))!=Cnil){
 	goto T19;}
-	(void)((*(LnkLI163))());
+	(void)((*(LnkLI158))());
 	if(((V5))==Cnil){
 	goto T25;}
 	(void)(princ((V3),Cnil));
 	base[3]= (V4);
 	vs_top=(vs_base=base+3)+1;
-	(void) (*Lnk164)();
+	(void) (*Lnk159)();
 	vs_top=sup;
 	goto T23;
 T25:;
@@ -80,11 +80,11 @@ T23:;
 	return;
 T19:;
 T33:;
-	(void)((*(LnkLI163))());
+	(void)((*(LnkLI158))());
 	if(((V5))==Cnil){
 	goto T38;}
 	(void)(princ((V3),Cnil));
-	(void)((*(LnkLI165))());
+	(void)((*(LnkLI160))());
 	(void)(prin1((V4),Cnil));
 	goto T36;
 T38:;
@@ -139,7 +139,7 @@ T48:;
 	goto T67;}
 	base[3]= (V4);
 	vs_top=(vs_base=base+3)+1;
-	(void) (*Lnk164)();
+	(void) (*Lnk159)();
 	vs_top=sup;
 T67:;
 	base[3]= Cnil;
@@ -148,12 +148,12 @@ T67:;
 T66:;
 	if(!eql(V6,VV[6])
 	&& !eql(V6,VV[7]))goto T71;
-	(void)((*(LnkLI166))());
+	(void)((*(LnkLI161))());
 	if(((V5))==Cnil){
 	goto T73;}
 	base[3]= (V4);
 	vs_top=(vs_base=base+3)+1;
-	(void) (*Lnk164)();
+	(void) (*Lnk159)();
 	vs_top=sup;
 T73:;
 	base[3]= Cnil;
@@ -162,14 +162,14 @@ T73:;
 T71:;
 	if(!eql(V6,VV[8])
 	&& !eql(V6,VV[9]))goto T77;
-	(void)((*(LnkLI166))());
+	(void)((*(LnkLI161))());
 	base[3]= Cnil;
 	vs_top=(vs_base=base+3)+1;
 	return;
 T77:;
 	if(!eql(V6,VV[10])
 	&& !eql(V6,VV[11]))goto T79;
-	(void)((*(LnkLI166))());
+	(void)((*(LnkLI161))());
 	bds_bind(VV[12],Ct);
 	bds_bind(VV[13],Cnil);
 	bds_bind(VV[14],Cnil);
@@ -182,7 +182,7 @@ T77:;
 T79:;
 	if(!eql(V6,VV[15])
 	&& !eql(V6,VV[16]))goto T82;
-	(void)((*(LnkLI166))());
+	(void)((*(LnkLI161))());
 	{frame_ptr fr;
 	fr=frs_sch_catch(VV[17]);
 	if(fr==NULL) FEerror("The tag ~s is undefined.",1,VV[17]);
@@ -196,14 +196,14 @@ T82:;
 	{object V9;
 	base[6]= symbol_value(VV[0]);
 	vs_top=(vs_base=base+6)+1;
-	(void) (*Lnk167)();
+	(void) (*Lnk162)();
 	vs_top=sup;
 	base[5]= vs_base[0];
 	vs_top=(vs_base=base+5)+1;
 	Leval();
 	vs_top=sup;
 	V9= vs_base[0];
-	(void)((*(LnkLI166))());
+	(void)((*(LnkLI161))());
 	base[4]= (V9);}
 	vs_top=(vs_base=base+3)+2;
 	return;
@@ -214,7 +214,7 @@ T85:;
 	register object V11;
 	base[6]= symbol_value(VV[0]);
 	vs_top=(vs_base=base+6)+1;
-	(void) (*Lnk167)();
+	(void) (*Lnk162)();
 	vs_top=sup;
 	base[5]= vs_base[0];
 	vs_top=(vs_base=base+5)+1;
@@ -225,7 +225,7 @@ T85:;
 	register object *sup=vs_base+VM3;
 	vs_reserve(VM3);
 	vs_top=sup;
-	(void)((*(LnkLI166))());
+	(void)((*(LnkLI161))());
 	}}
 	vs_base=V12;vs_top=V13;}
 	Llist();
@@ -252,7 +252,7 @@ T102:;
 T92:;
 	if(!eql(V6,VV[26])
 	&& !eql(V6,VV[27]))goto T118;
-	(void)((*(LnkLI166))());
+	(void)((*(LnkLI161))());
 	{frame_ptr fr;
 	fr=frs_sch_catch(VV[28]);
 	if(fr==NULL) FEerror("The tag ~s is undefined.",1,VV[28]);
@@ -260,7 +260,7 @@ T92:;
 	vs_top=(vs_base=base+3)+1;
 	unwind(fr,VV[28]);}
 T118:;
-	(void)((*(LnkLI166))());
+	(void)((*(LnkLI161))());
 	princ_char(10,Cnil);
 	base[3]= Ct;
 	base[4]= VV[29];
@@ -631,7 +631,7 @@ T210:;
 	base[0]= (V24);
 	base[1]= Ct;
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk168)();
+	(void) (*Lnk163)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T265;}
@@ -724,14 +724,14 @@ T286:;
 T297:;
 	base[0]= (V45);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk169)();
+	(void) (*Lnk164)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T309;}
 	base[0]= VV[59];
 	base[2]= (V45);
 	vs_top=(vs_base=base+2)+1;
-	(void) (*Lnk169)();
+	(void) (*Lnk164)();
 	vs_top=sup;
 	base[1]= vs_base[0];
 	base[2]= Cnil;
@@ -844,7 +844,7 @@ TTL:;
 	vs_top=sup;
 	V56= vs_base[0];
 	{object V55= V56;
-	if((V55!= VV[170]))goto T358;
+	if((V55!= VV[165]))goto T358;
 	base[0]= Ct;
 	base[1]= VV[66];
 	base[2]= (V54);
@@ -854,7 +854,7 @@ TTL:;
 	{object V57 = vs_base[0];
 	VMR11(V57)}
 T358:;
-	if((V55!= VV[171]))goto T362;
+	if((V55!= VV[166]))goto T362;
 	base[0]= Ct;
 	base[1]= VV[67];
 	base[2]= (V54);
@@ -864,7 +864,7 @@ T358:;
 	{object V58 = vs_base[0];
 	VMR11(V58)}
 T362:;
-	if((V55!= VV[172]))goto T366;
+	if((V55!= VV[167]))goto T366;
 	base[0]= Ct;
 	base[1]= VV[68];
 	base[2]= (V54);
@@ -905,7 +905,7 @@ T380:;
 	{object V60 = Cnil;
 	VMR11(V60)}
 T366:;
-	if((V55!= VV[173]))goto T387;
+	if((V55!= VV[168]))goto T387;
 	base[0]= Ct;
 	base[1]= VV[71];
 	base[2]= (V54);
@@ -946,8 +946,8 @@ T401:;
 	{object V62 = Cnil;
 	VMR11(V62)}
 T387:;
-	if((V55!= VV[174])
-	&& (V55!= VV[175]))goto T408;
+	if((V55!= VV[169])
+	&& (V55!= VV[170]))goto T408;
 	base[0]= Ct;
 	base[1]= VV[74];
 	base[2]= (V54);
@@ -1003,8 +1003,8 @@ T427:;
 	{object V67 = Cnil;
 	VMR11(V67)}}
 T408:;
-	if((V55!= VV[176])
-	&& (V55!= VV[177]))goto T433;
+	if((V55!= VV[171])
+	&& (V55!= VV[172]))goto T433;
 	base[0]= Ct;
 	base[1]= VV[77];
 	base[2]= (V54);
@@ -1072,14 +1072,14 @@ register object V75;
 TTL:;
 	base[0]= Ct;
 	{object V76= car((V75));
-	if((V76!= VV[178])
-	&& (V76!= VV[179])
-	&& (V76!= VV[180])
-	&& (V76!= VV[181]))goto T461;
+	if((V76!= VV[173])
+	&& (V76!= VV[174])
+	&& (V76!= VV[175])
+	&& (V76!= VV[176]))goto T461;
 	base[1]= VV[80];
 	goto T460;
 T461:;
-	if((V76!= VV[182]))goto T462;
+	if((V76!= VV[177]))goto T462;
 	base[1]= VV[81];
 	goto T460;
 T462:;
@@ -1223,7 +1223,7 @@ T512:;
 T518:;
 	base[0]= (V93);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk183)();
+	(void) (*Lnk178)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T527;}
@@ -1351,7 +1351,7 @@ T574:;
 T580:;
 	base[0]= (V103);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk183)();
+	(void) (*Lnk178)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T589;}
@@ -1477,7 +1477,7 @@ T636:;
 	princ_char(10,Cnil);
 T642:;
 	base[0]= VV[98];
-	base[1]= (*(LnkLI184))((V113));
+	base[1]= (*(LnkLI179))((V113));
 	base[2]= Cnil;
 	vs_top=(vs_base=base+0)+3;
 	(void) (*Lnk32)();
@@ -1490,7 +1490,7 @@ T650:;
 	base[0]= VV[99];
 	base[2]= (V113);
 	vs_top=(vs_base=base+2)+1;
-	(void) (*Lnk185)();
+	(void) (*Lnk180)();
 	vs_top=sup;
 	base[1]= vs_base[0];
 	base[2]= Cnil;
@@ -1556,7 +1556,7 @@ T686:;
 	base[10]= (V117);
 	base[11]= car(cddddr((V122)));
 	vs_top=(vs_base=base+10)+2;
-	(void) (*Lnk186)();
+	(void) (*Lnk181)();
 	vs_top=sup;
 	base[9]= vs_base[0];
 	vs_top=(vs_base=base+4)+6;
@@ -1579,7 +1579,7 @@ static L16()
 	vs_top=sup;
 TTL:;
 	bds_bind(VV[41],symbol_value(VV[41]));
-	(void)((*(LnkLI165))());
+	(void)((*(LnkLI160))());
 	if((symbol_value(VV[3]))!=Cnil){
 	goto T701;}
 	if(number_compare((VV[41]->s.s_dbind),small_fixnum(5))>0){
@@ -1608,7 +1608,7 @@ T701:;
 	else{
 	if(!(type_of((V125))==t_symbol)){
 	goto T715;}
-	V127= (*(LnkLI187))((V125));
+	V127= (*(LnkLI182))((V125));
 	frs_pop();
 	base[2]= V127;
 	vs_top=(vs_base=base+2)+1;
@@ -1621,7 +1621,7 @@ T715:;
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T718;}
-	V128= (*(LnkLI188))((V125));
+	V128= (*(LnkLI183))((V125));
 	frs_pop();
 	base[2]= V128;
 	vs_top=(vs_base=base+2)+1;
@@ -1630,7 +1630,7 @@ T715:;
 T718:;
 	if(!(type_of((V125))==t_character)){
 	goto T722;}
-	V129= (*(LnkLI189))((V125));
+	V129= (*(LnkLI184))((V125));
 	frs_pop();
 	base[2]= V129;
 	vs_top=(vs_base=base+2)+1;
@@ -1644,7 +1644,7 @@ type_of((V125))==t_shortfloat||
 type_of((V125))==t_longfloat||
 type_of((V125))==t_complex)){
 	goto T725;}
-	V130= (*(LnkLI190))((V125));
+	V130= (*(LnkLI185))((V125));
 	frs_pop();
 	base[2]= V130;
 	vs_top=(vs_base=base+2)+1;
@@ -1653,7 +1653,7 @@ type_of((V125))==t_complex)){
 T725:;
 	if(!(type_of((V125))==t_cons)){
 	goto T728;}
-	V131= (*(LnkLI191))((V125));
+	V131= (*(LnkLI186))((V125));
 	frs_pop();
 	base[2]= V131;
 	vs_top=(vs_base=base+2)+1;
@@ -1662,7 +1662,7 @@ T725:;
 T728:;
 	if(!(type_of((V125))==t_string)){
 	goto T731;}
-	V132= (*(LnkLI192))((V125));
+	V132= (*(LnkLI187))((V125));
 	frs_pop();
 	base[2]= V132;
 	vs_top=(vs_base=base+2)+1;
@@ -1673,7 +1673,7 @@ T731:;
 type_of((V125))==t_string||
 type_of((V125))==t_bitvector)){
 	goto T734;}
-	V133= (*(LnkLI193))((V125));
+	V133= (*(LnkLI188))((V125));
 	frs_pop();
 	base[2]= V133;
 	vs_top=(vs_base=base+2)+1;
@@ -1685,7 +1685,7 @@ type_of((V125))==t_vector||
 type_of((V125))==t_string||
 type_of((V125))==t_bitvector)){
 	goto T737;}
-	V134= (*(LnkLI194))((V125));
+	V134= (*(LnkLI189))((V125));
 	frs_pop();
 	base[2]= V134;
 	vs_top=(vs_base=base+2)+1;
@@ -1694,7 +1694,7 @@ type_of((V125))==t_bitvector)){
 T737:;
 	if(!(type_of((V125))==t_structure)){
 	goto T740;}
-	V135= (*(LnkLI195))((V125));
+	V135= (*(LnkLI190))((V125));
 	frs_pop();
 	base[2]= V135;
 	vs_top=(vs_base=base+2)+1;
@@ -1742,7 +1742,7 @@ TTL:;
 	else{
 	base[6]= (V136);
 	vs_top=(vs_base=base+6)+1;
-	(void) (*Lnk164)();
+	(void) (*Lnk159)();
 	vs_top=sup;
 	frs_pop();}
 T748:;
@@ -1789,7 +1789,7 @@ TTL:;
 	else{
 	base[8]= (V137);
 	vs_top=(vs_base=base+8)+1;
-	(void) (*Lnk164)();
+	(void) (*Lnk159)();
 	vs_top=sup;
 	frs_pop();}
 T755:;
@@ -1809,11 +1809,11 @@ T755:;
 /*	function definition for PRINT-DOC	*/
 
 static L19()
-{register object *VOL base=vs_base;
-	register object *VOL sup=base+VM20; VC20
+{register object *base=vs_base;
+	register object *sup=base+VM20; VC20
 	vs_reserve(VM20);
 	bds_check;
-	{VOL object V138;
+	{object V138;
 	if(vs_top-vs_base<1) too_few_arguments();
 	if(vs_top-vs_base>2) too_many_arguments();
 	vs_base=vs_base+1;
@@ -1824,7 +1824,7 @@ static L19()
 T759:;
 	V138= Cnil;
 T760:;
-	{VOL object V139;
+	{register object V139;
 	base[2]= Cnil;
 	V139= Cnil;
 	base[3]= base[0];
@@ -1832,8 +1832,8 @@ T760:;
 	Lspecial_form_p();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
-	goto T766;}{VOL object V140;
-	V140= (*(LnkLI196))(base[0],VV[105]);
+	goto T766;}{object V140;
+	V140= (*(LnkLI191))(base[0],VV[105]);
 	if(V140==Cnil)goto T770;
 	base[3]= V140;
 	goto T769;
@@ -1861,8 +1861,8 @@ T766:;
 	Lmacro_function();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
-	goto T778;}{VOL object V141;
-	V141= (*(LnkLI196))(base[0],VV[105]);
+	goto T778;}{object V141;
+	V141= (*(LnkLI191))(base[0],VV[105]);
 	if(V141==Cnil)goto T782;
 	base[3]= V141;
 	goto T781;
@@ -1880,8 +1880,8 @@ T778:;
 	Lfboundp();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
-	goto T786;}{VOL object V142;
-	V142= (*(LnkLI196))(base[0],VV[105]);
+	goto T786;}{object V142;
+	V142= (*(LnkLI191))(base[0],VV[105]);
 	if(V142==Cnil)goto T790;
 	base[3]= V142;
 	goto T789;
@@ -1894,7 +1894,7 @@ T790:;}
 	if(!(type_of((V139))==t_cons)){
 	goto T793;}
 	{object V143= car((V139));
-	if((V143!= VV[178]))goto T797;
+	if((V143!= VV[173]))goto T797;
 	base[4]= Cnil;
 	base[5]= VV[111];
 	base[6]= cadr((V139));
@@ -1904,7 +1904,7 @@ T790:;}
 	base[3]= vs_base[0];
 	goto T789;
 T797:;
-	if((V143!= VV[179]))goto T801;
+	if((V143!= VV[174]))goto T801;
 	base[4]= Cnil;
 	base[5]= VV[112];
 	base[6]= caddr((V139));
@@ -1914,7 +1914,7 @@ T797:;
 	base[3]= vs_base[0];
 	goto T789;
 T801:;
-	if((V143!= VV[180]))goto T805;
+	if((V143!= VV[175]))goto T805;
 	base[4]= Cnil;
 	base[5]= VV[113];
 	base[6]= car(cddddr((V139)));
@@ -1924,7 +1924,7 @@ T801:;
 	base[3]= vs_base[0];
 	goto T789;
 T805:;
-	if((V143!= VV[181]))goto T809;
+	if((V143!= VV[176]))goto T809;
 	base[4]= Cnil;
 	base[5]= VV[114];
 	base[6]= cadr(cddddr((V139)));
@@ -1945,7 +1945,7 @@ T789:;
 	vs_top=sup;
 	goto T764;
 T786:;
-	V139= (*(LnkLI196))(base[0],VV[105]);
+	V139= (*(LnkLI191))(base[0],VV[105]);
 	if(((V139))==Cnil){
 	goto T764;}
 	base[3]= (V139);
@@ -1972,10 +1972,10 @@ T764:;
 	V145= vs_base[0];
 	if(!((V144)==(V145))){
 	goto T824;}
-	if(((*(LnkLI196))(base[0],VV[120]))==Cnil){
+	if(((*(LnkLI191))(base[0],VV[120]))==Cnil){
 	goto T819;}
-T824:;{VOL object V146;
-	V146= (*(LnkLI196))(base[0],VV[120]);
+T824:;{object V146;
+	V146= (*(LnkLI191))(base[0],VV[120]);
 	if(V146==Cnil)goto T833;
 	base[3]= V146;
 	goto T832;
@@ -1993,8 +1993,8 @@ T821:;
 	siLspecialp();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
-	goto T837;}{VOL object V147;
-	V147= (*(LnkLI196))(base[0],VV[120]);
+	goto T837;}{object V147;
+	V147= (*(LnkLI191))(base[0],VV[120]);
 	if(V147==Cnil)goto T841;
 	base[3]= V147;
 	goto T840;
@@ -2007,7 +2007,7 @@ T840:;
 	vs_top=sup;
 	goto T819;
 T837:;
-	V139= (*(LnkLI196))(base[0],VV[120]);
+	V139= (*(LnkLI191))(base[0],VV[120]);
 	if(((V139))!=Cnil){
 	goto T844;}
 	base[3]= base[0];
@@ -2027,7 +2027,7 @@ T850:;
 	L20(base);
 	vs_top=sup;
 T819:;
-	V139= (*(LnkLI196))(base[0],VV[127]);
+	V139= (*(LnkLI191))(base[0],VV[127]);
 	if(((V139))==Cnil){
 	goto T854;}
 	base[3]= (V139);
@@ -2058,7 +2058,7 @@ T854:;
 	vs_top=sup;
 	bds_unwind1;
 T852:;
-	V139= (*(LnkLI196))(base[0],VV[133]);
+	V139= (*(LnkLI191))(base[0],VV[133]);
 	if(((V139))==Cnil){
 	goto T870;}
 	base[3]= (V139);
@@ -2083,7 +2083,7 @@ T870:;
 	L20(base);
 	vs_top=sup;
 T868:;
-	V139= (*(LnkLI196))(base[0],VV[35]);
+	V139= (*(LnkLI191))(base[0],VV[35]);
 	if(((V139))==Cnil){
 	goto T884;}
 	base[3]= (V139);
@@ -2152,19 +2152,19 @@ T901:;
 	if(!(type_of((V139))==t_cons)){
 	goto T920;}
 	{object V150= car((V139));
-	if((V150!= VV[178]))goto T922;
+	if((V150!= VV[173]))goto T922;
 	base[7]= make_cons(VV[148],cdr((V139)));
 	goto T918;
 T922:;
-	if((V150!= VV[179]))goto T923;
+	if((V150!= VV[174]))goto T923;
 	base[7]= make_cons(VV[148],cddr((V139)));
 	goto T918;
 T923:;
-	if((V150!= VV[180]))goto T924;
+	if((V150!= VV[175]))goto T924;
 	base[7]= make_cons(VV[148],cddddr((V139)));
 	goto T918;
 T924:;
-	if((V150!= VV[181]))goto T925;
+	if((V150!= VV[176]))goto T925;
 	base[7]= make_cons(VV[148],cdr(cddddr((V139))));
 	goto T918;
 T925:;
@@ -2183,129 +2183,31 @@ T918:;
 	vs_top=sup;
 	bds_unwind1;
 T763:;
-	{VOL object V151;
-	V151= symbol_name(base[0]);
-	base[3]= Cnil;
-	base[4]= VV[153];
-	vs_top=(vs_base=base+4)+1;
-	Lboundp();
+	base[3]= symbol_name(base[0]);
+	vs_top=(vs_base=base+3)+1;
+	(void) (*Lnk192)();
 	vs_top=sup;
-	if((vs_base[0])==Cnil){
-	goto T930;}
-	goto T929;
-T930:;
-	base[5]= VV[154];
-	vs_top=(vs_base=base+5)+1;
-	Lfind_package();
-	vs_top=sup;
-	base[4]= vs_base[0];
-	bds_bind(VV[130],base[4]);
-	base[6]= VV[155];
-	vs_top=(vs_base=base+6)+1;
-	(void) (*Lnk197)();
-	vs_top=sup;
-	base[5]= vs_base[0];
-	vs_top=(vs_base=base+5)+1;
-	Lprobe_file();
-	vs_top=sup;
-	base[3]= vs_base[0];
-	if((base[3])==Cnil){
-	goto T940;}
-	base[5]= base[3];
-	vs_top=(vs_base=base+5)+1;
-	(void) (*Lnk198)();
-	vs_top=sup;
-	bds_unwind1;
-	goto T929;
-T940:;
-	setq(VV[153],Cnil);
-	bds_unwind1;
-T929:;
-	{register object x= (V151),V153= symbol_value(VV[153]);
-	while(!endp(V153))
-	if(type_of(V153->c.c_car)==t_cons &&equal(x,V153->c.c_car->c.c_car)){
-	V152= (V153->c.c_car);
-	goto T947;
-	}else V153=V153->c.c_cdr;
-	V152= Cnil;}
-T947:;
-	base[3]= cdr(V152);
-	if((base[3])==Cnil){
-	goto T927;}
-	base[2]= Ct;
-	base[6]= VV[156];
-	vs_top=(vs_base=base+6)+1;
-	(void) (*Lnk197)();
-	vs_top=sup;
-	base[5]= vs_base[0];
-	vs_top=(vs_base=base+5)+1;
-	(void) (*Lnk199)();
-	vs_top=sup;
-	base[4]= vs_base[0];
-	{object tag;frame_ptr fr;object p;bool active;
-	frs_push(FRS_PROTECT,Cnil);
-	if(nlj_active){tag=nlj_tag;fr=nlj_fr;active=TRUE;}
-	else{
-	base[6]= base[4];
-	base[7]= base[3];
-	vs_top=(vs_base=base+6)+2;
-	Lfile_position();
-	vs_top=sup;
-	{register object V154;
-	V154= VV[4];
-T958:;
-	if(!(eql((V154),VV[157]))){
-	goto T959;}
-	base[6]= Cnil;
-	vs_top=(vs_base=base+6)+1;
-	goto T953;
-T959:;
-	(void)(princ((V154),Cnil));
-	base[6]= base[4];
-	base[7]= Cnil;
-	base[8]= VV[157];
-	vs_top=(vs_base=base+6)+3;
-	Lread_char();
-	vs_top=sup;
-	V154= vs_base[0];
-	goto T958;}
-T953:;
-	active=FALSE;}
-	base[5]=Cnil;
-	while(vs_base<vs_top)
-	{base[5]=MMcons(vs_top[-1],base[5]);vs_top--;}
-	vs_top=sup;
-	nlj_active=FALSE;frs_pop();
-	base[6]= base[4];
-	vs_top=(vs_base=base+6)+1;
-	Lclose();
-	vs_top=sup;
-	vs_base=vs_top=base+6;
-	for(p= base[5];!endp(p);p=MMcdr(p))vs_push(MMcar(p));
-	if(active)unwind(fr,tag);else{
-	vs_top=sup;}}}
-T927:;
 	if(((V138))==Cnil){
-	goto T973;}
+	goto T930;}
 	vs_top=(vs_base=base+2)+1;
 	return;
-T973:;
+T930:;
 	if((base[2])==Cnil){
-	goto T977;}
+	goto T934;}
 	base[3]= Ct;
-	base[4]= VV[158];
+	base[4]= VV[153];
 	vs_top=(vs_base=base+3)+2;
 	Lformat();
 	vs_top=sup;
-	goto T975;
-T977:;
+	goto T932;
+T934:;
 	base[3]= Ct;
-	base[4]= VV[159];
+	base[4]= VV[154];
 	base[5]= base[0];
 	vs_top=(vs_base=base+3)+3;
 	Lformat();
 	vs_top=sup;
-T975:;
+T932:;
 	vs_base=vs_top=base+3;
 	vs_base[0]=Cnil;
 	return;}
@@ -2317,276 +2219,276 @@ static L22()
 {register object *base=vs_base;
 	register object *sup=base+VM21; VC21
 	vs_reserve(VM21);
-	{object V155;
-	object V156;
+	{object V151;
+	object V152;
 	if(vs_top-vs_base<1) too_few_arguments();
 	if(vs_top-vs_base>2) too_many_arguments();
-	V155=(base[0]);
+	V151=(base[0]);
 	vs_base=vs_base+1;
-	if(vs_base>=vs_top){vs_top=sup;goto T984;}
-	V156=(base[1]);
+	if(vs_base>=vs_top){vs_top=sup;goto T941;}
+	V152=(base[1]);
 	vs_top=sup;
-	goto T985;
-T984:;
-	V156= VV[160];
-T985:;
-	{register object V157;
-	V157= Cnil;
-	V155= coerce_to_string((V155));
-	if(((V156))==Cnil){
-	goto T992;}
-	{object V158;
-	register object V159;
-	register object V160;
-	base[2]= V156;
+	goto T942;
+T941:;
+	V152= VV[155];
+T942:;
+	{register object V153;
+	V153= Cnil;
+	V151= coerce_to_string((V151));
+	if(((V152))==Cnil){
+	goto T949;}
+	{object V154;
+	register object V155;
+	register object V156;
+	base[2]= V152;
 	vs_top=(vs_base=base+2)+1;
 	Lpackagep();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
-	goto T996;}
-	V158= V156;
-	goto T994;
-T996:;
-	base[2]= coerce_to_string(V156);
+	goto T953;}
+	V154= V152;
+	goto T951;
+T953:;
+	base[2]= coerce_to_string(V152);
 	vs_top=(vs_base=base+2)+1;
 	Lfind_package();
 	vs_top=sup;
-	V158= vs_base[0];
-T994:;
-	V159= Cnil;
-	V160= Cnil;
-	{int V162;
-	int V163;
-	base[2]= (V158);
+	V154= vs_base[0];
+T951:;
+	V155= Cnil;
+	V156= Cnil;
+	{int V158;
+	int V159;
+	base[2]= (V154);
 	vs_top=(vs_base=base+2)+1;
-	(void) (*Lnk200)();
-	if(vs_base>=vs_top){vs_top=sup;goto T1002;}
-	V162= fix(vs_base[0]);
+	(void) (*Lnk193)();
+	if(vs_base>=vs_top){vs_top=sup;goto T959;}
+	V158= fix(vs_base[0]);
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T1003;}
-	V163= fix(vs_base[0]);
+	if(vs_base>=vs_top){vs_top=sup;goto T960;}
+	V159= fix(vs_base[0]);
 	vs_top=sup;
-	goto T1004;
-T1002:;
-	V162= fix(Cnil);
-T1003:;
-	V163= fix(Cnil);
-T1004:;
-	{object V164;
-	object V165;
+	goto T961;
+T959:;
+	V158= fix(Cnil);
+T960:;
+	V159= fix(Cnil);
+T961:;
+	{object V160;
+	object V161;
 	{ save_avma;
-	V166 = stoi(V163);
-	V167 = stoi(V162);
-	V164= make_integer(addii(V166,V167));restore_avma;}
-	V165= small_fixnum(0);
-T1008:;
-	if(!(number_compare((V165),(V164))>=0)){
-	goto T1009;}
-	V159= Cnil;
-	goto T990;
-T1009:;
-	V168 = make_fixnum(V163);
-	if(!(number_compare((V165),V168)<0)){
-	goto T1020;}
-	base[3]= (V158);
-	base[4]= (V165);
+	V162 = stoi(V159);
+	V163 = stoi(V158);
+	V160= make_integer(addii(V162,V163));restore_avma;}
+	V161= small_fixnum(0);
+T965:;
+	if(!(number_compare((V161),(V160))>=0)){
+	goto T966;}
+	V155= Cnil;
+	goto T947;
+T966:;
+	V164 = make_fixnum(V159);
+	if(!(number_compare((V161),V164)<0)){
+	goto T977;}
+	base[3]= (V154);
+	base[4]= (V161);
 	vs_top=(vs_base=base+3)+2;
 	siLpackage_internal();
 	vs_top=sup;
-	V160= vs_base[0];
-	goto T1018;
-T1020:;
-	base[3]= (V158);
-	V169 = make_fixnum(V163);
-	base[4]= number_minus((V165),V169);
+	V156= vs_base[0];
+	goto T975;
+T977:;
+	base[3]= (V154);
+	V165 = make_fixnum(V159);
+	base[4]= number_minus((V161),V165);
 	vs_top=(vs_base=base+3)+2;
 	siLpackage_external();
 	vs_top=sup;
-	V160= vs_base[0];
-T1018:;
-T1016:;
-	if(((V160))!=Cnil){
-	goto T1026;}
-	goto T1017;
-T1026:;
-	V159= car((V160));
-	V170= coerce_to_string((V159));
-	if(((*(LnkLI201))((V155),/* INLINE-ARGS */V170))==Cnil){
-	goto T1031;}{object V171;
-	base[3]= (V159);
+	V156= vs_base[0];
+T975:;
+T973:;
+	if(((V156))!=Cnil){
+	goto T983;}
+	goto T974;
+T983:;
+	V155= car((V156));
+	V166= coerce_to_string((V155));
+	if(((*(LnkLI194))((V151),/* INLINE-ARGS */V166))==Cnil){
+	goto T988;}{object V167;
+	base[3]= (V155);
 	base[4]= Ct;
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk168)();
+	(void) (*Lnk163)();
 	vs_top=sup;
-	V171= vs_base[0];
-	if(V171==Cnil)goto T1035;
-	V157= V171;
-	goto T1034;
-T1035:;}
-T1034:;
-T1031:;
-	V160= cdr((V160));
-	goto T1016;
-T1017:;
-	goto T1014;
-T1014:;
-	V165= one_plus((V165));
-	goto T1008;}}}
-T992:;
-	{object V172;
-	object V173;
+	V167= vs_base[0];
+	if(V167==Cnil)goto T992;
+	V153= V167;
+	goto T991;
+T992:;}
+T991:;
+T988:;
+	V156= cdr((V156));
+	goto T973;
+T974:;
+	goto T971;
+T971:;
+	V161= one_plus((V161));
+	goto T965;}}}
+T949:;
+	{object V168;
+	object V169;
 	vs_base=vs_top;
 	Llist_all_packages();
 	vs_top=sup;
-	V172= vs_base[0];
-	V173= car((V172));
-T1047:;
-	if(!(endp((V172)))){
-	goto T1048;}
-	goto T990;
-T1048:;
-	{object V174;
-	register object V175;
-	register object V176;
-	base[4]= V173;
+	V168= vs_base[0];
+	V169= car((V168));
+T1004:;
+	if(!(endp((V168)))){
+	goto T1005;}
+	goto T947;
+T1005:;
+	{object V170;
+	register object V171;
+	register object V172;
+	base[4]= V169;
 	vs_top=(vs_base=base+4)+1;
 	Lpackagep();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
-	goto T1055;}
-	V174= V173;
-	goto T1053;
-T1055:;
-	base[4]= coerce_to_string(V173);
+	goto T1012;}
+	V170= V169;
+	goto T1010;
+T1012:;
+	base[4]= coerce_to_string(V169);
 	vs_top=(vs_base=base+4)+1;
 	Lfind_package();
 	vs_top=sup;
-	V174= vs_base[0];
-T1053:;
-	V175= Cnil;
-	V176= Cnil;
-	{int V178;
-	int V179;
-	base[4]= (V174);
+	V170= vs_base[0];
+T1010:;
+	V171= Cnil;
+	V172= Cnil;
+	{int V174;
+	int V175;
+	base[4]= (V170);
 	vs_top=(vs_base=base+4)+1;
-	(void) (*Lnk200)();
-	if(vs_base>=vs_top){vs_top=sup;goto T1061;}
-	V178= fix(vs_base[0]);
+	(void) (*Lnk193)();
+	if(vs_base>=vs_top){vs_top=sup;goto T1018;}
+	V174= fix(vs_base[0]);
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T1062;}
-	V179= fix(vs_base[0]);
+	if(vs_base>=vs_top){vs_top=sup;goto T1019;}
+	V175= fix(vs_base[0]);
 	vs_top=sup;
-	goto T1063;
-T1061:;
-	V178= fix(Cnil);
-T1062:;
-	V179= fix(Cnil);
-T1063:;
-	{object V180;
-	register object V181;
+	goto T1020;
+T1018:;
+	V174= fix(Cnil);
+T1019:;
+	V175= fix(Cnil);
+T1020:;
+	{object V176;
+	register object V177;
 	{ save_avma;
-	V182 = stoi(V179);
-	V183 = stoi(V178);
-	V180= make_integer(addii(V182,V183));restore_avma;}
-	V181= small_fixnum(0);
-T1067:;
-	if(!(number_compare((V181),(V180))>=0)){
-	goto T1068;}
-	V175= Cnil;
-	goto T1052;
-T1068:;
-	V184 = make_fixnum(V179);
-	if(!(number_compare((V181),V184)<0)){
-	goto T1079;}
-	base[5]= (V174);
-	base[6]= (V181);
+	V178 = stoi(V175);
+	V179 = stoi(V174);
+	V176= make_integer(addii(V178,V179));restore_avma;}
+	V177= small_fixnum(0);
+T1024:;
+	if(!(number_compare((V177),(V176))>=0)){
+	goto T1025;}
+	V171= Cnil;
+	goto T1009;
+T1025:;
+	V180 = make_fixnum(V175);
+	if(!(number_compare((V177),V180)<0)){
+	goto T1036;}
+	base[5]= (V170);
+	base[6]= (V177);
 	vs_top=(vs_base=base+5)+2;
 	siLpackage_internal();
 	vs_top=sup;
-	V176= vs_base[0];
-	goto T1077;
-T1079:;
-	base[5]= (V174);
-	V185 = make_fixnum(V179);
-	base[6]= number_minus((V181),V185);
+	V172= vs_base[0];
+	goto T1034;
+T1036:;
+	base[5]= (V170);
+	V181 = make_fixnum(V175);
+	base[6]= number_minus((V177),V181);
 	vs_top=(vs_base=base+5)+2;
 	siLpackage_external();
 	vs_top=sup;
-	V176= vs_base[0];
-T1077:;
-T1075:;
-	if(((V176))!=Cnil){
-	goto T1085;}
-	goto T1076;
-T1085:;
-	V175= car((V176));
-	V186= coerce_to_string((V175));
-	if(((*(LnkLI201))((V155),/* INLINE-ARGS */V186))==Cnil){
-	goto T1090;}{object V187;
-	base[5]= (V175);
+	V172= vs_base[0];
+T1034:;
+T1032:;
+	if(((V172))!=Cnil){
+	goto T1042;}
+	goto T1033;
+T1042:;
+	V171= car((V172));
+	V182= coerce_to_string((V171));
+	if(((*(LnkLI194))((V151),/* INLINE-ARGS */V182))==Cnil){
+	goto T1047;}{object V183;
+	base[5]= (V171);
 	base[6]= Ct;
 	vs_top=(vs_base=base+5)+2;
-	(void) (*Lnk168)();
+	(void) (*Lnk163)();
 	vs_top=sup;
-	V187= vs_base[0];
-	if(V187==Cnil)goto T1094;
-	V157= V187;
-	goto T1093;
-T1094:;}
-T1093:;
-T1090:;
-	V176= cdr((V176));
-	goto T1075;
-T1076:;
-	goto T1073;
-T1073:;
-	V181= one_plus((V181));
-	goto T1067;}}}
-T1052:;
+	V183= vs_base[0];
+	if(V183==Cnil)goto T1051;
+	V153= V183;
+	goto T1050;
+T1051:;}
+T1050:;
+T1047:;
 	V172= cdr((V172));
-	V173= car((V172));
-	goto T1047;}
-T990:;
-	if(((V157))==Cnil){
-	goto T1110;}
+	goto T1032;
+T1033:;
+	goto T1030;
+T1030:;
+	V177= one_plus((V177));
+	goto T1024;}}}
+T1009:;
+	V168= cdr((V168));
+	V169= car((V168));
+	goto T1004;}
+T947:;
+	if(((V153))==Cnil){
+	goto T1067;}
 	base[2]= Ct;
-	base[3]= VV[161];
+	base[3]= VV[156];
 	vs_top=(vs_base=base+2)+2;
 	Lformat();
 	vs_top=sup;
-	goto T1108;
-T1110:;
+	goto T1065;
+T1067:;
 	base[2]= Ct;
-	base[3]= VV[162];
-	base[4]= (V155);
-	base[5]= (V156);
-	if((V156)==Cnil){
+	base[3]= VV[157];
+	base[4]= (V151);
+	base[5]= (V152);
+	if((V152)==Cnil){
 	base[6]= Cnil;
-	goto T1118;}
-	base[8]= V156;
+	goto T1075;}
+	base[8]= V152;
 	vs_top=(vs_base=base+8)+1;
 	Lpackagep();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
-	goto T1121;}
-	base[7]= V156;
-	goto T1119;
-T1121:;
-	base[8]= coerce_to_string(V156);
+	goto T1078;}
+	base[7]= V152;
+	goto T1076;
+T1078:;
+	base[8]= coerce_to_string(V152);
 	vs_top=(vs_base=base+8)+1;
 	Lfind_package();
 	vs_top=sup;
 	base[7]= vs_base[0];
-T1119:;
+T1076:;
 	vs_top=(vs_base=base+7)+1;
 	Lpackage_name();
 	vs_top=sup;
 	base[6]= vs_base[0];
-T1118:;
+T1075:;
 	vs_top=(vs_base=base+2)+5;
 	Lformat();
 	vs_top=sup;
-T1108:;
+T1065:;
 	vs_base=vs_top=base+2;
 	vs_base[0]=Cnil;
 	return;}
@@ -2606,19 +2508,19 @@ TTL:;
 	vs_top=(vs_base=base+0)+1;
 	Lsymbol_package();
 	vs_top=sup;
-	V189= vs_base[0];
+	V185= vs_base[0];
 	base[0]= VV[151];
 	vs_top=(vs_base=base+0)+1;
 	Lfind_package();
 	vs_top=sup;
-	V190= vs_base[0];
-	if(!((V189)==(V190))){
-	goto T1126;}
+	V186= vs_base[0];
+	if(!((V185)==(V186))){
+	goto T1083;}
 	base[0]= VV[152];
 	vs_top=(vs_base=base+0)+1;
 	Lfind_package();
 	return;
-T1126:;
+T1083:;
 	base[0]= symbol_value(VV[130]);
 	vs_top=(vs_base=base+0)+1;
 	return;
@@ -2630,48 +2532,46 @@ register object *base0;
 {	register object *base=vs_base;
 	register object *sup=base+VM23; VC23
 	vs_reserve(VM23);
-	{object V191;
-	object V192;
+	{object V187;
+	object V188;
 	check_arg(2);
-	V191=(base[0]);
-	V192=(base[1]);
+	V187=(base[0]);
+	V188=(base[1]);
 	vs_top=sup;
 TTL:;
 	base0[2]= Ct;
 	base[2]= Ct;
 	base[3]= VV[150];
 	base[4]= base0[0];
-	base[5]= (V192);
-	base[6]= (V191);
+	base[5]= (V188);
+	base[6]= (V187);
 	vs_top=(vs_base=base+2)+5;
 	Lformat();
 	return;
 	}
 }
-static object  LnkTLI201(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[201],&LnkLI201,2,ap);} /* SUBSTRINGP */
-static LnkT200(){ call_or_link(VV[200],&Lnk200);} /* PACKAGE-SIZE */
-static LnkT199(){ call_or_link(VV[199],&Lnk199);} /* OPEN */
-static LnkT198(){ call_or_link(VV[198],&Lnk198);} /* LOAD */
-static LnkT197(){ call_or_link(VV[197],&Lnk197);} /* SRC-PATH */
-static object  LnkTLI196(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[196],&LnkLI196,2,ap);} /* DOCUMENTATION */
-static object  LnkTLI195(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[195],&LnkLI195,1,ap);} /* INSPECT-STRUCTURE */
-static object  LnkTLI194(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[194],&LnkLI194,1,ap);} /* INSPECT-ARRAY */
-static object  LnkTLI193(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[193],&LnkLI193,1,ap);} /* INSPECT-VECTOR */
-static object  LnkTLI192(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[192],&LnkLI192,1,ap);} /* INSPECT-STRING */
-static object  LnkTLI191(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[191],&LnkLI191,1,ap);} /* INSPECT-CONS */
-static object  LnkTLI190(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[190],&LnkLI190,1,ap);} /* INSPECT-NUMBER */
-static object  LnkTLI189(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[189],&LnkLI189,1,ap);} /* INSPECT-CHARACTER */
-static object  LnkTLI188(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[188],&LnkLI188,1,ap);} /* INSPECT-PACKAGE */
-static object  LnkTLI187(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[187],&LnkLI187,1,ap);} /* INSPECT-SYMBOL */
-static LnkT186(){ call_or_link(VV[186],&Lnk186);} /* STRUCTURE-REF1 */
-static LnkT185(){ call_or_link(VV[185],&Lnk185);} /* ARRAY-TOTAL-SIZE */
-static object  LnkTLI184(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[184],&LnkLI184,1,ap);} /* ARRAY-DIMENSIONS */
-static LnkT183(){ call_or_link(VV[183],&Lnk183);} /* ARRAY-HAS-FILL-POINTER-P */
-static LnkT169(){ call_or_link(VV[169],&Lnk169);} /* PACKAGE-SHADOWING-SYMBOLS */
-static LnkT168(){ call_or_link(VV[168],&Lnk168);} /* PRINT-DOC */
+static object  LnkTLI194(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[194],&LnkLI194,2,ap);} /* SUBSTRINGP */
+static LnkT193(){ call_or_link(VV[193],&Lnk193);} /* PACKAGE-SIZE */
+static LnkT192(){ call_or_link(VV[192],&Lnk192);} /* IDESCRIBE */
+static object  LnkTLI191(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[191],&LnkLI191,2,ap);} /* DOCUMENTATION */
+static object  LnkTLI190(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[190],&LnkLI190,1,ap);} /* INSPECT-STRUCTURE */
+static object  LnkTLI189(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[189],&LnkLI189,1,ap);} /* INSPECT-ARRAY */
+static object  LnkTLI188(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[188],&LnkLI188,1,ap);} /* INSPECT-VECTOR */
+static object  LnkTLI187(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[187],&LnkLI187,1,ap);} /* INSPECT-STRING */
+static object  LnkTLI186(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[186],&LnkLI186,1,ap);} /* INSPECT-CONS */
+static object  LnkTLI185(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[185],&LnkLI185,1,ap);} /* INSPECT-NUMBER */
+static object  LnkTLI184(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[184],&LnkLI184,1,ap);} /* INSPECT-CHARACTER */
+static object  LnkTLI183(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[183],&LnkLI183,1,ap);} /* INSPECT-PACKAGE */
+static object  LnkTLI182(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[182],&LnkLI182,1,ap);} /* INSPECT-SYMBOL */
+static LnkT181(){ call_or_link(VV[181],&Lnk181);} /* STRUCTURE-REF1 */
+static LnkT180(){ call_or_link(VV[180],&Lnk180);} /* ARRAY-TOTAL-SIZE */
+static object  LnkTLI179(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[179],&LnkLI179,1,ap);} /* ARRAY-DIMENSIONS */
+static LnkT178(){ call_or_link(VV[178],&Lnk178);} /* ARRAY-HAS-FILL-POINTER-P */
+static LnkT164(){ call_or_link(VV[164],&Lnk164);} /* PACKAGE-SHADOWING-SYMBOLS */
+static LnkT163(){ call_or_link(VV[163],&Lnk163);} /* PRINT-DOC */
 static LnkT32(){ call_or_link(VV[32],&Lnk32);} /* READ-INSPECT-COMMAND */
-static LnkT167(){ call_or_link(VV[167],&Lnk167);} /* READ-PRESERVING-WHITESPACE */
-static object  LnkTLI166(){return call_proc0(VV[166],&LnkLI166);} /* INSPECT-READ-LINE */
-static object  LnkTLI165(){return call_proc0(VV[165],&LnkLI165);} /* INSPECT-INDENT */
-static LnkT164(){ call_or_link(VV[164],&Lnk164);} /* INSPECT-OBJECT */
-static object  LnkTLI163(){return call_proc0(VV[163],&LnkLI163);} /* INSPECT-INDENT-1 */
+static LnkT162(){ call_or_link(VV[162],&Lnk162);} /* READ-PRESERVING-WHITESPACE */
+static object  LnkTLI161(){return call_proc0(VV[161],&LnkLI161);} /* INSPECT-READ-LINE */
+static object  LnkTLI160(){return call_proc0(VV[160],&LnkLI160);} /* INSPECT-INDENT */
+static LnkT159(){ call_or_link(VV[159],&Lnk159);} /* INSPECT-OBJECT */
+static object  LnkTLI158(){return call_proc0(VV[158],&LnkLI158);} /* INSPECT-INDENT-1 */
