@@ -17,7 +17,7 @@ T2:;
 	base[0]= VV[0];
 	base[1]= (V2);
 	vs_top=(vs_base=base+0)+2;
-	Lerror();
+	(void) (*Lnk9)();
 	vs_top=sup;
 T1:;
 	if(!(number_compare(small_fixnum(0),(V2))==0)){
@@ -28,7 +28,7 @@ T9:;
 	{object V4;
 	base[0]= (V2);
 	vs_top=(vs_base=base+0)+1;
-	Linteger_length();
+	(void) (*Lnk10)();
 	vs_top=sup;
 	V4= vs_base[0];
 	{register object V5;
@@ -37,11 +37,11 @@ T9:;
 	base[2]= (V4);
 	base[3]= small_fixnum(2);
 	vs_top=(vs_base=base+2)+2;
-	Lceiling();
+	(void) (*Lnk11)();
 	vs_top=sup;
 	base[1]= vs_base[0];
 	vs_top=(vs_base=base+0)+2;
-	Lash();
+	(void) (*Lnk12)();
 	vs_top=sup;
 	V5= vs_base[0];
 	V6= Cnil;
@@ -49,7 +49,7 @@ T19:;
 	base[0]= (V2);
 	base[1]= (V5);
 	vs_top=(vs_base=base+0)+2;
-	Lfloor();
+	(void) (*Lnk13)();
 	vs_top=sup;
 	V6= vs_base[0];
 	if(!(number_compare((V5),(V6))<=0)){
@@ -60,7 +60,7 @@ T26:;
 	base[0]= number_plus((V5),(V6));
 	base[1]= small_fixnum(2);
 	vs_top=(vs_base=base+0)+2;
-	Lfloor();
+	(void) (*Lnk13)();
 	vs_top=sup;
 	V5= vs_base[0];
 	goto T19;}}
@@ -74,35 +74,35 @@ register object V9;
 TTL:;
 	base[0]= (V9);
 	vs_top=(vs_base=base+0)+1;
-	Lcomplexp();
+	(void) (*Lnk14)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T36;}
 	base[1]= (V9);
 	vs_top=(vs_base=base+1)+1;
-	Lrealpart();
+	(void) (*Lnk15)();
 	vs_top=sup;
 	V10= vs_base[0];
 	base[1]= (V9);
 	vs_top=(vs_base=base+1)+1;
-	Lrealpart();
+	(void) (*Lnk15)();
 	vs_top=sup;
 	V11= vs_base[0];
 	V12= number_times(V10,V11);
 	base[1]= (V9);
 	vs_top=(vs_base=base+1)+1;
-	Limagpart();
+	(void) (*Lnk16)();
 	vs_top=sup;
 	V13= vs_base[0];
 	base[1]= (V9);
 	vs_top=(vs_base=base+1)+1;
-	Limagpart();
+	(void) (*Lnk16)();
 	vs_top=sup;
 	V14= vs_base[0];
 	V15= number_times(V13,V14);
 	base[0]= number_plus(/* INLINE-ARGS */V12,/* INLINE-ARGS */V15);
 	vs_top=(vs_base=base+0)+1;
-	Lsqrt();
+	(void) (*Lnk17)();
 	vs_top=sup;
 	{object V16 = vs_base[0];
 	VMR2(V16)}
@@ -124,16 +124,16 @@ object V20;
 TTL:;
 	base[1]= (V20);
 	vs_top=(vs_base=base+1)+1;
-	Limagpart();
+	(void) (*Lnk16)();
 	vs_top=sup;
 	base[0]= vs_base[0];
 	base[2]= (V20);
 	vs_top=(vs_base=base+2)+1;
-	Lrealpart();
+	(void) (*Lnk15)();
 	vs_top=sup;
 	base[1]= vs_base[0];
 	vs_top=(vs_base=base+0)+2;
-	Latan();
+	(void) (*Lnk18)();
 	vs_top=sup;
 	{object V21 = vs_base[0];
 	VMR3(V21)}
@@ -151,9 +151,9 @@ TTL:;
 	VMR4(V24)}
 T56:;
 	base[0]= (V23);
-	base[1]= (*(LnkLI9))((V23));
+	base[1]= (*(LnkLI19))((V23));
 	vs_top=(vs_base=base+0)+2;
-	Ldivide();
+	(void) (*Lnk20)();
 	vs_top=sup;
 	{object V25 = vs_base[0];
 	VMR4(V25)}
@@ -167,7 +167,7 @@ object V27;
 TTL:;
 	base[0]= number_times(VV[1],(V27));
 	vs_top=(vs_base=base+0)+1;
-	Lexp();
+	(void) (*Lnk21)();
 	vs_top=sup;
 	{object V28 = vs_base[0];
 	VMR5(V28)}
@@ -184,19 +184,19 @@ TTL:;
 	V35= number_times((V30),(V30));
 	base[1]= number_minus(VV[2],/* INLINE-ARGS */V35);
 	vs_top=(vs_base=base+1)+1;
-	Lsqrt();
+	(void) (*Lnk17)();
 	vs_top=sup;
 	V34= vs_base[0];
 	base[0]= number_plus(/* INLINE-ARGS */V33,V34);
 	vs_top=(vs_base=base+0)+1;
-	Llog();
+	(void) (*Lnk22)();
 	vs_top=sup;
 	V32= vs_base[0];
 	V36= number_times(VV[1],V32);
 	V31= number_negate(/* INLINE-ARGS */V36);
 	base[0]= (V30);
 	vs_top=(vs_base=base+0)+1;
-	Lcomplexp();
+	(void) (*Lnk14)();
 	vs_top=sup;
 	if((vs_base[0])!=Cnil){
 	goto T68;}
@@ -207,7 +207,7 @@ TTL:;
 T68:;
 	base[0]= (V31);
 	vs_top=(vs_base=base+0)+1;
-	Limagpart();
+	(void) (*Lnk16)();
 	vs_top=sup;
 	V37= vs_base[0];
 	if(!(number_compare(small_fixnum(0),V37)==0)){
@@ -215,7 +215,7 @@ T68:;
 T66:;
 	base[0]= (V31);
 	vs_top=(vs_base=base+0)+1;
-	Lrealpart();
+	(void) (*Lnk15)();
 	vs_top=sup;
 	{object V38 = vs_base[0];
 	VMR6(V38)}
@@ -234,20 +234,20 @@ TTL:;
 	V45= number_times((V41),(V41));
 	base[1]= number_minus(VV[2],/* INLINE-ARGS */V45);
 	vs_top=(vs_base=base+1)+1;
-	Lsqrt();
+	(void) (*Lnk17)();
 	vs_top=sup;
 	V44= vs_base[0];
 	V46= number_times(VV[1],V44);
 	base[0]= number_plus((V41),/* INLINE-ARGS */V46);
 	vs_top=(vs_base=base+0)+1;
-	Llog();
+	(void) (*Lnk22)();
 	vs_top=sup;
 	V43= vs_base[0];
 	V47= number_times(VV[1],V43);
 	V42= number_negate(/* INLINE-ARGS */V47);
 	base[0]= (V41);
 	vs_top=(vs_base=base+0)+1;
-	Lcomplexp();
+	(void) (*Lnk14)();
 	vs_top=sup;
 	if((vs_base[0])!=Cnil){
 	goto T86;}
@@ -258,7 +258,7 @@ TTL:;
 T86:;
 	base[0]= (V42);
 	vs_top=(vs_base=base+0)+1;
-	Limagpart();
+	(void) (*Lnk16)();
 	vs_top=sup;
 	V48= vs_base[0];
 	if(!(number_compare(small_fixnum(0),V48)==0)){
@@ -266,7 +266,7 @@ T86:;
 T84:;
 	base[0]= (V42);
 	vs_top=(vs_base=base+0)+1;
-	Lrealpart();
+	(void) (*Lnk15)();
 	vs_top=sup;
 	{object V49 = vs_base[0];
 	VMR7(V49)}
@@ -283,18 +283,18 @@ object V52;
 TTL:;
 	base[1]= (V52);
 	vs_top=(vs_base=base+1)+1;
-	Lexp();
+	(void) (*Lnk21)();
 	vs_top=sup;
 	V53= vs_base[0];
 	base[1]= number_negate((V52));
 	vs_top=(vs_base=base+1)+1;
-	Lexp();
+	(void) (*Lnk21)();
 	vs_top=sup;
 	V54= vs_base[0];
 	base[0]= number_minus(V53,V54);
 	base[1]= VV[4];
 	vs_top=(vs_base=base+0)+2;
-	Ldivide();
+	(void) (*Lnk20)();
 	vs_top=sup;
 	{object V55 = vs_base[0];
 	VMR8(V55)}
@@ -308,18 +308,18 @@ object V57;
 TTL:;
 	base[1]= (V57);
 	vs_top=(vs_base=base+1)+1;
-	Lexp();
+	(void) (*Lnk21)();
 	vs_top=sup;
 	V58= vs_base[0];
 	base[1]= number_negate((V57));
 	vs_top=(vs_base=base+1)+1;
-	Lexp();
+	(void) (*Lnk21)();
 	vs_top=sup;
 	V59= vs_base[0];
 	base[0]= number_plus(V58,V59);
 	base[1]= VV[4];
 	vs_top=(vs_base=base+0)+2;
-	Ldivide();
+	(void) (*Lnk20)();
 	vs_top=sup;
 	{object V60 = vs_base[0];
 	VMR9(V60)}
@@ -331,10 +331,10 @@ static object LI10(V62)
 object V62;
 {	 VMB10 VMS10 VMV10
 TTL:;
-	base[0]= (*(LnkLI10))((V62));
-	base[1]= (*(LnkLI11))((V62));
+	base[0]= (*(LnkLI23))((V62));
+	base[1]= (*(LnkLI24))((V62));
 	vs_top=(vs_base=base+0)+2;
-	Ldivide();
+	(void) (*Lnk20)();
 	vs_top=sup;
 	{object V63 = vs_base[0];
 	VMR10(V63)}
@@ -349,12 +349,12 @@ TTL:;
 	V67= number_times((V65),(V65));
 	base[1]= number_plus(VV[2],/* INLINE-ARGS */V67);
 	vs_top=(vs_base=base+1)+1;
-	Lsqrt();
+	(void) (*Lnk17)();
 	vs_top=sup;
 	V66= vs_base[0];
 	base[0]= number_plus((V65),V66);
 	vs_top=(vs_base=base+0)+1;
-	Llog();
+	(void) (*Lnk22)();
 	vs_top=sup;
 	{object V68 = vs_base[0];
 	VMR11(V68)}
@@ -370,17 +370,17 @@ TTL:;
 	base[2]= one_minus((V70));
 	base[3]= one_plus((V70));
 	vs_top=(vs_base=base+2)+2;
-	Ldivide();
+	(void) (*Lnk20)();
 	vs_top=sup;
 	base[1]= vs_base[0];
 	vs_top=(vs_base=base+1)+1;
-	Lsqrt();
+	(void) (*Lnk17)();
 	vs_top=sup;
 	V72= vs_base[0];
 	V73= number_times(/* INLINE-ARGS */V71,V72);
 	base[0]= number_plus((V70),/* INLINE-ARGS */V73);
 	vs_top=(vs_base=base+0)+1;
-	Llog();
+	(void) (*Lnk22)();
 	vs_top=sup;
 	{object V74 = vs_base[0];
 	VMR12(V74)}
@@ -400,22 +400,22 @@ T120:;
 	base[0]= VV[5];
 	base[1]= (V76);
 	vs_top=(vs_base=base+0)+2;
-	Lerror();
+	(void) (*Lnk9)();
 	vs_top=sup;
 T119:;
 	base[1]= one_plus((V76));
 	V77= number_times((V76),(V76));
 	base[3]= number_minus(VV[2],/* INLINE-ARGS */V77);
 	vs_top=(vs_base=base+3)+1;
-	Lsqrt();
+	(void) (*Lnk17)();
 	vs_top=sup;
 	base[2]= vs_base[0];
 	vs_top=(vs_base=base+1)+2;
-	Ldivide();
+	(void) (*Lnk20)();
 	vs_top=sup;
 	base[0]= vs_base[0];
 	vs_top=(vs_base=base+0)+1;
-	Llog();
+	(void) (*Lnk22)();
 	vs_top=sup;
 	{object V78 = vs_base[0];
 	VMR13(V78)}
@@ -436,7 +436,7 @@ TTL:;
 	object V84;
 	base[0]= (V80);
 	vs_top=(vs_base=base+0)+1;
-	Linteger_decode_float();
+	(void) (*Lnk25)();
 	if(vs_base>=vs_top){vs_top=sup;goto T135;}
 	V82= vs_base[0];
 	vs_base++;
@@ -458,7 +458,7 @@ T138:;
 	goto T140;}
 	base[0]= (V80);
 	vs_top=(vs_base=base+0)+1;
-	Lfloat_radix();
+	(void) (*Lnk26)();
 	vs_top=sup;
 	V85= vs_base[0];
 	V86= number_expt(V85,(V83));
@@ -467,7 +467,7 @@ T138:;
 T140:;
 	base[0]= (V80);
 	vs_top=(vs_base=base+0)+1;
-	Lfloat_radix();
+	(void) (*Lnk26)();
 	vs_top=sup;
 	V88= vs_base[0];
 	V89= number_expt(V88,(V83));
@@ -477,16 +477,16 @@ T140:;
 T131:;
 	base[0]= (V81);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk12)();
+	(void) (*Lnk27)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T147;}
 	{object V92 = (V80);
 	VMR14(V92)}
 T147:;
-	base[0]= (*(LnkLI13))(VV[6],(V81),VV[7]);
+	base[0]= (*(LnkLI28))(VV[6],(V81),VV[7]);
 	vs_top=(vs_base=base+0)+1;
-	Lerror();
+	(void) (*Lnk9)();
 	vs_top=sup;
 	{object V93 = vs_base[0];
 	VMR14(V93)}}
@@ -514,16 +514,16 @@ T152:;
 	object V97;
 	base[3]= (V94);
 	vs_top=(vs_base=base+3)+1;
-	Lfloat();
+	(void) (*Lnk29)();
 	vs_top=sup;
 	base[2]= vs_base[0];
 	base[4]= (V95);
 	vs_top=(vs_base=base+4)+1;
-	Lfloat();
+	(void) (*Lnk29)();
 	vs_top=sup;
 	base[3]= vs_base[0];
 	vs_top=(vs_base=base+2)+2;
-	Lfloor();
+	(void) (*Lnk13)();
 	if(vs_base>=vs_top){vs_top=sup;goto T159;}
 	V96= vs_base[0];
 	vs_base++;
@@ -539,7 +539,7 @@ T161:;
 	base[3]= (V96);
 	base[4]= (V97);
 	vs_top=(vs_base=base+3)+2;
-	Lfloat();
+	(void) (*Lnk29)();
 	vs_top=sup;
 	base[2]= vs_base[0];
 	base[3]= (V97);
@@ -570,16 +570,16 @@ T167:;
 	object V101;
 	base[3]= (V98);
 	vs_top=(vs_base=base+3)+1;
-	Lfloat();
+	(void) (*Lnk29)();
 	vs_top=sup;
 	base[2]= vs_base[0];
 	base[4]= (V99);
 	vs_top=(vs_base=base+4)+1;
-	Lfloat();
+	(void) (*Lnk29)();
 	vs_top=sup;
 	base[3]= vs_base[0];
 	vs_top=(vs_base=base+2)+2;
-	Lceiling();
+	(void) (*Lnk11)();
 	if(vs_base>=vs_top){vs_top=sup;goto T174;}
 	V100= vs_base[0];
 	vs_base++;
@@ -595,7 +595,7 @@ T176:;
 	base[3]= (V100);
 	base[4]= (V101);
 	vs_top=(vs_base=base+3)+2;
-	Lfloat();
+	(void) (*Lnk29)();
 	vs_top=sup;
 	base[2]= vs_base[0];
 	base[3]= (V101);
@@ -626,16 +626,16 @@ T182:;
 	object V105;
 	base[3]= (V102);
 	vs_top=(vs_base=base+3)+1;
-	Lfloat();
+	(void) (*Lnk29)();
 	vs_top=sup;
 	base[2]= vs_base[0];
 	base[4]= (V103);
 	vs_top=(vs_base=base+4)+1;
-	Lfloat();
+	(void) (*Lnk29)();
 	vs_top=sup;
 	base[3]= vs_base[0];
 	vs_top=(vs_base=base+2)+2;
-	Ltruncate();
+	(void) (*Lnk30)();
 	if(vs_base>=vs_top){vs_top=sup;goto T189;}
 	V104= vs_base[0];
 	vs_base++;
@@ -651,7 +651,7 @@ T191:;
 	base[3]= (V104);
 	base[4]= (V105);
 	vs_top=(vs_base=base+3)+2;
-	Lfloat();
+	(void) (*Lnk29)();
 	vs_top=sup;
 	base[2]= vs_base[0];
 	base[3]= (V105);
@@ -682,16 +682,16 @@ T197:;
 	object V109;
 	base[3]= (V106);
 	vs_top=(vs_base=base+3)+1;
-	Lfloat();
+	(void) (*Lnk29)();
 	vs_top=sup;
 	base[2]= vs_base[0];
 	base[4]= (V107);
 	vs_top=(vs_base=base+4)+1;
-	Lfloat();
+	(void) (*Lnk29)();
 	vs_top=sup;
 	base[3]= vs_base[0];
 	vs_top=(vs_base=base+2)+2;
-	Lround();
+	(void) (*Lnk31)();
 	if(vs_base>=vs_top){vs_top=sup;goto T204;}
 	V108= vs_base[0];
 	vs_base++;
@@ -707,7 +707,7 @@ T206:;
 	base[3]= (V108);
 	base[4]= (V109);
 	vs_top=(vs_base=base+3)+2;
-	Lfloat();
+	(void) (*Lnk29)();
 	vs_top=sup;
 	base[2]= vs_base[0];
 	base[3]= (V109);
@@ -726,7 +726,7 @@ TTL:;
 	base[1]= (V112);
 	base[2]= (V113);
 	vs_top=(vs_base=base+0)+3;
-	Lboole();
+	(void) (*Lnk32)();
 	vs_top=sup;
 	{object V114 = vs_base[0];
 	VMR19(V114)}
@@ -742,7 +742,7 @@ TTL:;
 	base[1]= (V117);
 	base[2]= (V118);
 	vs_top=(vs_base=base+0)+3;
-	Lboole();
+	(void) (*Lnk32)();
 	vs_top=sup;
 	{object V119 = vs_base[0];
 	VMR20(V119)}
@@ -758,7 +758,7 @@ TTL:;
 	base[1]= (V122);
 	base[2]= (V123);
 	vs_top=(vs_base=base+0)+3;
-	Lboole();
+	(void) (*Lnk32)();
 	vs_top=sup;
 	{object V124 = vs_base[0];
 	VMR21(V124)}
@@ -774,7 +774,7 @@ TTL:;
 	base[1]= (V127);
 	base[2]= (V128);
 	vs_top=(vs_base=base+0)+3;
-	Lboole();
+	(void) (*Lnk32)();
 	vs_top=sup;
 	{object V129 = vs_base[0];
 	VMR22(V129)}
@@ -790,7 +790,7 @@ TTL:;
 	base[1]= (V132);
 	base[2]= (V133);
 	vs_top=(vs_base=base+0)+3;
-	Lboole();
+	(void) (*Lnk32)();
 	vs_top=sup;
 	{object V134 = vs_base[0];
 	VMR23(V134)}
@@ -806,7 +806,7 @@ TTL:;
 	base[1]= (V137);
 	base[2]= (V138);
 	vs_top=(vs_base=base+0)+3;
-	Lboole();
+	(void) (*Lnk32)();
 	vs_top=sup;
 	{object V139 = vs_base[0];
 	VMR24(V139)}
@@ -821,7 +821,7 @@ TTL:;
 	base[0]= small_fixnum(-1);
 	base[1]= (V141);
 	vs_top=(vs_base=base+0)+2;
-	Llogxor();
+	(void) (*Lnk33)();
 	vs_top=sup;
 	{object V142 = vs_base[0];
 	VMR25(V142)}
@@ -833,148 +833,185 @@ static object LI26(V145,V146)
 object V145;object V146;
 {	 VMB26 VMS26 VMV26
 TTL:;
-	base[0]= (V145);
-	base[1]= (V146);
-	vs_top=(vs_base=base+0)+2;
-	Llogand();
+	base[2]= (V145);
+	base[3]= (V146);
+	vs_top=(vs_base=base+2)+2;
+	(void) (*Lnk34)();
 	vs_top=sup;
-	V147= vs_base[0];
-	{object V148 = (((number_compare(small_fixnum(0),V147)==0?Ct:Cnil))==Cnil?Ct:Cnil);
-	VMR26(V148)}
+	base[1]= vs_base[0];
+	vs_top=(vs_base=base+1)+1;
+	(void) (*Lnk35)();
+	vs_top=sup;
+	base[0]= vs_base[0];
+	vs_top=(vs_base=base+0)+1;
+	(void) (*Lnk36)();
+	vs_top=sup;
+	{object V147 = vs_base[0];
+	VMR26(V147)}
 }
 /*	local entry for function BYTE	*/
 
-static object LI27(V151,V152)
+static object LI27(V150,V151)
 
-object V151;object V152;
+object V150;object V151;
 {	 VMB27 VMS27 VMV27
 TTL:;
-	{object V153 = make_cons((V151),(V152));
-	VMR27(V153)}
+	{object V152 = make_cons((V150),(V151));
+	VMR27(V152)}
 }
 /*	local entry for function BYTE-SIZE	*/
 
-static object LI28(V155)
+static object LI28(V154)
 
-object V155;
+object V154;
 {	 VMB28 VMS28 VMV28
 TTL:;
-	{object V156 = car((V155));
-	VMR28(V156)}
+	{object V155 = car((V154));
+	VMR28(V155)}
 }
 /*	local entry for function BYTE-POSITION	*/
 
-static object LI29(V158)
+static object LI29(V157)
 
-object V158;
+object V157;
 {	 VMB29 VMS29 VMV29
 TTL:;
-	{object V159 = cdr((V158));
-	VMR29(V159)}
+	{object V158 = cdr((V157));
+	VMR29(V158)}
 }
 /*	local entry for function LDB	*/
 
-static object LI30(V162,V163)
+static object LI30(V161,V162)
 
-object V162;object V163;
+object V161;object V162;
 {	 VMB30 VMS30 VMV30
 TTL:;
-	base[0]= (V163);
-	V165= (*(LnkLI15))((V162));
-	base[1]= number_negate(/* INLINE-ARGS */V165);
+	base[0]= (V162);
+	V164= (*(LnkLI38))((V161));
+	base[1]= number_negate(/* INLINE-ARGS */V164);
 	vs_top=(vs_base=base+0)+2;
-	Lash();
+	(void) (*Lnk12)();
 	vs_top=sup;
-	V164= vs_base[0];
+	V163= vs_base[0];
 	base[0]= small_fixnum(1);
-	base[1]= (*(LnkLI16))((V162));
+	base[1]= (*(LnkLI39))((V161));
 	vs_top=(vs_base=base+0)+2;
-	Lash();
+	(void) (*Lnk12)();
 	vs_top=sup;
-	V166= vs_base[0];
-	V167= number_negate(V166);
-	{object V168 = (*(LnkLI14))(V164,/* INLINE-ARGS */V167);
-	VMR30(V168)}
+	V165= vs_base[0];
+	V166= number_negate(V165);
+	{object V167 = (*(LnkLI37))(V163,/* INLINE-ARGS */V166);
+	VMR30(V167)}
 }
 /*	local entry for function LDB-TEST	*/
 
-static object LI31(V171,V172)
+static object LI31(V170,V171)
 
-object V171;object V172;
+object V170;object V171;
 {	 VMB31 VMS31 VMV31
 TTL:;
-	V173= (*(LnkLI17))((V171),(V172));
-	{object V174 = (((number_compare(small_fixnum(0),/* INLINE-ARGS */V173)==0?Ct:Cnil))==Cnil?Ct:Cnil);
-	VMR31(V174)}
+	base[1]= (*(LnkLI40))((V170),(V171));
+	vs_top=(vs_base=base+1)+1;
+	(void) (*Lnk35)();
+	vs_top=sup;
+	base[0]= vs_base[0];
+	vs_top=(vs_base=base+0)+1;
+	(void) (*Lnk36)();
+	vs_top=sup;
+	{object V172 = vs_base[0];
+	VMR31(V172)}
 }
 /*	local entry for function MASK-FIELD	*/
 
-static object LI32(V177,V178)
+static object LI32(V175,V176)
 
-object V177;object V178;
+object V175;object V176;
 {	 VMB32 VMS32 VMV32
 TTL:;
-	base[0]= (*(LnkLI17))((V177),(V178));
-	base[1]= (*(LnkLI15))((V177));
+	base[0]= (*(LnkLI40))((V175),(V176));
+	base[1]= (*(LnkLI38))((V175));
 	vs_top=(vs_base=base+0)+2;
-	Lash();
+	(void) (*Lnk12)();
 	vs_top=sup;
-	{object V179 = vs_base[0];
-	VMR32(V179)}
+	{object V177 = vs_base[0];
+	VMR32(V177)}
 }
 /*	local entry for function DPB	*/
 
-static object LI33(V183,V184,V185)
+static object LI33(V181,V182,V183)
 
-object V183;object V184;object V185;
+object V181;object V182;object V183;
 {	 VMB33 VMS33 VMV33
 TTL:;
-	base[0]= (V185);
-	base[1]= (*(LnkLI18))((V184),(V185));
+	base[0]= (V183);
+	base[1]= (*(LnkLI41))((V182),(V183));
 	base[4]= small_fixnum(1);
-	base[5]= (*(LnkLI16))((V184));
+	base[5]= (*(LnkLI39))((V182));
 	vs_top=(vs_base=base+4)+2;
-	Lash();
+	(void) (*Lnk12)();
 	vs_top=sup;
-	V186= vs_base[0];
-	V187= number_negate(V186);
-	base[3]= (*(LnkLI14))((V183),/* INLINE-ARGS */V187);
-	base[4]= (*(LnkLI15))((V184));
+	V184= vs_base[0];
+	V185= number_negate(V184);
+	base[3]= (*(LnkLI37))((V181),/* INLINE-ARGS */V185);
+	base[4]= (*(LnkLI38))((V182));
 	vs_top=(vs_base=base+3)+2;
-	Lash();
+	(void) (*Lnk12)();
 	vs_top=sup;
 	base[2]= vs_base[0];
 	vs_top=(vs_base=base+0)+3;
-	Llogxor();
+	(void) (*Lnk33)();
 	vs_top=sup;
-	{object V188 = vs_base[0];
-	VMR33(V188)}
+	{object V186 = vs_base[0];
+	VMR33(V186)}
 }
 /*	local entry for function DEPOSIT-FIELD	*/
 
-static object LI34(V192,V193,V194)
+static object LI34(V190,V191,V192)
 
-object V192;object V193;object V194;
+object V190;object V191;object V192;
 {	 VMB34 VMS34 VMV34
 TTL:;
-	base[0]= (V192);
-	V196= (*(LnkLI15))((V193));
-	base[1]= number_negate(/* INLINE-ARGS */V196);
+	base[0]= (V190);
+	V194= (*(LnkLI38))((V191));
+	base[1]= number_negate(/* INLINE-ARGS */V194);
 	vs_top=(vs_base=base+0)+2;
-	Lash();
+	(void) (*Lnk12)();
 	vs_top=sup;
-	V195= vs_base[0];
-	{object V197 = (*(LnkLI19))(V195,(V193),(V194));
-	VMR34(V197)}
+	V193= vs_base[0];
+	{object V195 = (*(LnkLI42))(V193,(V191),(V192));
+	VMR34(V195)}
 }
-static object  LnkTLI19(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[19],&LnkLI19,3,ap);} /* DPB */
-static object  LnkTLI18(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[18],&LnkLI18,2,ap);} /* MASK-FIELD */
-static object  LnkTLI17(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[17],&LnkLI17,2,ap);} /* LDB */
-static object  LnkTLI16(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[16],&LnkLI16,1,ap);} /* BYTE-SIZE */
-static object  LnkTLI15(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[15],&LnkLI15,1,ap);} /* BYTE-POSITION */
-static object  LnkTLI14(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[14],&LnkLI14,2,ap);} /* LOGANDC2 */
-static object  LnkTLI13(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[13],&LnkLI13,3,ap);} /* TYPECASE-ERROR-STRING */
-static LnkT12(){ call_or_link(VV[12],&Lnk12);} /* RATIONALP */
-static object  LnkTLI11(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[11],&LnkLI11,1,ap);} /* COSH */
-static object  LnkTLI10(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[10],&LnkLI10,1,ap);} /* SINH */
-static object  LnkTLI9(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[9],&LnkLI9,1,ap);} /* ABS */
+static object  LnkTLI42(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[42],&LnkLI42,3,ap);} /* DPB */
+static object  LnkTLI41(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[41],&LnkLI41,2,ap);} /* MASK-FIELD */
+static object  LnkTLI40(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[40],&LnkLI40,2,ap);} /* LDB */
+static object  LnkTLI39(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[39],&LnkLI39,1,ap);} /* BYTE-SIZE */
+static object  LnkTLI38(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[38],&LnkLI38,1,ap);} /* BYTE-POSITION */
+static object  LnkTLI37(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[37],&LnkLI37,2,ap);} /* LOGANDC2 */
+static LnkT36(){ call_or_link(VV[36],&Lnk36);} /* NOT */
+static LnkT35(){ call_or_link(VV[35],&Lnk35);} /* ZEROP */
+static LnkT34(){ call_or_link(VV[34],&Lnk34);} /* LOGAND */
+static LnkT33(){ call_or_link(VV[33],&Lnk33);} /* LOGXOR */
+static LnkT32(){ call_or_link(VV[32],&Lnk32);} /* BOOLE3 */
+static LnkT31(){ call_or_link(VV[31],&Lnk31);} /* ROUND */
+static LnkT30(){ call_or_link(VV[30],&Lnk30);} /* TRUNCATE */
+static LnkT29(){ call_or_link(VV[29],&Lnk29);} /* FLOAT */
+static object  LnkTLI28(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[28],&LnkLI28,3,ap);} /* TYPECASE-ERROR-STRING */
+static LnkT27(){ call_or_link(VV[27],&Lnk27);} /* RATIONALP */
+static LnkT26(){ call_or_link(VV[26],&Lnk26);} /* FLOAT-RADIX */
+static LnkT25(){ call_or_link(VV[25],&Lnk25);} /* INTEGER-DECODE-FLOAT */
+static object  LnkTLI24(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[24],&LnkLI24,1,ap);} /* COSH */
+static object  LnkTLI23(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[23],&LnkLI23,1,ap);} /* SINH */
+static LnkT22(){ call_or_link(VV[22],&Lnk22);} /* LOG */
+static LnkT21(){ call_or_link(VV[21],&Lnk21);} /* EXP */
+static LnkT20(){ call_or_link(VV[20],&Lnk20);} /*  */
+static object  LnkTLI19(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[19],&LnkLI19,1,ap);} /* ABS */
+static LnkT18(){ call_or_link(VV[18],&Lnk18);} /* ATAN */
+static LnkT17(){ call_or_link(VV[17],&Lnk17);} /* SQRT */
+static LnkT16(){ call_or_link(VV[16],&Lnk16);} /* IMAGPART */
+static LnkT15(){ call_or_link(VV[15],&Lnk15);} /* REALPART */
+static LnkT14(){ call_or_link(VV[14],&Lnk14);} /* COMPLEXP */
+static LnkT13(){ call_or_link(VV[13],&Lnk13);} /* FLOOR */
+static LnkT12(){ call_or_link(VV[12],&Lnk12);} /* ASH */
+static LnkT11(){ call_or_link(VV[11],&Lnk11);} /* CEILING */
+static LnkT10(){ call_or_link(VV[10],&Lnk10);} /* INTEGER-LENGTH */
+static LnkT9(){ call_or_link(VV[9],&Lnk9);} /* ERROR */
