@@ -83,13 +83,13 @@ T1:;
 	V10= list(2,VV[6],base[2]);
 	V11= list(4,VV[5],/* INLINE-ARGS */V10,list(2,VV[9],listA(3,VV[10],base[3],base[4])),VV[11]);
 	V12= list(2,VV[6],base[2]);
-	V13= (*(LnkLI71))(base[4]);
+	V13= (*(LnkLI74))(base[4]);
 	V14= list(4,VV[5],/* INLINE-ARGS */V12,/* INLINE-ARGS */V13,VV[12]);
 	base[5]= list(6,VV[3],VV[4],/* INLINE-ARGS */V9,/* INLINE-ARGS */V11,/* INLINE-ARGS */V14,list(2,VV[6],base[2]));
 	vs_top=(vs_base=base+5)+1;
 	return;
 }
-/*	function definition for G1054	*/
+/*	function definition for G1070	*/
 
 static L2()
 {register object *base=vs_base;
@@ -102,7 +102,7 @@ TTL:;
 	vs_top=(vs_base=base+0)+1;
 	return;
 }
-/*	function definition for G1055	*/
+/*	function definition for G1071	*/
 
 static L3()
 {register object *base=vs_base;
@@ -115,7 +115,7 @@ TTL:;
 	vs_top=(vs_base=base+0)+1;
 	return;
 }
-/*	function definition for G1056	*/
+/*	function definition for G1072	*/
 
 static L4()
 {register object *base=vs_base;
@@ -131,7 +131,7 @@ TTL:;
 	return;
 	}
 }
-/*	function definition for G1057	*/
+/*	function definition for G1073	*/
 
 static L5()
 {register object *base=vs_base;
@@ -162,7 +162,7 @@ T49:;
 	return;
 	}
 }
-/*	function definition for G1058	*/
+/*	function definition for G1074	*/
 
 static L6()
 {register object *base=vs_base;
@@ -189,7 +189,7 @@ T55:;
 	return;
 	}
 }
-/*	function definition for G1059	*/
+/*	function definition for G1075	*/
 
 static L7()
 {register object *base=vs_base;
@@ -198,11 +198,11 @@ static L7()
 	check_arg(0);
 	vs_top=sup;
 TTL:;
-	base[0]= list(2,VV[20],small_fixnum(8));
+	base[0]= list(2,VV[20],symbol_value(VV[21]));
 	vs_top=(vs_base=base+0)+1;
 	return;
 }
-/*	function definition for G1060	*/
+/*	function definition for G1076	*/
 
 static L8()
 {register object *base=vs_base;
@@ -211,11 +211,11 @@ static L8()
 	check_arg(0);
 	vs_top=sup;
 TTL:;
-	base[0]= list(2,VV[21],small_fixnum(8));
+	base[0]= list(2,VV[22],symbol_value(VV[21]));
 	vs_top=(vs_base=base+0)+1;
 	return;
 }
-/*	function definition for G1061	*/
+/*	function definition for G1077	*/
 
 static L9()
 {register object *base=vs_base;
@@ -224,11 +224,11 @@ static L9()
 	check_arg(0);
 	vs_top=sup;
 TTL:;
-	base[0]= list(2,VV[20],small_fixnum(16));
+	base[0]= list(2,VV[20],symbol_value(VV[23]));
 	vs_top=(vs_base=base+0)+1;
 	return;
 }
-/*	function definition for G1062	*/
+/*	function definition for G1078	*/
 
 static L10()
 {register object *base=vs_base;
@@ -237,11 +237,11 @@ static L10()
 	check_arg(0);
 	vs_top=sup;
 TTL:;
-	base[0]= list(2,VV[21],small_fixnum(16));
+	base[0]= list(2,VV[22],symbol_value(VV[23]));
 	vs_top=(vs_base=base+0)+1;
 	return;
 }
-/*	function definition for G1063	*/
+/*	function definition for G1079	*/
 
 static L11()
 {register object *base=vs_base;
@@ -262,12 +262,12 @@ T57:;
 T58:;
 	V25= VV[17];
 T59:;
-	base[2]= list(3,VV[22],(V24),make_cons((V25),Cnil));
+	base[2]= list(3,VV[24],(V24),make_cons((V25),Cnil));
 	vs_top=(vs_base=base+2)+1;
 	return;
 	}
 }
-/*	function definition for G1064	*/
+/*	function definition for G1080	*/
 
 static L12()
 {register object *base=vs_base;
@@ -282,12 +282,12 @@ static L12()
 T62:;
 	V26= VV[17];
 T63:;
-	base[1]= list(3,VV[23],VV[24],(V26));
+	base[1]= list(3,VV[25],VV[26],(V26));
 	vs_top=(vs_base=base+1)+1;
 	return;
 	}
 }
-/*	function definition for G1065	*/
+/*	function definition for G1081	*/
 
 static L13()
 {register object *base=vs_base;
@@ -302,12 +302,12 @@ static L13()
 T65:;
 	V27= VV[17];
 T66:;
-	base[1]= list(3,VV[23],VV[25],(V27));
+	base[1]= list(3,VV[25],VV[27],(V27));
 	vs_top=(vs_base=base+1)+1;
 	return;
 	}
 }
-/*	function definition for G1066	*/
+/*	function definition for G1082	*/
 
 static L14()
 {register object *base=vs_base;
@@ -322,12 +322,12 @@ static L14()
 T68:;
 	V28= VV[17];
 T69:;
-	base[1]= list(3,VV[26],Ct,make_cons((V28),Cnil));
+	base[1]= list(3,VV[28],Ct,make_cons((V28),Cnil));
 	vs_top=(vs_base=base+1)+1;
 	return;
 	}
 }
-/*	function definition for G1067	*/
+/*	function definition for G1083	*/
 
 static L15()
 {register object *base=vs_base;
@@ -342,12 +342,12 @@ static L15()
 T71:;
 	V29= VV[17];
 T72:;
-	base[1]= list(3,VV[26],VV[24],make_cons((V29),Cnil));
+	base[1]= list(3,VV[28],VV[26],make_cons((V29),Cnil));
 	vs_top=(vs_base=base+1)+1;
 	return;
 	}
 }
-/*	function definition for G1068	*/
+/*	function definition for G1084	*/
 
 static L16()
 {register object *base=vs_base;
@@ -362,7 +362,7 @@ static L16()
 T74:;
 	V30= VV[17];
 T75:;
-	base[1]= list(3,VV[26],VV[25],make_cons((V30),Cnil));
+	base[1]= list(3,VV[28],VV[27],make_cons((V30),Cnil));
 	vs_top=(vs_base=base+1)+1;
 	return;
 	}
@@ -394,7 +394,7 @@ T77:;
 T79:;
 	base[0]= (V32);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk72)();
+	(void) (*Lnk75)();
 	vs_top=sup;
 	V36= vs_base[0];
 	if((V36)==Cnil){
@@ -439,7 +439,7 @@ T94:;
 	V43= cdr((V41));
 T92:;
 	{object V45;
-	V45= get((V42),VV[27],Cnil);
+	V45= get((V42),VV[29],Cnil);
 	if(((V45))==Cnil){
 	goto T102;}
 	base[2]= (V40);
@@ -448,7 +448,7 @@ T92:;
 	return;}
 T102:;
 	{object V46= (V42);
-	if((V46!= VV[36]))goto T107;
+	if((V46!= VV[38]))goto T107;
 	{register object x= (V40),V47= (V43);
 	while(!endp(V47))
 	if(eql(x,V47->c.c_car)){
@@ -460,18 +460,18 @@ T102:;
 	vs_top=(vs_base=base+2)+1;
 	return;}
 T107:;
-	if((V46!= VV[39]))goto T108;
+	if((V46!= VV[41]))goto T108;
 	base[2]= (V40);
 	base[3]= car((V43));
 	vs_top=(vs_base=base+2)+2;
-	(void) (*Lnk73)();
+	(void) (*Lnk76)();
 	vs_top=sup;
 	V48= vs_base[0];
 	base[2]= ((V48)==Cnil?Ct:Cnil);
 	vs_top=(vs_base=base+2)+1;
 	return;
 T108:;
-	if((V46!= VV[37]))goto T112;
+	if((V46!= VV[39]))goto T112;
 	{register object V49;
 	V49= (V43);
 T114:;
@@ -484,7 +484,7 @@ T115:;
 	base[2]= (V40);
 	base[3]= car((V49));
 	vs_top=(vs_base=base+2)+2;
-	(void) (*Lnk73)();
+	(void) (*Lnk76)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T119;}
@@ -495,7 +495,7 @@ T119:;
 	V49= cdr((V49));
 	goto T114;}
 T112:;
-	if((V46!= VV[38]))goto T127;
+	if((V46!= VV[40]))goto T127;
 	{register object V50;
 	V50= (V43);
 T129:;
@@ -508,7 +508,7 @@ T130:;
 	base[2]= (V40);
 	base[3]= car((V50));
 	vs_top=(vs_base=base+2)+2;
-	(void) (*Lnk73)();
+	(void) (*Lnk76)();
 	vs_top=sup;
 	if((vs_base[0])!=Cnil){
 	goto T134;}
@@ -519,7 +519,7 @@ T134:;
 	V50= cdr((V50));
 	goto T129;}
 T127:;
-	if((V46!= VV[74]))goto T142;
+	if((V46!= VV[77]))goto T142;
 	base[2]= car((V43));
 	base[3]= (V40);
 	vs_top=(vs_base=base+3)+1;
@@ -536,37 +536,37 @@ T145:;
 	vs_top=(vs_base=base+2)+1;
 	return;
 T146:;
-	if((V46!= VV[28]))goto T147;
+	if((V46!= VV[30]))goto T147;
 	base[2]= (V40);
 	vs_top=(vs_base=base+2)+1;
 	Ltype_of();
 	vs_top=sup;
 	V51= vs_base[0];
-	base[2]= ((V51)==(VV[28])?Ct:Cnil);
+	base[2]= ((V51)==(VV[30])?Ct:Cnil);
 	vs_top=(vs_base=base+2)+1;
 	return;
 T147:;
-	if((V46!= VV[29]))goto T150;
+	if((V46!= VV[31]))goto T150;
 	base[2]= (V40);
 	vs_top=(vs_base=base+2)+1;
 	Ltype_of();
 	vs_top=sup;
 	V52= vs_base[0];
-	base[2]= ((V52)==(VV[29])?Ct:Cnil);
+	base[2]= ((V52)==(VV[31])?Ct:Cnil);
 	vs_top=(vs_base=base+2)+1;
 	return;
 T150:;
-	if((V46!= VV[30]))goto T153;
+	if((V46!= VV[32]))goto T153;
 	base[2]= (V40);
 	vs_top=(vs_base=base+2)+1;
 	Ltype_of();
 	vs_top=sup;
 	V53= vs_base[0];
-	base[2]= ((V53)==(VV[30])?Ct:Cnil);
+	base[2]= ((V53)==(VV[32])?Ct:Cnil);
 	vs_top=(vs_base=base+2)+1;
 	return;
 T153:;
-	if((V46!= VV[75]))goto T156;
+	if((V46!= VV[78]))goto T156;
 	if(type_of((V40))==t_character){
 	goto T157;}
 	base[2]= Cnil;
@@ -578,7 +578,7 @@ T157:;
 	Lstandard_char_p();
 	return;
 T156:;
-	if((V46!= VV[24]))goto T160;
+	if((V46!= VV[26]))goto T160;
 	if(type_of((V40))==t_character){
 	goto T161;}
 	base[2]= Cnil;
@@ -597,14 +597,14 @@ T160:;
 	vs_top=(vs_base=base+2)+1;
 	return;
 T165:;
-	base[2]= (*(LnkLI76))((V40),(V43));
+	base[2]= (*(LnkLI79))((V40),(V43));
 	vs_top=(vs_base=base+2)+1;
 	return;
 T164:;
-	if((V46!= VV[59]))goto T167;
+	if((V46!= VV[61]))goto T167;
 	base[2]= (V40);
 	vs_top=(vs_base=base+2)+1;
-	(void) (*Lnk77)();
+	(void) (*Lnk80)();
 	vs_top=sup;
 	if((vs_base[0])!=Cnil){
 	goto T168;}
@@ -612,56 +612,56 @@ T164:;
 	vs_top=(vs_base=base+2)+1;
 	return;
 T168:;
-	base[2]= (*(LnkLI76))((V40),(V43));
+	base[2]= (*(LnkLI79))((V40),(V43));
 	vs_top=(vs_base=base+2)+1;
 	return;
 T167:;
-	if((V46!= VV[60]))goto T171;
+	if((V46!= VV[62]))goto T171;
 	if(type_of((V40))==t_shortfloat||type_of((V40))==t_longfloat){
 	goto T172;}
 	base[2]= Cnil;
 	vs_top=(vs_base=base+2)+1;
 	return;
 T172:;
-	base[2]= (*(LnkLI76))((V40),(V43));
+	base[2]= (*(LnkLI79))((V40),(V43));
 	vs_top=(vs_base=base+2)+1;
 	return;
 T171:;
-	if((V46!= VV[31]))goto T174;
+	if((V46!= VV[33]))goto T174;
 	base[2]= (V40);
 	vs_top=(vs_base=base+2)+1;
 	Ltype_of();
 	vs_top=sup;
 	V54= vs_base[0];
-	if((V54)==(VV[31])){
+	if((V54)==(VV[33])){
 	goto T175;}
 	base[2]= Cnil;
 	vs_top=(vs_base=base+2)+1;
 	return;
 T175:;
-	base[2]= (*(LnkLI76))((V40),(V43));
+	base[2]= (*(LnkLI79))((V40),(V43));
 	vs_top=(vs_base=base+2)+1;
 	return;
 T174:;
-	if((V46!= VV[78])
-	&& (V46!= VV[79])
-	&& (V46!= VV[32]))goto T179;
+	if((V46!= VV[81])
+	&& (V46!= VV[82])
+	&& (V46!= VV[34]))goto T179;
 	base[2]= (V40);
 	vs_top=(vs_base=base+2)+1;
 	Ltype_of();
 	vs_top=sup;
 	V55= vs_base[0];
-	if((V55)==(VV[32])){
+	if((V55)==(VV[34])){
 	goto T180;}
 	base[2]= Cnil;
 	vs_top=(vs_base=base+2)+1;
 	return;
 T180:;
-	base[2]= (*(LnkLI76))((V40),(V43));
+	base[2]= (*(LnkLI79))((V40),(V43));
 	vs_top=(vs_base=base+2)+1;
 	return;
 T179:;
-	if((V46!= VV[63]))goto T184;
+	if((V46!= VV[65]))goto T184;
 	base[2]= (V40);
 	vs_top=(vs_base=base+2)+1;
 	Lcomplexp();
@@ -685,7 +685,7 @@ T188:;
 	base[2]= vs_base[0];
 	base[3]= car((V43));
 	vs_top=(vs_base=base+2)+2;
-	(void) (*Lnk73)();
+	(void) (*Lnk76)();
 	vs_top=sup;
 	if((vs_base[0])!=Cnil){
 	goto T190;}
@@ -701,7 +701,7 @@ T190:;
 	V41= car((V43));
 	goto TTL;
 T184:;
-	if((V46!= VV[43]))goto T199;
+	if((V46!= VV[45]))goto T199;
 	if(!(type_of((V40))==t_cons||((V40))==Cnil)){
 	goto T200;}
 	base[2]= Ct;
@@ -714,7 +714,7 @@ type_of((V40))==t_bitvector?Ct:Cnil);
 	vs_top=(vs_base=base+2)+1;
 	return;
 T199:;
-	if((V46!= VV[80]))goto T202;
+	if((V46!= VV[83]))goto T202;
 	if(type_of((V40))==t_string){
 	goto T203;}
 	base[2]= Cnil;
@@ -727,12 +727,12 @@ T203:;
 	vs_top=(vs_base=base+2)+1;
 	return;
 T205:;
-	V56= (*(LnkLI82))((V40));
-	base[2]= (*(LnkLI81))(/* INLINE-ARGS */V56,(V43));
+	V56= (*(LnkLI85))((V40));
+	base[2]= (*(LnkLI84))(/* INLINE-ARGS */V56,(V43));
 	vs_top=(vs_base=base+2)+1;
 	return;
 T202:;
-	if((V46!= VV[83]))goto T207;
+	if((V46!= VV[86]))goto T207;
 	if((type_of((V40))==t_bitvector)){
 	goto T208;}
 	base[2]= Cnil;
@@ -745,12 +745,12 @@ T208:;
 	vs_top=(vs_base=base+2)+1;
 	return;
 T210:;
-	V57= (*(LnkLI82))((V40));
-	base[2]= (*(LnkLI81))(/* INLINE-ARGS */V57,(V43));
+	V57= (*(LnkLI85))((V40));
+	base[2]= (*(LnkLI84))(/* INLINE-ARGS */V57,(V43));
 	vs_top=(vs_base=base+2)+1;
 	return;
 T207:;
-	if((V46!= VV[84]))goto T212;
+	if((V46!= VV[87]))goto T212;
 	base[2]= (V40);
 	vs_top=(vs_base=base+2)+1;
 	Lsimple_string_p();
@@ -767,12 +767,12 @@ T213:;
 	vs_top=(vs_base=base+2)+1;
 	return;
 T216:;
-	V58= (*(LnkLI82))((V40));
-	base[2]= (*(LnkLI81))(/* INLINE-ARGS */V58,(V43));
+	V58= (*(LnkLI85))((V40));
+	base[2]= (*(LnkLI84))(/* INLINE-ARGS */V58,(V43));
 	vs_top=(vs_base=base+2)+1;
 	return;
 T212:;
-	if((V46!= VV[85]))goto T218;
+	if((V46!= VV[88]))goto T218;
 	base[2]= (V40);
 	vs_top=(vs_base=base+2)+1;
 	Lsimple_bit_vector_p();
@@ -789,12 +789,12 @@ T219:;
 	vs_top=(vs_base=base+2)+1;
 	return;
 T222:;
-	V59= (*(LnkLI82))((V40));
-	base[2]= (*(LnkLI81))(/* INLINE-ARGS */V59,(V43));
+	V59= (*(LnkLI85))((V40));
+	base[2]= (*(LnkLI84))(/* INLINE-ARGS */V59,(V43));
 	vs_top=(vs_base=base+2)+1;
 	return;
 T218:;
-	if((V46!= VV[86]))goto T224;
+	if((V46!= VV[89]))goto T224;
 	base[2]= (V40);
 	vs_top=(vs_base=base+2)+1;
 	Lsimple_vector_p();
@@ -811,13 +811,13 @@ T225:;
 	vs_top=(vs_base=base+2)+1;
 	return;
 T228:;
-	V60= (*(LnkLI82))((V40));
-	base[2]= (*(LnkLI81))(/* INLINE-ARGS */V60,(V43));
+	V60= (*(LnkLI85))((V40));
+	base[2]= (*(LnkLI84))(/* INLINE-ARGS */V60,(V43));
 	vs_top=(vs_base=base+2)+1;
 	return;
 T224:;
-	if((V46!= VV[26]))goto T230;
-	if(((*(LnkLI87))((V40)))!=Cnil){
+	if((V46!= VV[28]))goto T230;
+	if(((*(LnkLI90))((V40)))!=Cnil){
 	goto T231;}
 	base[2]= Cnil;
 	vs_top=(vs_base=base+2)+1;
@@ -836,7 +836,7 @@ T237:;
 	Larray_element_type();
 	vs_top=sup;
 	V61= vs_base[0];
-	V62= (*(LnkLI88))(car((V43)));
+	V62= (*(LnkLI91))(car((V43)));
 	if(equal(V61,/* INLINE-ARGS */V62)){
 	goto T233;}
 	base[2]= Cnil;
@@ -855,12 +855,12 @@ T241:;
 	vs_top=(vs_base=base+2)+1;
 	return;
 T243:;
-	V63= (*(LnkLI82))((V40));
-	base[2]= (*(LnkLI81))(/* INLINE-ARGS */V63,cadr((V43)));
+	V63= (*(LnkLI85))((V40));
+	base[2]= (*(LnkLI84))(/* INLINE-ARGS */V63,cadr((V43)));
 	vs_top=(vs_base=base+2)+1;
 	return;
 T230:;
-	if((V46!= VV[22]))goto T245;
+	if((V46!= VV[24]))goto T245;
 	if(type_of((V40))==t_array||
 type_of((V40))==t_vector||
 type_of((V40))==t_string||
@@ -883,7 +883,7 @@ T252:;
 	Larray_element_type();
 	vs_top=sup;
 	V64= vs_base[0];
-	V65= (*(LnkLI88))(car((V43)));
+	V65= (*(LnkLI91))(car((V43)));
 	if(equal(V64,/* INLINE-ARGS */V65)){
 	goto T248;}
 	base[2]= Cnil;
@@ -902,23 +902,23 @@ T256:;
 	vs_top=(vs_base=base+2)+1;
 	return;
 T258:;
-	V66= (*(LnkLI82))((V40));
-	base[2]= (*(LnkLI81))(/* INLINE-ARGS */V66,cadr((V43)));
+	V66= (*(LnkLI85))((V40));
+	base[2]= (*(LnkLI84))(/* INLINE-ARGS */V66,cadr((V43)));
 	vs_top=(vs_base=base+2)+1;
 	return;
 T245:;
-	V44= get((V42),VV[33],Cnil);
+	V44= get((V42),VV[35],Cnil);
 	if(((V44))==Cnil){
 	goto T261;}
 	base[2]= (V40);
 	base[3]= (V44);
 	vs_top=(vs_base=base+2)+2;
-	(void) (*Lnk89)();
+	(void) (*Lnk92)();
 	return;
 T261:;
-	if((get((V42),VV[34],Cnil))==Cnil){
+	if((get((V42),VV[36],Cnil))==Cnil){
 	goto T267;}
-	base[2]= get((V42),VV[34],Cnil);
+	base[2]= get((V42),VV[36],Cnil);
 	{object V67;
 	V67= (V43);
 	 vs_top=base+3;
@@ -956,9 +956,9 @@ T281:;
 	V70= car((V69));
 	V71= cdr((V69));
 T279:;
-	if((get((V70),VV[34],Cnil))==Cnil){
+	if((get((V70),VV[36],Cnil))==Cnil){
 	goto T290;}
-	base[0]= get((V70),VV[34],Cnil);
+	base[0]= get((V70),VV[36],Cnil);
 	{object V72;
 	V72= (V71);
 	 vs_top=base+1;
@@ -991,12 +991,12 @@ TTL:;
 	goto T299;}
 	V76= car((V76));
 T299:;
-	{register object x= (V76),V77= VV[35];
+	{register object x= (V76),V77= VV[37];
 	while(!endp(V77))
 	if(eql(x,V77->c.c_car)){
 	goto T303;
 	}else V77=V77->c.c_cdr;}
-	if((get((V76),VV[33],Cnil))==Cnil){
+	if((get((V76),VV[35],Cnil))==Cnil){
 	goto T304;}
 T303:;
 	{object V78 = Ct;
@@ -1032,8 +1032,8 @@ TTL:;
 	V86= Cnil;
 	V87= Cnil;
 	V88= Cnil;
-	V80= (*(LnkLI90))((V80));
-	V81= (*(LnkLI90))((V81));
+	V80= (*(LnkLI93))((V80));
+	V81= (*(LnkLI93))((V81));
 	if(!(equal((V80),(V81)))){
 	goto T319;}
 	base[2]= Ct;
@@ -1045,7 +1045,7 @@ T319:;
 	V83= car((V81));
 	V84= cdr((V80));
 	V85= cdr((V81));
-	if(!(((V82))==(VV[36]))){
+	if(!(((V82))==(VV[38]))){
 	goto T334;}
 	{register object V89;
 	object V90;
@@ -1059,7 +1059,7 @@ T341:;
 	base[3]= (V90);
 	base[4]= (V81);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk73)();
+	(void) (*Lnk76)();
 	vs_top=sup;
 	if((vs_base[0])!=Cnil){
 	goto T345;}
@@ -1077,7 +1077,7 @@ T336:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T334:;
-	if(!(((V82))==(VV[37]))){
+	if(!(((V82))==(VV[39]))){
 	goto T360;}
 	{register object V91;
 	object V92;
@@ -1093,7 +1093,7 @@ T367:;
 	base[3]= (V92);
 	base[4]= (V81);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk91)();
+	(void) (*Lnk94)();
 	if(vs_base>=vs_top){vs_top=sup;goto T375;}
 	V93= vs_base[0];
 	vs_base++;
@@ -1122,7 +1122,7 @@ T362:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T360:;
-	if(!(((V82))==(VV[38]))){
+	if(!(((V82))==(VV[40]))){
 	goto T390;}
 	{register object V95;
 	object V96;
@@ -1137,7 +1137,7 @@ T397:;
 	base[3]= (V96);
 	base[4]= (V81);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk91)();
+	(void) (*Lnk94)();
 	vs_top=sup;
 	V97= vs_base[0];
 	if(((V97))==Cnil){
@@ -1156,26 +1156,26 @@ T392:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T390:;
-	if(!(((V82))==(VV[39]))){
+	if(!(((V82))==(VV[41]))){
 	goto T332;}
-	if(!(((V83))==(VV[39]))){
+	if(!(((V83))==(VV[41]))){
 	goto T419;}
 	V80= car((V85));
 	V81= car((V84));
 	goto TTL;
 T419:;
 	V80= Ct;
-	V81= list(3,VV[37],(V81),car((V84)));
+	V81= list(3,VV[39],(V81),car((V84)));
 	goto TTL;
 T332:;
-	if(!(((V83))==(VV[36]))){
+	if(!(((V83))==(VV[38]))){
 	goto T429;}
 	base[2]= Cnil;
 	base[3]= Cnil;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T429:;
-	if(!(((V83))==(VV[37]))){
+	if(!(((V83))==(VV[39]))){
 	goto T434;}
 	{register object V98;
 	object V99;
@@ -1190,7 +1190,7 @@ T441:;
 	base[3]= (V80);
 	base[4]= (V99);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk91)();
+	(void) (*Lnk94)();
 	vs_top=sup;
 	V100= vs_base[0];
 	if(((V100))==Cnil){
@@ -1209,7 +1209,7 @@ T436:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T434:;
-	if(!(((V83))==(VV[38]))){
+	if(!(((V83))==(VV[40]))){
 	goto T461;}
 	{register object V101;
 	object V102;
@@ -1225,7 +1225,7 @@ T468:;
 	base[3]= (V80);
 	base[4]= (V102);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk91)();
+	(void) (*Lnk94)();
 	if(vs_base>=vs_top){vs_top=sup;goto T476;}
 	V103= vs_base[0];
 	vs_base++;
@@ -1254,19 +1254,19 @@ T463:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T461:;
-	if(!(((V83))==(VV[39]))){
+	if(!(((V83))==(VV[41]))){
 	goto T427;}
-	V80= list(3,VV[38],(V80),car((V85)));
+	V80= list(3,VV[40],(V80),car((V85)));
 	V81= Cnil;
 	goto TTL;
 T427:;
-	V86= (*(LnkLI92))((V80));
-	V87= (*(LnkLI92))((V81));
+	V86= (*(LnkLI95))((V80));
+	V87= (*(LnkLI95))((V81));
 	if(((V82))==(Cnil)){
 	goto T499;}
 	if(((V83))==(Ct)){
 	goto T499;}
-	if(!(((V83))==(VV[40]))){
+	if(!(((V83))==(VV[42]))){
 	goto T500;}
 T499:;
 	base[2]= Ct;
@@ -1288,16 +1288,16 @@ T509:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T514:;
-	if(!(((V82))==(VV[40]))){
+	if(!(((V82))==(VV[42]))){
 	goto T519;}
 	base[2]= Cnil;
 	base[3]= (V87);
 	vs_top=(vs_base=base+2)+2;
 	return;
 T519:;
-	if(!(((V83))==(VV[41]))){
+	if(!(((V83))==(VV[43]))){
 	goto T524;}
-	{register object x= (V82),V105= VV[42];
+	{register object x= (V82),V105= VV[44];
 	while(!endp(V105))
 	if(eql(x,V105->c.c_car)){
 	goto T528;
@@ -1314,9 +1314,9 @@ T527:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T524:;
-	if(!(((V83))==(VV[43]))){
+	if(!(((V83))==(VV[45]))){
 	goto T534;}
-	{register object x= (V82),V106= VV[44];
+	{register object x= (V82),V106= VV[46];
 	while(!endp(V106))
 	if(eql(x,V106->c.c_car)){
 	goto T538;
@@ -1328,7 +1328,7 @@ T538:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T537:;
-	if(!(((V82))==(VV[22]))){
+	if(!(((V82))==(VV[24]))){
 	goto T542;}
 	if((cdr((V84)))==Cnil){
 	goto T545;}
@@ -1351,23 +1351,23 @@ T542:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T534:;
-	if(!(((V82))==(VV[41]))){
+	if(!(((V82))==(VV[43]))){
 	goto T558;}
 	base[2]= Cnil;
 	base[3]= (V87);
 	vs_top=(vs_base=base+2)+2;
 	return;
 T558:;
-	if(!(((V82))==(VV[43]))){
+	if(!(((V82))==(VV[45]))){
 	goto T563;}
 	base[2]= Cnil;
 	base[3]= (V87);
 	vs_top=(vs_base=base+2)+2;
 	return;
 T563:;
-	if(!(((V83))==(VV[45]))){
+	if(!(((V83))==(VV[47]))){
 	goto T568;}
-	{register object x= (V82),V107= VV[46];
+	{register object x= (V82),V107= VV[48];
 	while(!endp(V107))
 	if(eql(x,V107->c.c_car)){
 	goto T572;
@@ -1391,16 +1391,16 @@ T576:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T568:;
-	if(!(((V82))==(VV[45]))){
+	if(!(((V82))==(VV[47]))){
 	goto T583;}
 	base[2]= Cnil;
 	base[3]= (V87);
 	vs_top=(vs_base=base+2)+2;
 	return;
 T583:;
-	if(!(((V83))==(VV[47]))){
+	if(!(((V83))==(VV[49]))){
 	goto T588;}
-	{register object x= (V82),V108= VV[48];
+	{register object x= (V82),V108= VV[50];
 	while(!endp(V108))
 	if(eql(x,V108->c.c_car)){
 	goto T592;
@@ -1417,9 +1417,9 @@ T591:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T588:;
-	if(!(((V83))==(VV[49]))){
+	if(!(((V83))==(VV[51]))){
 	goto T598;}
-	if(!(((V82))==(VV[49]))){
+	if(!(((V82))==(VV[51]))){
 	goto T601;}
 	base[2]= Ct;
 	base[3]= Ct;
@@ -1431,9 +1431,9 @@ T601:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T598:;
-	if(!(((V83))==(VV[50]))){
+	if(!(((V83))==(VV[52]))){
 	goto T608;}
-	if(!(((V82))==(VV[50]))){
+	if(!(((V82))==(VV[52]))){
 	goto T611;}
 	base[2]= Ct;
 	base[3]= Ct;
@@ -1445,9 +1445,9 @@ T611:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T608:;
-	if(!(((V83))==(VV[51]))){
+	if(!(((V83))==(VV[53]))){
 	goto T618;}
-	{register object x= (V82),V109= VV[52];
+	{register object x= (V82),V109= VV[54];
 	while(!endp(V109))
 	if(eql(x,V109->c.c_car)){
 	goto T622;
@@ -1464,18 +1464,18 @@ T621:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T618:;
-	if(!(((V82))==(VV[51]))){
+	if(!(((V82))==(VV[53]))){
 	goto T628;}
 	base[2]= Cnil;
 	base[3]= (V87);
 	vs_top=(vs_base=base+2)+2;
 	return;
 T628:;
-	if(!(((V83))==(VV[53]))){
+	if(!(((V83))==(VV[55]))){
 	goto T633;}
-	if(((V82))==(VV[53])){
+	if(((V82))==(VV[55])){
 	goto T635;}
-	if((get((V82),VV[33],Cnil))==Cnil){
+	if((get((V82),VV[35],Cnil))==Cnil){
 	goto T636;}
 T635:;
 	base[2]= Ct;
@@ -1488,18 +1488,18 @@ T636:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T633:;
-	if(!(((V82))==(VV[53]))){
+	if(!(((V82))==(VV[55]))){
 	goto T645;}
 	base[2]= Cnil;
 	base[3]= (V87);
 	vs_top=(vs_base=base+2)+2;
 	return;
 T645:;
-	V88= get((V82),VV[33],Cnil);
+	V88= get((V82),VV[35],Cnil);
 	if(((V88))==Cnil){
 	goto T650;}
 	{object V110;
-	V110= get((V83),VV[33],Cnil);
+	V110= get((V83),VV[35],Cnil);
 	if(((V110))==Cnil){
 	goto T655;}
 	{register object V111;
@@ -1519,7 +1519,7 @@ T659:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T665:;
-	V111= structure_ref((V111),VV[33],4);
+	V111= structure_ref((V111),VV[35],4);
 	goto T658;}
 T655:;
 	base[2]= Cnil;
@@ -1527,7 +1527,7 @@ T655:;
 	vs_top=(vs_base=base+2)+2;
 	return;}
 T650:;
-	if((get((V83),VV[33],Cnil))==Cnil){
+	if((get((V83),VV[35],Cnil))==Cnil){
 	goto T676;}
 	base[2]= Cnil;
 	base[3]= (V86);
@@ -1535,17 +1535,17 @@ T650:;
 	return;
 T676:;
 	{object V113= (V82);
-	if((V113!= VV[29]))goto T680;
+	if((V113!= VV[31]))goto T680;
 	{object V114= (V83);
-	if((V114!= VV[29]))goto T681;
+	if((V114!= VV[31]))goto T681;
 	base[2]= Ct;
 	base[3]= Ct;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T681:;
 	if((V114!= VV[13])
-	&& (V114!= VV[59]))goto T684;
-	if(((*(LnkLI93))(VV[54],(V85)))==Cnil){
+	&& (V114!= VV[61]))goto T684;
+	if(((*(LnkLI96))(VV[56],(V85)))==Cnil){
 	goto T686;}
 	base[2]= Ct;
 	base[3]= Ct;
@@ -1562,16 +1562,16 @@ T684:;
 	vs_top=(vs_base=base+2)+2;
 	return;}
 T680:;
-	if((V113!= VV[30]))goto T694;
+	if((V113!= VV[32]))goto T694;
 	{object V115= (V83);
-	if((V115!= VV[30]))goto T695;
+	if((V115!= VV[32]))goto T695;
 	base[2]= Ct;
 	base[3]= Ct;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T695:;
-	if((V115!= VV[59]))goto T698;
-	if(((*(LnkLI93))(VV[55],(V85)))==Cnil){
+	if((V115!= VV[61]))goto T698;
+	if(((*(LnkLI96))(VV[57],(V85)))==Cnil){
 	goto T700;}
 	base[2]= Ct;
 	base[3]= Ct;
@@ -1588,8 +1588,8 @@ T698:;
 	vs_top=(vs_base=base+2)+2;
 	return;}
 T694:;
-	if((V113!= VV[75]))goto T708;
-	{register object x= (V83),V116= VV[56];
+	if((V113!= VV[78]))goto T708;
+	{register object x= (V83),V116= VV[58];
 	while(!endp(V116))
 	if(eql(x,V116->c.c_car)){
 	goto T711;
@@ -1606,8 +1606,8 @@ T710:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T708:;
-	if((V113!= VV[24]))goto T716;
-	{register object x= (V83),V117= VV[57];
+	if((V113!= VV[26]))goto T716;
+	{register object x= (V83),V117= VV[59];
 	while(!endp(V117))
 	if(eql(x,V117->c.c_car)){
 	goto T719;
@@ -1625,14 +1625,14 @@ T718:;
 	return;
 T716:;
 	if((V113!= VV[13]))goto T724;
-	{register object x= (V83),V118= VV[58];
+	{register object x= (V83),V118= VV[60];
 	while(!endp(V118))
 	if(eql(x,V118->c.c_car)){
 	goto T727;
 	}else V118=V118->c.c_cdr;
 	goto T726;}
 T727:;
-	base[2]= (*(LnkLI93))((V84),(V85));
+	base[2]= (*(LnkLI96))((V84),(V85));
 	base[3]= Ct;
 	vs_top=(vs_base=base+2)+2;
 	return;
@@ -1642,10 +1642,10 @@ T726:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T724:;
-	if((V113!= VV[59]))goto T732;
-	if(!(((V83))==(VV[59]))){
+	if((V113!= VV[61]))goto T732;
+	if(!(((V83))==(VV[61]))){
 	goto T734;}
-	base[2]= (*(LnkLI93))((V84),(V85));
+	base[2]= (*(LnkLI96))((V84),(V85));
 	base[3]= Ct;
 	vs_top=(vs_base=base+2)+2;
 	return;
@@ -1655,10 +1655,10 @@ T734:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T732:;
-	if((V113!= VV[60]))goto T740;
-	if(!(((V83))==(VV[60]))){
+	if((V113!= VV[62]))goto T740;
+	if(!(((V83))==(VV[62]))){
 	goto T742;}
-	base[2]= (*(LnkLI93))((V84),(V85));
+	base[2]= (*(LnkLI96))((V84),(V85));
 	base[3]= Ct;
 	vs_top=(vs_base=base+2)+2;
 	return;
@@ -1668,15 +1668,15 @@ T742:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T740:;
-	if((V113!= VV[31]))goto T748;
-	{register object x= (V83),V119= VV[61];
+	if((V113!= VV[33]))goto T748;
+	{register object x= (V83),V119= VV[63];
 	while(!endp(V119))
 	if(eql(x,V119->c.c_car)){
 	goto T751;
 	}else V119=V119->c.c_cdr;
 	goto T750;}
 T751:;
-	base[2]= (*(LnkLI93))((V84),(V85));
+	base[2]= (*(LnkLI96))((V84),(V85));
 	base[3]= Ct;
 	vs_top=(vs_base=base+2)+2;
 	return;
@@ -1686,17 +1686,17 @@ T750:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T748:;
-	if((V113!= VV[78])
-	&& (V113!= VV[79])
-	&& (V113!= VV[32]))goto T756;
-	{register object x= (V83),V120= VV[62];
+	if((V113!= VV[81])
+	&& (V113!= VV[82])
+	&& (V113!= VV[34]))goto T756;
+	{register object x= (V83),V120= VV[64];
 	while(!endp(V120))
 	if(eql(x,V120->c.c_car)){
 	goto T759;
 	}else V120=V120->c.c_cdr;
 	goto T758;}
 T759:;
-	base[2]= (*(LnkLI93))((V84),(V85));
+	base[2]= (*(LnkLI96))((V84),(V85));
 	base[3]= Ct;
 	vs_top=(vs_base=base+2)+2;
 	return;
@@ -1706,8 +1706,8 @@ T758:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T756:;
-	if((V113!= VV[63]))goto T764;
-	if(!(((V83))==(VV[63]))){
+	if((V113!= VV[65]))goto T764;
+	if(!(((V83))==(VV[65]))){
 	goto T766;}{object V121;
 	V121= car((V84));
 	if(V121==Cnil)goto T770;
@@ -1730,10 +1730,10 @@ T766:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T764:;
-	if((V113!= VV[26]))goto T777;
-	if(((V83))==(VV[26])){
+	if((V113!= VV[28]))goto T777;
+	if(((V83))==(VV[28])){
 	goto T778;}
-	if(!(((V83))==(VV[22]))){
+	if(!(((V83))==(VV[24]))){
 	goto T779;}
 T778:;
 	if(endp((V84))){
@@ -1791,7 +1791,7 @@ T818:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T817:;
-	base[2]= (*(LnkLI81))(cadr((V84)),cadr((V85)));
+	base[2]= (*(LnkLI84))(cadr((V84)),cadr((V85)));
 	base[3]= Ct;
 	vs_top=(vs_base=base+2)+2;
 	return;
@@ -1801,8 +1801,8 @@ T779:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T777:;
-	if((V113!= VV[22]))goto T828;
-	if(!(((V83))==(VV[22]))){
+	if((V113!= VV[24]))goto T828;
+	if(!(((V83))==(VV[24]))){
 	goto T830;}
 	if(endp((V84))){
 	goto T833;}
@@ -1859,7 +1859,7 @@ T867:;
 	vs_top=(vs_base=base+2)+2;
 	return;
 T866:;
-	base[2]= (*(LnkLI81))(cadr((V84)),cadr((V85)));
+	base[2]= (*(LnkLI84))(cadr((V84)),cadr((V85)));
 	base[3]= Ct;
 	vs_top=(vs_base=base+2)+2;
 	return;
@@ -2136,16 +2136,16 @@ TTL:;
 	base[0]= (V169);
 	base[1]= (V170);
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk73)();
+	(void) (*Lnk76)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T1038;}
 	{object V171 = (V169);
 	VMR25(V171)}
 T1038:;
-	V170= (*(LnkLI90))((V170));
+	V170= (*(LnkLI93))((V170));
 	{object V172= car((V170));
-	if((V172!= VV[41]))goto T1045;
+	if((V172!= VV[43]))goto T1045;
 	{register object V173;
 	register object V174;
 	V175 = make_fixnum(length((V169)));
@@ -2162,8 +2162,8 @@ T1049:;
 	V174= one_minus((V174));
 	goto T1048;}
 T1045:;
-	if((V172!= VV[22])
-	&& (V172!= VV[26]))goto T1057;
+	if((V172!= VV[24])
+	&& (V172!= VV[28]))goto T1057;
 	if(endp(cdr((V170)))){
 	goto T1058;}
 	if(endp(cddr((V170)))){
@@ -2172,7 +2172,7 @@ T1045:;
 	goto T1058;}
 	if(endp(cdr(caddr((V170))))){
 	goto T1058;}
-	base[0]= VV[64];
+	base[0]= VV[66];
 	vs_top=(vs_base=base+0)+1;
 	Lerror();
 	vs_top=sup;
@@ -2181,7 +2181,7 @@ T1058:;
 	register object V179;
 	register object V180;
 	V181 = make_fixnum(length((V169)));
-	V178= (VFUN_NARGS=2,(*(LnkLI94))((V170),V181));
+	V178= (VFUN_NARGS=2,(*(LnkLI97))((V170),V181));
 	V180= make_fixnum(length((V169)));
 	V179= small_fixnum(0);
 T1071:;
@@ -2195,7 +2195,7 @@ T1072:;
 	V179= one_plus((V179));
 	goto T1071;}
 T1057:;
-	if((V172!= VV[95]))goto T1080;
+	if((V172!= VV[98]))goto T1080;
 	base[0]= (V169);
 	vs_top=(vs_base=base+0)+1;
 	Lcharacter();
@@ -2203,7 +2203,7 @@ T1057:;
 	{object V184 = vs_base[0];
 	VMR25(V184)}
 T1080:;
-	if((V172!= VV[60]))goto T1082;
+	if((V172!= VV[62]))goto T1082;
 	base[0]= (V169);
 	vs_top=(vs_base=base+0)+1;
 	Lfloat();
@@ -2211,27 +2211,27 @@ T1080:;
 	{object V185 = vs_base[0];
 	VMR25(V185)}
 T1082:;
-	if((V172!= VV[31]))goto T1084;
+	if((V172!= VV[33]))goto T1084;
 	base[0]= (V169);
-	base[1]= VV[65];
+	base[1]= VV[67];
 	vs_top=(vs_base=base+0)+2;
 	Lfloat();
 	vs_top=sup;
 	{object V186 = vs_base[0];
 	VMR25(V186)}
 T1084:;
-	if((V172!= VV[78])
-	&& (V172!= VV[79])
-	&& (V172!= VV[32]))goto T1087;
+	if((V172!= VV[81])
+	&& (V172!= VV[82])
+	&& (V172!= VV[34]))goto T1087;
 	base[0]= (V169);
-	base[1]= VV[66];
+	base[1]= VV[68];
 	vs_top=(vs_base=base+0)+2;
 	Lfloat();
 	vs_top=sup;
 	{object V187 = vs_base[0];
 	VMR25(V187)}
 T1087:;
-	if((V172!= VV[63]))goto T1090;
+	if((V172!= VV[65]))goto T1090;
 	if((cdr((V170)))==Cnil){
 	goto T1091;}
 	if((cadr((V170)))==Cnil){
@@ -2260,20 +2260,20 @@ T1092:;
 	Lrealpart();
 	vs_top=sup;
 	V189= vs_base[0];
-	base[0]= (*(LnkLI96))(V189,cadr((V170)));
+	base[0]= (*(LnkLI99))(V189,cadr((V170)));
 	base[2]= (V169);
 	vs_top=(vs_base=base+2)+1;
 	Limagpart();
 	vs_top=sup;
 	V190= vs_base[0];
-	base[1]= (*(LnkLI96))(V190,cadr((V170)));
+	base[1]= (*(LnkLI99))(V190,cadr((V170)));
 	vs_top=(vs_base=base+0)+2;
 	Lcomplex();
 	vs_top=sup;
 	{object V191 = vs_base[0];
 	VMR25(V191)}
 T1090:;
-	base[0]= VV[67];
+	base[0]= VV[69];
 	base[1]= (V169);
 	base[2]= (V170);
 	vs_top=(vs_base=base+0)+3;
@@ -2289,45 +2289,58 @@ static L26()
 	register object *sup=base+VM26; VC26
 	vs_reserve(VM26);
 	{object V193;
-	check_arg(1);
+	object V194;
+	if(vs_top-vs_base<1) too_few_arguments();
+	if(vs_top-vs_base>2) too_many_arguments();
 	V193=(base[0]);
+	vs_base=vs_base+1;
+	if(vs_base>=vs_top){vs_top=sup;goto T1111;}
+	V194=(base[1]);
 	vs_top=sup;
-TTL:;
-	if(symbol_value(VV[68])==Cnil){
-	base[1]= Cnil;
-	vs_top=(vs_base=base+1)+1;
-	return;}
-	if(((eql((V193),symbol_value(VV[68]))?Ct:Cnil))==Cnil){
-	goto T1111;}
-	base[1]= Cnil;
-	vs_top=(vs_base=base+1)+1;
-	return;
+	goto T1112;
 T1111:;
-	if(symbol_value(VV[69])==Cnil){
-	base[1]= Cnil;
-	vs_top=(vs_base=base+1)+1;
+	V194= Cnil;
+T1112:;
+	if(symbol_value(VV[70])==Cnil){
+	base[2]= Cnil;
+	vs_top=(vs_base=base+2)+1;
 	return;}
-	base[1]= Ct;
-	base[2]= VV[70];
-	base[3]= (V193);
-	vs_top=(vs_base=base+1)+3;
+	if(!(((eql((V193),symbol_value(VV[70]))?Ct:Cnil))==Cnil)){
+	goto T1116;}
+	goto T1114;
+T1116:;
+	if(((eql((V194),symbol_value(VV[71]))?Ct:Cnil))==Cnil){
+	goto T1114;}
+	base[2]= Cnil;
+	vs_top=(vs_base=base+2)+1;
+	return;
+T1114:;
+	if(symbol_value(VV[72])==Cnil){
+	base[2]= Cnil;
+	vs_top=(vs_base=base+2)+1;
+	return;}
+	base[2]= Ct;
+	base[3]= VV[73];
+	base[4]= (V194);
+	base[5]= (V193);
+	vs_top=(vs_base=base+2)+4;
 	Lformat();
 	return;
 	}
 }
-static object  LnkTLI96(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[96],&LnkLI96,2,ap);} /* COERCE */
-static object  LnkTLI94(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[94],&LnkLI94,ap);} /* MAKE-SEQUENCE */
-static object  LnkTLI93(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[93],&LnkLI93,2,ap);} /* SUB-INTERVAL-P */
-static object  LnkTLI92(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[92],&LnkLI92,1,ap);} /* KNOWN-TYPE-P */
-static LnkT91(){ call_or_link(VV[91],&Lnk91);} /* SUBTYPEP */
-static object  LnkTLI90(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[90],&LnkLI90,1,ap);} /* NORMALIZE-TYPE */
-static LnkT89(){ call_or_link(VV[89],&Lnk89);} /* STRUCTURE-SUBTYPE-P */
-static object  LnkTLI88(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[88],&LnkLI88,1,ap);} /* BEST-ARRAY-ELEMENT-TYPE */
-static object  LnkTLI87(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[87],&LnkLI87,1,ap);} /* SIMPLE-ARRAY-P */
-static object  LnkTLI82(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[82],&LnkLI82,1,ap);} /* ARRAY-DIMENSIONS */
-static object  LnkTLI81(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[81],&LnkLI81,2,ap);} /* MATCH-DIMENSIONS */
-static LnkT77(){ call_or_link(VV[77],&Lnk77);} /* RATIONALP */
-static object  LnkTLI76(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[76],&LnkLI76,2,ap);} /* IN-INTERVAL-P */
-static LnkT73(){ call_or_link(VV[73],&Lnk73);} /* TYPEP */
-static LnkT72(){ call_or_link(VV[72],&Lnk72);} /* ARRAY-HAS-FILL-POINTER-P */
-static object  LnkTLI71(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[71],&LnkLI71,1,ap);} /* FIND-DOCUMENTATION */
+static object  LnkTLI99(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[99],&LnkLI99,2,ap);} /* COERCE */
+static object  LnkTLI97(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[97],&LnkLI97,ap);} /* MAKE-SEQUENCE */
+static object  LnkTLI96(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[96],&LnkLI96,2,ap);} /* SUB-INTERVAL-P */
+static object  LnkTLI95(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[95],&LnkLI95,1,ap);} /* KNOWN-TYPE-P */
+static LnkT94(){ call_or_link(VV[94],&Lnk94);} /* SUBTYPEP */
+static object  LnkTLI93(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[93],&LnkLI93,1,ap);} /* NORMALIZE-TYPE */
+static LnkT92(){ call_or_link(VV[92],&Lnk92);} /* STRUCTURE-SUBTYPE-P */
+static object  LnkTLI91(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[91],&LnkLI91,1,ap);} /* BEST-ARRAY-ELEMENT-TYPE */
+static object  LnkTLI90(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[90],&LnkLI90,1,ap);} /* SIMPLE-ARRAY-P */
+static object  LnkTLI85(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[85],&LnkLI85,1,ap);} /* ARRAY-DIMENSIONS */
+static object  LnkTLI84(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[84],&LnkLI84,2,ap);} /* MATCH-DIMENSIONS */
+static LnkT80(){ call_or_link(VV[80],&Lnk80);} /* RATIONALP */
+static object  LnkTLI79(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[79],&LnkLI79,2,ap);} /* IN-INTERVAL-P */
+static LnkT76(){ call_or_link(VV[76],&Lnk76);} /* TYPEP */
+static LnkT75(){ call_or_link(VV[75],&Lnk75);} /* ARRAY-HAS-FILL-POINTER-P */
+static object  LnkTLI74(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[74],&LnkLI74,1,ap);} /* FIND-DOCUMENTATION */
