@@ -21,7 +21,7 @@ static L1()
 	goto T1;}
 	base[4]= car(base[3]);
 	vs_top=(vs_base=base+4)+1;
-	Lfunctionp();
+	(void) (*Lnk93)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T2;}
@@ -37,14 +37,14 @@ T1:;
 	goto T13;}
 	base[4]= VV[8];
 	vs_top=(vs_base=base+4)+1;
-	Lerror();
+	(void) (*Lnk94)();
 	vs_top=sup;
 T13:;
 	if(endp(cddr(base[3]))){
 	goto T17;}
 	base[4]= VV[9];
 	vs_top=(vs_base=base+4)+1;
-	Lerror();
+	(void) (*Lnk94)();
 	vs_top=sup;
 T17:;
 	V7= cadr(base[3]);
@@ -59,14 +59,14 @@ T9:;
 T2:;
 	base[4]= cadr(base[3]);
 	vs_top=(vs_base=base+4)+1;
-	Llist_length();
+	(void) (*Lnk95)();
 	vs_top=sup;
 	V9= vs_base[0];
 	if(number_compare(V9,small_fixnum(1))==0){
 	goto T21;}
 	base[4]= VV[11];
 	vs_top=(vs_base=base+4)+1;
-	Lerror();
+	(void) (*Lnk94)();
 	vs_top=sup;
 T21:;
 	V10= list(2,VV[3],base[2]);
@@ -74,7 +74,7 @@ T21:;
 	V12= list(3,VV[5],list(2,VV[3],base[2]),VV[14]);
 	V13= list(3,VV[5],list(2,VV[3],base[2]),VV[15]);
 	V14= list(2,VV[3],base[2]);
-	V15= (*(LnkLI93))(cddr(base[3]));
+	V15= (*(LnkLI96))(cddr(base[3]));
 	V16= list(4,VV[2],/* INLINE-ARGS */V14,/* INLINE-ARGS */V15,VV[16]);
 	base[4]= list(7,VV[0],VV[12],/* INLINE-ARGS */V11,/* INLINE-ARGS */V12,/* INLINE-ARGS */V13,/* INLINE-ARGS */V16,list(2,VV[3],base[2]));
 	vs_top=(vs_base=base+4)+1;
@@ -98,7 +98,7 @@ static L2()
 	base[6]= Cnil;}
 	base[7]= car(base[3]);
 	vs_top=(vs_base=base+7)+1;
-	(void) (*Lnk94)();
+	(void) (*Lnk97)();
 	if(vs_base<vs_top){
 	base[4]= vs_base[0];
 	vs_base++;
@@ -116,7 +116,7 @@ static L2()
 	goto T35;
 T37:;
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	V18= vs_base[0];
 	base[4]= make_cons(V18,base[4]);
@@ -128,7 +128,7 @@ T35:;
 	V22= list(3,VV[5],list(2,VV[3],base[2]),VV[23]);
 	V23= list(3,VV[5],list(2,VV[3],base[2]),VV[24]);
 	V24= list(2,VV[3],base[2]);
-	V25= (*(LnkLI93))(cdr(base[3]));
+	V25= (*(LnkLI96))(cdr(base[3]));
 	V26= list(4,VV[2],/* INLINE-ARGS */V24,/* INLINE-ARGS */V25,VV[25]);
 	base[7]= list(7,VV[0],VV[19],/* INLINE-ARGS */V21,/* INLINE-ARGS */V22,/* INLINE-ARGS */V23,/* INLINE-ARGS */V26,list(2,VV[3],base[2]));
 	vs_top=(vs_base=base+7)+1;
@@ -161,7 +161,7 @@ T45:;
 	base[2]= (V27);
 	base[3]= (V28);
 	vs_top=(vs_base=base+2)+2;
-	(void) (*Lnk95)();
+	(void) (*Lnk99)();
 	if(vs_base>=vs_top){vs_top=sup;goto T50;}
 	V29= vs_base[0];
 	vs_base++;
@@ -191,14 +191,14 @@ T54:;
 T55:;
 	base[2]= (V31);
 	vs_top=(vs_base=base+2)+1;
-	Llist_length();
+	(void) (*Lnk95)();
 	vs_top=sup;
 	V34= vs_base[0];
 	if(number_compare(V34,small_fixnum(1))==0){
 	goto T56;}
 	base[2]= VV[26];
 	vs_top=(vs_base=base+2)+1;
-	Lerror();
+	(void) (*Lnk94)();
 	vs_top=sup;
 T56:;
 	base[2]= (V29);
@@ -235,7 +235,7 @@ T68:;
 	goto T72;}
 	{object V38;
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	V38= vs_base[0];
 	base[2]= Cnil;
@@ -254,7 +254,7 @@ T80:;
 	base[2]= VV[28];
 	base[3]= (V35);
 	vs_top=(vs_base=base+2)+2;
-	Lerror();
+	(void) (*Lnk94)();
 	return;
 T81:;
 	if(((V36))==Cnil){
@@ -272,7 +272,7 @@ T92:;
 	base[2]= (V35);
 	base[3]= (V36);
 	vs_top=(vs_base=base+2)+2;
-	Lmacroexpand();
+	(void) (*Lnk100)();
 	vs_top=sup;
 	V37= vs_base[0];
 	if(!(((V35))==((V37)))){
@@ -280,13 +280,13 @@ T92:;
 	base[2]= VV[29];
 	base[3]= (V35);
 	vs_top=(vs_base=base+2)+2;
-	Lerror();
+	(void) (*Lnk94)();
 	vs_top=sup;
 T97:;
 	base[2]= (V37);
 	base[3]= (V36);
 	vs_top=(vs_base=base+2)+2;
-	(void) (*Lnk95)();
+	(void) (*Lnk99)();
 	return;
 T88:;
 	if((get(car((V35)),VV[30],Cnil))==Cnil){
@@ -318,7 +318,7 @@ T110:;
 	base[2]=V43=MMcons(Cnil,Cnil);
 T117:;
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	(V43->c.c_car)= vs_base[0];
 	if(endp(V44=MMcdr(V44))){
@@ -328,7 +328,7 @@ T117:;
 	goto T117;}
 T116:;
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	V42= vs_base[0];
 	base[2]= (V41);
@@ -336,7 +336,7 @@ T116:;
 	base[4]= make_cons((V42),Cnil);
 	if(((V37))==Cnil){
 	goto T125;}
-	base[5]= (*(LnkLI96))(car((V41)),car((V37)),cdr((V37)),(V42));
+	base[5]= (*(LnkLI101))(car((V41)),car((V37)),cdr((V37)),(V42));
 	goto T123;
 T125:;
 	V46= get(car((V35)),VV[31],Cnil);
@@ -362,7 +362,7 @@ T111:;
 	base[6]=V53=MMcons(Cnil,Cnil);
 T133:;
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	(V53->c.c_car)= vs_base[0];
 	if(endp(V54=MMcdr(V54))){
@@ -372,7 +372,7 @@ T133:;
 	goto T133;}
 T132:;
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	V50= vs_base[0];
 	V51= get(car((V35)),VV[33],Cnil);
@@ -402,23 +402,23 @@ T132:;
 T130:;
 	base[2]= car((V35));
 	vs_top=(vs_base=base+2)+1;
-	Lmacro_function();
+	(void) (*Lnk102)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T148;}
 	base[3]= (V35);
 	vs_top=(vs_base=base+3)+1;
-	Lmacroexpand();
+	(void) (*Lnk100)();
 	vs_top=sup;
 	base[2]= vs_base[0];
 	vs_top=(vs_base=base+2)+1;
-	(void) (*Lnk95)();
+	(void) (*Lnk99)();
 	return;
 T148:;
 	base[2]= VV[34];
 	base[3]= (V35);
 	vs_top=(vs_base=base+2)+2;
-	Lerror();
+	(void) (*Lnk94)();
 	return;}
 	}
 }
@@ -440,14 +440,14 @@ static L5()
 	base[4]= V58;}
 	base[5]= base[4];
 	vs_top=(vs_base=base+5)+1;
-	Llast();
+	(void) (*Lnk103)();
 	vs_top=sup;
 	V59= vs_base[0];
 	base[5]= list(4,VV[35],base[2],base[3],car(V59));
 	vs_top=(vs_base=base+5)+1;
 	return;
 }
-/*	function definition for G1057	*/
+/*	function definition for G1081	*/
 
 static L6()
 {register object *base=vs_base;
@@ -478,7 +478,7 @@ T158:;
 	base[4]= (V61);
 	base[5]= (V60);
 	vs_top=(vs_base=base+4)+2;
-	(void) (*Lnk97)();
+	(void) (*Lnk104)();
 	if(vs_base>=vs_top){vs_top=sup;goto T163;}
 	V64= vs_base[0];
 	vs_base++;
@@ -509,11 +509,11 @@ T168:;
 	{object V69;
 	object V70;
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	V69= vs_base[0];
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	V70= vs_base[0];
 	V71= make_cons((V69),Cnil);
@@ -529,7 +529,7 @@ T168:;
 	return;}}
 	}
 }
-/*	function definition for G1059	*/
+/*	function definition for G1083	*/
 
 static L7()
 {register object *base=vs_base;
@@ -552,7 +552,7 @@ TTL:;
 	base[3]= (V77);
 	base[4]= (V75);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk97)();
+	(void) (*Lnk104)();
 	if(vs_base>=vs_top){vs_top=sup;goto T179;}
 	V78= vs_base[0];
 	vs_base++;
@@ -582,7 +582,7 @@ T183:;
 T184:;
 	{object V83;
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	V83= vs_base[0];
 	base[3]= (V78);
@@ -596,7 +596,7 @@ T184:;
 	return;}}
 	}
 }
-/*	function definition for G1061	*/
+/*	function definition for G1085	*/
 
 static L8()
 {register object *base=vs_base;
@@ -629,7 +629,7 @@ T192:;
 	base[3]= VV[40];
 	base[4]= (V87);
 	vs_top=(vs_base=base+3)+2;
-	Lerror();
+	(void) (*Lnk94)();
 	vs_top=sup;
 T191:;
 	{register object V89;
@@ -640,7 +640,7 @@ T191:;
 	base[3]= make_cons(cadr((V87)),(V88));
 	base[4]= (V86);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk97)();
+	(void) (*Lnk104)();
 	if(vs_base>=vs_top){vs_top=sup;goto T207;}
 	V89= vs_base[0];
 	vs_base++;
@@ -670,13 +670,13 @@ T211:;
 T212:;
 	base[3]= (V92);
 	vs_top=(vs_base=base+3)+1;
-	Llast();
+	(void) (*Lnk103)();
 	vs_top=sup;
 	V94= vs_base[0];
 	V95= car(V94);
 	base[3]= (V89);
 	vs_top=(vs_base=base+3)+1;
-	Llast();
+	(void) (*Lnk103)();
 	vs_top=sup;
 	V96= vs_base[0];
 	if(!((/* INLINE-ARGS */V95)==(car(V96)))){
@@ -691,17 +691,17 @@ T212:;
 T214:;
 	base[4]= (V92);
 	vs_top=(vs_base=base+4)+1;
-	Lbutlast();
+	(void) (*Lnk105)();
 	vs_top=sup;
 	base[3]= vs_base[0];
 	vs_top=(vs_base=base+3)+1;
-	Llast();
+	(void) (*Lnk103)();
 	vs_top=sup;
 	V97= vs_base[0];
 	V98= car(V97);
 	base[3]= (V89);
 	vs_top=(vs_base=base+3)+1;
-	Llast();
+	(void) (*Lnk103)();
 	vs_top=sup;
 	V99= vs_base[0];
 	if(!((/* INLINE-ARGS */V98)==(car(V99)))){
@@ -713,23 +713,23 @@ T214:;
 	base[7]= (V92);
 	base[8]= small_fixnum(2);
 	vs_top=(vs_base=base+7)+2;
-	Lbutlast();
+	(void) (*Lnk105)();
 	vs_top=sup;
 	V101= vs_base[0];
 	V102= cdr(V101);
 	base[8]= (V92);
 	vs_top=(vs_base=base+8)+1;
-	Lbutlast();
+	(void) (*Lnk105)();
 	vs_top=sup;
 	base[7]= vs_base[0];
 	vs_top=(vs_base=base+7)+1;
-	Llast();
+	(void) (*Lnk103)();
 	vs_top=sup;
 	V103= vs_base[0];
 	V104= car(V103);
 	base[7]= (V92);
 	vs_top=(vs_base=base+7)+1;
-	Llast();
+	(void) (*Lnk103)();
 	vs_top=sup;
 	V105= vs_base[0];
 	V106= list(3,VV[42],/* INLINE-ARGS */V104,list(2,VV[43],car(V105)));
@@ -742,11 +742,11 @@ T226:;
 	base[3]= VV[44];
 	base[4]= (V87);
 	vs_top=(vs_base=base+3)+2;
-	Lerror();
+	(void) (*Lnk94)();
 	return;}
 	}
 }
-/*	function definition for G1062	*/
+/*	function definition for G1086	*/
 
 static L9()
 {register object *base=vs_base;
@@ -769,7 +769,7 @@ TTL:;
 	base[3]= (V109);
 	base[4]= (V108);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk97)();
+	(void) (*Lnk104)();
 	if(vs_base>=vs_top){vs_top=sup;goto T251;}
 	V111= vs_base[0];
 	vs_base++;
@@ -801,11 +801,11 @@ T256:;
 	object V117;
 	object V118;
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	V116= vs_base[0];
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	V117= vs_base[0];
 	V118= car((V113));
@@ -819,7 +819,7 @@ T256:;
 	return;}}
 	}
 }
-/*	function definition for G1064	*/
+/*	function definition for G1088	*/
 
 static L10()
 {register object *base=vs_base;
@@ -842,7 +842,7 @@ TTL:;
 	base[3]= (V122);
 	base[4]= (V120);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk97)();
+	(void) (*Lnk104)();
 	if(vs_base>=vs_top){vs_top=sup;goto T268;}
 	V123= vs_base[0];
 	vs_base++;
@@ -874,11 +874,11 @@ T273:;
 	object V129;
 	object V130;
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	V128= vs_base[0];
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	V129= vs_base[0];
 	V130= car((V125));
@@ -892,7 +892,7 @@ T273:;
 	return;}}
 	}
 }
-/*	function definition for G1066	*/
+/*	function definition for G1090	*/
 
 static L11()
 {register object *base=vs_base;
@@ -915,7 +915,7 @@ TTL:;
 	base[3]= (V134);
 	base[4]= (V132);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk97)();
+	(void) (*Lnk104)();
 	if(vs_base>=vs_top){vs_top=sup;goto T285;}
 	V135= vs_base[0];
 	vs_base++;
@@ -947,11 +947,11 @@ T290:;
 	object V141;
 	object V142;
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	V140= vs_base[0];
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	V141= vs_base[0];
 	V142= car((V137));
@@ -998,7 +998,7 @@ T309:;
 	base[0]= (V147);
 	base[1]= (V149);
 	vs_top=(vs_base=base+0)+2;
-	Lmacroexpand();
+	(void) (*Lnk100)();
 	if(vs_base<vs_top){
 	V147= vs_base[0];
 	vs_base++;
@@ -1029,7 +1029,7 @@ T329:;
 	V150= get(car((V147)),VV[32],Cnil);
 	if(((V150))==Cnil){
 	goto T335;}
-	{object V157 = (*(LnkLI96))(cadr((V147)),car((V150)),cdr((V150)),(V148));
+	{object V157 = (*(LnkLI101))(cadr((V147)),car((V150)),cdr((V150)),(V148));
 	VMR12(V157)}
 T335:;
 	{object V158;
@@ -1040,7 +1040,7 @@ T335:;
 	base[0]= (V147);
 	base[1]= (V149);
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk97)();
+	(void) (*Lnk104)();
 	if(vs_base>=vs_top){vs_top=sup;goto T344;}
 	V158= vs_base[0];
 	vs_base++;
@@ -1068,6 +1068,7 @@ T347:;
 T348:;
 	V162= Cnil;
 T349:;
+	base[1]=symbol_function(VV[43]);
 	V167= append((V158),(V160));
 	V168= make_cons((V148),Cnil);
 	V169= append((V159),/* INLINE-ARGS */V168);
@@ -1079,7 +1080,12 @@ T349:;
 	goto T350;}
 	base[0]=V164=MMcons(Cnil,Cnil);
 T351:;
-	(V164->c.c_car)= list(2,(V165->c.c_car),(V166->c.c_car));
+	base[2]= (V165->c.c_car);
+	base[3]= (V166->c.c_car);
+	vs_top=(vs_base=base+2)+2;
+	(void) (*Lnk43)();
+	vs_top=sup;
+	(V164->c.c_car)= vs_base[0];
 	if(endp(V165=MMcdr(V165))||endp(V166=MMcdr(V166))){
 	V163= base[0];
 	goto T350;}
@@ -1097,14 +1103,14 @@ object V175;object V176;object V177;object V178;
 {	 VMB13 VMS13 VMV13
 TTL:;
 	{object V179= (V176);
-	if((V179!= VV[43]))goto T353;
+	if((V179!= VV[43]))goto T355;
 	{object V180 = list(4,VV[52],(V175),(V177),(V178));
 	VMR13(V180)}
-T353:;
-	if((V179!= VV[98]))goto T354;
+T355:;
+	if((V179!= VV[106]))goto T356;
 	{object V181 = list(4,VV[53],(V175),(V177),(V178));
 	VMR13(V181)}
-T354:;
+T356:;
 	{object V182 = list(5,VV[54],(V175),list(2,VV[3],(V176)),(V177),(V178));
 	VMR13(V182)}}
 }
@@ -1116,22 +1122,22 @@ register object V185;object V186;
 {	 VMB14 VMS14 VMV14
 TTL:;
 	if(!(endp((V185)))){
-	goto T356;}
+	goto T358;}
 	{object V187 = Cnil;
 	VMR14(V187)}
-T356:;
+T358:;
 	if(!(endp(cdr((V185))))){
-	goto T359;}
+	goto T361;}
 	base[0]= VV[55];
 	base[1]= (V185);
 	vs_top=(vs_base=base+0)+2;
-	Lerror();
+	(void) (*Lnk94)();
 	vs_top=sup;
 	{object V188 = vs_base[0];
 	VMR14(V188)}
-T359:;
-	V189= (*(LnkLI99))(car((V185)),cadr((V185)),(V186));
-	V190= (*(LnkLI100))(cddr((V185)),(V186));
+T361:;
+	V189= (*(LnkLI107))(car((V185)),cadr((V185)),(V186));
+	V190= (*(LnkLI108))(cddr((V185)),(V186));
 	{object V191 = make_cons(/* INLINE-ARGS */V189,/* INLINE-ARGS */V190);
 	VMR14(V191)}
 }
@@ -1144,26 +1150,26 @@ register object V194;object V195;
 TTL:;
 	V194= cdr((V194));
 	if(!(endp((V194)))){
-	goto T366;}
+	goto T368;}
 	{object V196 = Cnil;
 	VMR15(V196)}
-T366:;
+T368:;
 	if(!(endp(cdr((V194))))){
-	goto T369;}
+	goto T371;}
 	base[0]= VV[56];
 	base[1]= (V194);
 	vs_top=(vs_base=base+0)+2;
-	Lerror();
+	(void) (*Lnk94)();
 	vs_top=sup;
 	{object V197 = vs_base[0];
 	VMR15(V197)}
-T369:;
+T371:;
 	if(!(endp(cddr((V194))))){
-	goto T374;}
-	{object V198 = (*(LnkLI99))(car((V194)),cadr((V194)),(V195));
+	goto T376;}
+	{object V198 = (*(LnkLI107))(car((V194)),cadr((V194)),(V195));
 	VMR15(V198)}
-T374:;
-	V199= (*(LnkLI100))((V194),(V195));
+T376:;
+	V199= (*(LnkLI108))((V194),(V195));
 	{object V200 = make_cons(VV[57],/* INLINE-ARGS */V199);
 	VMR15(V200)}
 }
@@ -1178,48 +1184,48 @@ static L16()
 	{object V201=base[0]->c.c_cdr;
 	base[2]= V201;}
 	if(!(endp(base[2]))){
-	goto T377;}
+	goto T379;}
 	base[3]= Cnil;
 	vs_top=(vs_base=base+3)+1;
 	return;
-T377:;
+T379:;
 	if(!(endp(cdr(base[2])))){
-	goto T380;}
+	goto T382;}
 	base[3]= VV[58];
 	base[4]= base[2];
 	vs_top=(vs_base=base+3)+2;
-	Lerror();
+	(void) (*Lnk94)();
 	return;
-T380:;
+T382:;
 	if(!(endp(cddr(base[2])))){
-	goto T385;}
-	V202= (*(LnkLI99))(car(base[2]),cadr(base[2]),base[1]);
+	goto T387;}
+	V202= (*(LnkLI107))(car(base[2]),cadr(base[2]),base[1]);
 	base[3]= list(3,VV[57],/* INLINE-ARGS */V202,Cnil);
 	vs_top=(vs_base=base+3)+1;
 	return;
-T385:;
+T387:;
 	{register object V203;
 	register object V204;
 	register object V205;
 	V203= base[2];
 	V204= Cnil;
 	V205= Cnil;
-T388:;
+T390:;
 	if(!(endp((V203)))){
-	goto T389;}
+	goto T391;}
 	V206= nreverse((V205));
 	base[3]= listA(3,VV[51],(V204),append(/* INLINE-ARGS */V206,VV[59]));
 	vs_top=(vs_base=base+3)+1;
 	return;
-T389:;
+T391:;
 	if(!(endp(cdr((V203))))){
-	goto T393;}
+	goto T395;}
 	base[3]= VV[60];
 	base[4]= base[2];
 	vs_top=(vs_base=base+3)+2;
-	Lerror();
+	(void) (*Lnk94)();
 	vs_top=sup;
-T393:;
+T395:;
 	{register object V207;
 	register object V208;
 	register object V209;
@@ -1228,35 +1234,36 @@ T393:;
 	base[3]= car((V203));
 	base[4]= base[1];
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk97)();
-	if(vs_base>=vs_top){vs_top=sup;goto T402;}
+	(void) (*Lnk104)();
+	if(vs_base>=vs_top){vs_top=sup;goto T404;}
 	V207= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T403;}
+	if(vs_base>=vs_top){vs_top=sup;goto T405;}
 	V208= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T404;}
+	if(vs_base>=vs_top){vs_top=sup;goto T406;}
 	V209= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T405;}
+	if(vs_base>=vs_top){vs_top=sup;goto T407;}
 	V210= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T406;}
+	if(vs_base>=vs_top){vs_top=sup;goto T408;}
 	V211= vs_base[0];
 	vs_top=sup;
-	goto T407;
-T402:;
-	V207= Cnil;
-T403:;
-	V208= Cnil;
+	goto T409;
 T404:;
-	V209= Cnil;
+	V207= Cnil;
 T405:;
-	V210= Cnil;
+	V208= Cnil;
 T406:;
-	V211= Cnil;
+	V209= Cnil;
 T407:;
+	V210= Cnil;
+T408:;
+	V211= Cnil;
+T409:;
 	V205= make_cons((V210),(V205));
+	base[4]=symbol_function(VV[43]);
 	V216= append((V207),(V209));
 	V217= make_cons(cadr((V203)),Cnil);
 	V218= append((V208),/* INLINE-ARGS */V217);
@@ -1265,19 +1272,24 @@ T407:;
 	object V215= /* INLINE-ARGS */V218;
 	if(endp(V214)||endp(V215)){
 	V212= Cnil;
-	goto T411;}
+	goto T413;}
 	base[3]=V213=MMcons(Cnil,Cnil);
-T412:;
-	(V213->c.c_car)= list(2,(V214->c.c_car),(V215->c.c_car));
+T414:;
+	base[5]= (V214->c.c_car);
+	base[6]= (V215->c.c_car);
+	vs_top=(vs_base=base+5)+2;
+	(void) (*Lnk43)();
+	vs_top=sup;
+	(V213->c.c_car)= vs_base[0];
 	if(endp(V214=MMcdr(V214))||endp(V215=MMcdr(V215))){
 	V212= base[3];
-	goto T411;}
+	goto T413;}
 	V213=MMcdr(V213)=MMcons(Cnil,Cnil);
-	goto T412;}
-T411:;
+	goto T414;}
+T413:;
 	V204= nconc((V204),V212);}
 	V203= cddr((V203));
-	goto T388;}
+	goto T390;}
 }
 /*	macro definition for SHIFTF	*/
 
@@ -1296,7 +1308,7 @@ static L17()
 	register object V224;
 	register object V225;
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	V224= vs_base[0];
 	V220= base[2];
@@ -1304,46 +1316,52 @@ static L17()
 	V222= Cnil;
 	V223= Cnil;
 	V225= Cnil;
-T419:;
+T423:;
 	if(!(endp(cdr((V220))))){
-	goto T420;}
+	goto T424;}
 	V222= nreverse((V222));
 	V223= nreverse((V223));
 	V225= nreverse((V225));
 	base[3]= (V221);
 	V227= list(2,(V224),car((V225)));
 	base[4]= make_cons(/* INLINE-ARGS */V227,Cnil);
+	base[7]=symbol_function(VV[43]);
 	{object V228;
 	object V229= (V222);
 	object V230= cdr((V225));
 	if(endp(V229)||endp(V230)){
 	base[5]= Cnil;
-	goto T432;}
+	goto T436;}
 	base[6]=V228=MMcons(Cnil,Cnil);
-T433:;
-	(V228->c.c_car)= list(2,(V229->c.c_car),(V230->c.c_car));
+T437:;
+	base[8]= (V229->c.c_car);
+	base[9]= (V230->c.c_car);
+	vs_top=(vs_base=base+8)+2;
+	(void) (*Lnk43)();
+	vs_top=sup;
+	(V228->c.c_car)= vs_base[0];
 	if(endp(V229=MMcdr(V229))||endp(V230=MMcdr(V230))){
 	base[5]= base[6];
-	goto T432;}
+	goto T436;}
 	V228=MMcdr(V228)=MMcons(Cnil,Cnil);
-	goto T433;}
-T432:;
+	goto T437;}
+T436:;
 	base[7]= (V222);
 	vs_top=(vs_base=base+7)+1;
-	Llast();
+	(void) (*Lnk103)();
 	vs_top=sup;
 	V231= vs_base[0];
 	V232= list(2,car(V231),car((V220)));
 	base[6]= make_cons(/* INLINE-ARGS */V232,Cnil);
 	vs_top=(vs_base=base+3)+4;
-	Lnconc();
+	(void) (*Lnk109)();
 	vs_top=sup;
 	V226= vs_base[0];
 	V233= make_cons((V224),Cnil);
 	base[3]= listA(3,VV[51],V226,append((V223),/* INLINE-ARGS */V233));
 	vs_top=(vs_base=base+3)+1;
 	return;
-T420:;
+T424:;
 	{register object V234;
 	register object V235;
 	register object V236;
@@ -1352,55 +1370,61 @@ T420:;
 	base[3]= car((V220));
 	base[4]= base[1];
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk97)();
-	if(vs_base>=vs_top){vs_top=sup;goto T443;}
+	(void) (*Lnk104)();
+	if(vs_base>=vs_top){vs_top=sup;goto T449;}
 	V234= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T444;}
+	if(vs_base>=vs_top){vs_top=sup;goto T450;}
 	V235= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T445;}
+	if(vs_base>=vs_top){vs_top=sup;goto T451;}
 	V236= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T446;}
+	if(vs_base>=vs_top){vs_top=sup;goto T452;}
 	V237= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T447;}
+	if(vs_base>=vs_top){vs_top=sup;goto T453;}
 	V238= vs_base[0];
 	vs_top=sup;
-	goto T448;
-T443:;
+	goto T454;
+T449:;
 	V234= Cnil;
-T444:;
+T450:;
 	V235= Cnil;
-T445:;
+T451:;
 	V236= Cnil;
-T446:;
+T452:;
 	V237= Cnil;
-T447:;
+T453:;
 	V238= Cnil;
-T448:;
+T454:;
+	base[4]=symbol_function(VV[43]);
 	{object V240;
 	object V241= (V234);
 	object V242= (V235);
 	if(endp(V241)||endp(V242)){
 	V239= Cnil;
-	goto T451;}
+	goto T457;}
 	base[3]=V240=MMcons(Cnil,Cnil);
-T452:;
-	(V240->c.c_car)= list(2,(V241->c.c_car),(V242->c.c_car));
+T458:;
+	base[5]= (V241->c.c_car);
+	base[6]= (V242->c.c_car);
+	vs_top=(vs_base=base+5)+2;
+	(void) (*Lnk43)();
+	vs_top=sup;
+	(V240->c.c_car)= vs_base[0];
 	if(endp(V241=MMcdr(V241))||endp(V242=MMcdr(V242))){
 	V239= base[3];
-	goto T451;}
+	goto T457;}
 	V240=MMcdr(V240)=MMcons(Cnil,Cnil);
-	goto T452;}
-T451:;
+	goto T458;}
+T457:;
 	V221= nconc((V221),V239);
 	V222= make_cons(car((V236)),(V222));
 	V223= make_cons((V237),(V223));
 	V225= make_cons((V238),(V225));}
 	V220= cdr((V220));
-	goto T419;}
+	goto T423;}
 }
 /*	macro definition for ROTATEF	*/
 
@@ -1422,43 +1446,49 @@ static L18()
 	V246= Cnil;
 	V247= Cnil;
 	V248= Cnil;
-T463:;
+T471:;
 	if(!(endp((V244)))){
-	goto T464;}
+	goto T472;}
 	V246= nreverse((V246));
 	V247= nreverse((V247));
 	V248= nreverse((V248));
 	base[3]= (V245);
+	base[6]=symbol_function(VV[43]);
 	{object V250;
 	object V251= (V246);
 	object V252= cdr((V248));
 	if(endp(V251)||endp(V252)){
 	base[4]= Cnil;
-	goto T475;}
+	goto T483;}
 	base[5]=V250=MMcons(Cnil,Cnil);
-T476:;
-	(V250->c.c_car)= list(2,(V251->c.c_car),(V252->c.c_car));
+T484:;
+	base[7]= (V251->c.c_car);
+	base[8]= (V252->c.c_car);
+	vs_top=(vs_base=base+7)+2;
+	(void) (*Lnk43)();
+	vs_top=sup;
+	(V250->c.c_car)= vs_base[0];
 	if(endp(V251=MMcdr(V251))||endp(V252=MMcdr(V252))){
 	base[4]= base[5];
-	goto T475;}
+	goto T483;}
 	V250=MMcdr(V250)=MMcons(Cnil,Cnil);
-	goto T476;}
-T475:;
+	goto T484;}
+T483:;
 	base[6]= (V246);
 	vs_top=(vs_base=base+6)+1;
-	Llast();
+	(void) (*Lnk103)();
 	vs_top=sup;
 	V253= vs_base[0];
 	V254= list(2,car(V253),car((V248)));
 	base[5]= make_cons(/* INLINE-ARGS */V254,Cnil);
 	vs_top=(vs_base=base+3)+3;
-	Lnconc();
+	(void) (*Lnk109)();
 	vs_top=sup;
 	V249= vs_base[0];
 	base[3]= listA(3,VV[51],V249,append((V247),VV[61]));
 	vs_top=(vs_base=base+3)+1;
 	return;
-T464:;
+T472:;
 	{register object V255;
 	register object V256;
 	register object V257;
@@ -1467,55 +1497,61 @@ T464:;
 	base[3]= car((V244));
 	base[4]= base[1];
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk97)();
-	if(vs_base>=vs_top){vs_top=sup;goto T486;}
+	(void) (*Lnk104)();
+	if(vs_base>=vs_top){vs_top=sup;goto T496;}
 	V255= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T487;}
+	if(vs_base>=vs_top){vs_top=sup;goto T497;}
 	V256= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T488;}
+	if(vs_base>=vs_top){vs_top=sup;goto T498;}
 	V257= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T489;}
+	if(vs_base>=vs_top){vs_top=sup;goto T499;}
 	V258= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T490;}
+	if(vs_base>=vs_top){vs_top=sup;goto T500;}
 	V259= vs_base[0];
 	vs_top=sup;
-	goto T491;
-T486:;
+	goto T501;
+T496:;
 	V255= Cnil;
-T487:;
+T497:;
 	V256= Cnil;
-T488:;
+T498:;
 	V257= Cnil;
-T489:;
+T499:;
 	V258= Cnil;
-T490:;
+T500:;
 	V259= Cnil;
-T491:;
+T501:;
+	base[4]=symbol_function(VV[43]);
 	{object V261;
 	object V262= (V255);
 	object V263= (V256);
 	if(endp(V262)||endp(V263)){
 	V260= Cnil;
-	goto T494;}
+	goto T504;}
 	base[3]=V261=MMcons(Cnil,Cnil);
-T495:;
-	(V261->c.c_car)= list(2,(V262->c.c_car),(V263->c.c_car));
+T505:;
+	base[5]= (V262->c.c_car);
+	base[6]= (V263->c.c_car);
+	vs_top=(vs_base=base+5)+2;
+	(void) (*Lnk43)();
+	vs_top=sup;
+	(V261->c.c_car)= vs_base[0];
 	if(endp(V262=MMcdr(V262))||endp(V263=MMcdr(V263))){
 	V260= base[3];
-	goto T494;}
+	goto T504;}
 	V261=MMcdr(V261)=MMcons(Cnil,Cnil);
-	goto T495;}
-T494:;
+	goto T505;}
+T504:;
 	V245= nconc((V245),V260);
 	V246= make_cons(car((V257)),(V246));
 	V247= make_cons((V258),(V247));
 	V248= make_cons((V259),(V248));}
 	V244= cdr((V244));
-	goto T463;}
+	goto T471;}
 }
 /*	macro definition for DEFINE-MODIFY-MACRO	*/
 
@@ -1546,41 +1582,41 @@ static L19()
 	register object V267;
 	V266= base[3];
 	V267= Cnil;
-T508:;
+T520:;
 	if(((V266))!=Cnil){
-	goto T509;}
+	goto T521;}
 	V268= list(2,VV[3],base[4]);
 	V265= listA(4,VV[43],/* INLINE-ARGS */V268,VV[62],nreverse((V267)));
-	goto T506;
-T509:;
+	goto T518;
+T521:;
 	if((car((V266)))==(VV[63])){
-	goto T513;}
+	goto T525;}
 	if(!((car((V266)))==(VV[64]))){
-	goto T516;}
+	goto T528;}
 	V269= list(2,VV[3],base[4]);
 	V270= nreverse((V267));
 	V271= make_cons(cadr((V266)),Cnil);
 	V265= listA(4,VV[65],/* INLINE-ARGS */V269,VV[62],append(/* INLINE-ARGS */V270,/* INLINE-ARGS */V271));
-	goto T506;
-T516:;
+	goto T518;
+T528:;
 	if(!(type_of(car((V266)))==t_symbol)){
-	goto T520;}
+	goto T532;}
 	V267= make_cons(car((V266)),(V267));
-	goto T513;
-T520:;
+	goto T525;
+T532:;
 	V267= make_cons(caar((V266)),(V267));
-T513:;
+T525:;
 	V266= cdr((V266));
-	goto T508;}
-T506:;
+	goto T520;}
+T518:;
 	V272= listA(4,VV[67],VV[68],VV[69],base[3]);
 	if((base[5])==Cnil){
-	goto T529;}
+	goto T541;}
 	V273= make_cons(base[5],Cnil);
-	goto T527;
-T529:;
+	goto T539;
+T541:;
 	V273= Cnil;
-T527:;
+T539:;
 	V274= list(3,VV[70],VV[71],list(3,VV[72],base[2],list(3,VV[36],VV[73],list(4,VV[43],VV[74],VV[69],(V265)))));
 	V275= list(2,/* INLINE-ARGS */V274,list(4,VV[75],VV[76],VV[77],list(4,VV[43],VV[78],list(4,VV[79],VV[80],VV[81],list(3,VV[42],VV[82],list(2,VV[43],(V265)))),VV[83])));
 	base[6]= listA(4,VV[66],base[2],/* INLINE-ARGS */V272,append(V273,/* INLINE-ARGS */V275));
@@ -1611,49 +1647,55 @@ static L20()
 	base[4]= base[2];
 	base[5]= base[1];
 	vs_top=(vs_base=base+4)+2;
-	(void) (*Lnk97)();
-	if(vs_base>=vs_top){vs_top=sup;goto T534;}
+	(void) (*Lnk104)();
+	if(vs_base>=vs_top){vs_top=sup;goto T546;}
 	V277= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T535;}
+	if(vs_base>=vs_top){vs_top=sup;goto T547;}
 	V278= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T536;}
+	if(vs_base>=vs_top){vs_top=sup;goto T548;}
 	V279= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T537;}
+	if(vs_base>=vs_top){vs_top=sup;goto T549;}
 	V280= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T538;}
+	if(vs_base>=vs_top){vs_top=sup;goto T550;}
 	V281= vs_base[0];
 	vs_top=sup;
-	goto T539;
-T534:;
+	goto T551;
+T546:;
 	V277= Cnil;
-T535:;
+T547:;
 	V278= Cnil;
-T536:;
+T548:;
 	V279= Cnil;
-T537:;
+T549:;
 	V280= Cnil;
-T538:;
+T550:;
 	V281= Cnil;
-T539:;
+T551:;
+	base[5]=symbol_function(VV[43]);
 	{object V283;
 	object V284= (V277);
 	object V285= (V278);
 	if(endp(V284)||endp(V285)){
 	V282= Cnil;
-	goto T540;}
+	goto T552;}
 	base[4]=V283=MMcons(Cnil,Cnil);
-T541:;
-	(V283->c.c_car)= list(2,(V284->c.c_car),(V285->c.c_car));
+T553:;
+	base[6]= (V284->c.c_car);
+	base[7]= (V285->c.c_car);
+	vs_top=(vs_base=base+6)+2;
+	(void) (*Lnk43)();
+	vs_top=sup;
+	(V283->c.c_car)= vs_base[0];
 	if(endp(V284=MMcdr(V284))||endp(V285=MMcdr(V285))){
 	V282= base[4];
-	goto T540;}
+	goto T552;}
 	V283=MMcdr(V283)=MMcons(Cnil,Cnil);
-	goto T541;}
-T540:;
+	goto T553;}
+T552:;
 	V286= list(2,car((V279)),VV[84]);
 	base[4]= list(3,VV[51],V282,list(5,VV[75],/* INLINE-ARGS */V286,list(3,VV[85],(V281),base[3]),(V280),VV[84]));
 	vs_top=(vs_base=base+4)+1;
@@ -1678,11 +1720,11 @@ static L21()
 	V287=V287->c.c_cdr;}
 	if(!endp(V287))invalid_macro_call();}
 	if(!(type_of(base[2])==t_symbol)){
-	goto T544;}
+	goto T558;}
 	base[4]= list(3,VV[27],base[2],list(3,VV[86],base[2],base[3]));
 	vs_top=(vs_base=base+4)+1;
 	return;
-T544:;
+T558:;
 	{object V289;
 	object V290;
 	object V291;
@@ -1691,34 +1733,35 @@ T544:;
 	base[4]= base[2];
 	base[5]= base[1];
 	vs_top=(vs_base=base+4)+2;
-	(void) (*Lnk97)();
-	if(vs_base>=vs_top){vs_top=sup;goto T550;}
+	(void) (*Lnk104)();
+	if(vs_base>=vs_top){vs_top=sup;goto T564;}
 	V289= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T551;}
+	if(vs_base>=vs_top){vs_top=sup;goto T565;}
 	V290= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T552;}
+	if(vs_base>=vs_top){vs_top=sup;goto T566;}
 	V291= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T553;}
+	if(vs_base>=vs_top){vs_top=sup;goto T567;}
 	V292= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T554;}
+	if(vs_base>=vs_top){vs_top=sup;goto T568;}
 	V293= vs_base[0];
 	vs_top=sup;
-	goto T555;
-T550:;
+	goto T569;
+T564:;
 	V289= Cnil;
-T551:;
+T565:;
 	V290= Cnil;
-T552:;
+T566:;
 	V291= Cnil;
-T553:;
+T567:;
 	V292= Cnil;
-T554:;
+T568:;
 	V293= Cnil;
-T555:;
+T569:;
+	base[5]=symbol_function(VV[43]);
 	V298= append((V289),(V291));
 	V299= list(3,VV[86],(V293),base[3]);
 	V300= make_cons(/* INLINE-ARGS */V299,Cnil);
@@ -1728,16 +1771,21 @@ T555:;
 	object V297= /* INLINE-ARGS */V301;
 	if(endp(V296)||endp(V297)){
 	V294= Cnil;
-	goto T556;}
+	goto T570;}
 	base[4]=V295=MMcons(Cnil,Cnil);
-T557:;
-	(V295->c.c_car)= list(2,(V296->c.c_car),(V297->c.c_car));
+T571:;
+	base[6]= (V296->c.c_car);
+	base[7]= (V297->c.c_car);
+	vs_top=(vs_base=base+6)+2;
+	(void) (*Lnk43)();
+	vs_top=sup;
+	(V295->c.c_car)= vs_base[0];
 	if(endp(V296=MMcdr(V296))||endp(V297=MMcdr(V297))){
 	V294= base[4];
-	goto T556;}
+	goto T570;}
 	V295=MMcdr(V295)=MMcons(Cnil,Cnil);
-	goto T557;}
-T556:;
+	goto T571;}
+T570:;
 	base[4]= list(3,VV[51],V294,(V292));
 	vs_top=(vs_base=base+4)+1;
 	return;}
@@ -1761,11 +1809,11 @@ static L22()
 	V302=V302->c.c_cdr;}
 	if(!endp(V302))invalid_macro_call();}
 	if(!(type_of(base[2])==t_symbol)){
-	goto T560;}
+	goto T576;}
 	base[4]= list(3,VV[27],base[2],list(3,VV[87],base[2],base[3]));
 	vs_top=(vs_base=base+4)+1;
 	return;
-T560:;
+T576:;
 	{object V304;
 	object V305;
 	object V306;
@@ -1774,34 +1822,35 @@ T560:;
 	base[4]= base[2];
 	base[5]= base[1];
 	vs_top=(vs_base=base+4)+2;
-	(void) (*Lnk97)();
-	if(vs_base>=vs_top){vs_top=sup;goto T566;}
+	(void) (*Lnk104)();
+	if(vs_base>=vs_top){vs_top=sup;goto T582;}
 	V304= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T567;}
+	if(vs_base>=vs_top){vs_top=sup;goto T583;}
 	V305= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T568;}
+	if(vs_base>=vs_top){vs_top=sup;goto T584;}
 	V306= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T569;}
+	if(vs_base>=vs_top){vs_top=sup;goto T585;}
 	V307= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T570;}
+	if(vs_base>=vs_top){vs_top=sup;goto T586;}
 	V308= vs_base[0];
 	vs_top=sup;
-	goto T571;
-T566:;
+	goto T587;
+T582:;
 	V304= Cnil;
-T567:;
+T583:;
 	V305= Cnil;
-T568:;
+T584:;
 	V306= Cnil;
-T569:;
+T585:;
 	V307= Cnil;
-T570:;
+T586:;
 	V308= Cnil;
-T571:;
+T587:;
+	base[5]=symbol_function(VV[43]);
 	V313= append((V304),(V306));
 	V314= list(3,VV[87],(V308),base[3]);
 	V315= make_cons(/* INLINE-ARGS */V314,Cnil);
@@ -1811,16 +1860,21 @@ T571:;
 	object V312= /* INLINE-ARGS */V316;
 	if(endp(V311)||endp(V312)){
 	V309= Cnil;
-	goto T572;}
+	goto T588;}
 	base[4]=V310=MMcons(Cnil,Cnil);
-T573:;
-	(V310->c.c_car)= list(2,(V311->c.c_car),(V312->c.c_car));
+T589:;
+	base[6]= (V311->c.c_car);
+	base[7]= (V312->c.c_car);
+	vs_top=(vs_base=base+6)+2;
+	(void) (*Lnk43)();
+	vs_top=sup;
+	(V310->c.c_car)= vs_base[0];
 	if(endp(V311=MMcdr(V311))||endp(V312=MMcdr(V312))){
 	V309= base[4];
-	goto T572;}
+	goto T588;}
 	V310=MMcdr(V310)=MMcons(Cnil,Cnil);
-	goto T573;}
-T572:;
+	goto T589;}
+T588:;
 	base[4]= list(3,VV[51],V309,(V307));
 	vs_top=(vs_base=base+4)+1;
 	return;}
@@ -1842,11 +1896,11 @@ static L23()
 	V317=V317->c.c_cdr;
 	if(!endp(V317))invalid_macro_call();}
 	if(!(type_of(base[3])==t_symbol)){
-	goto T575;}
+	goto T593;}
 	base[4]= list(3,VV[27],base[3],list(3,VV[88],base[2],base[3]));
 	vs_top=(vs_base=base+4)+1;
 	return;
-T575:;
+T593:;
 	{object V318;
 	object V319;
 	object V320;
@@ -1855,34 +1909,35 @@ T575:;
 	base[4]= base[3];
 	base[5]= base[1];
 	vs_top=(vs_base=base+4)+2;
-	(void) (*Lnk97)();
-	if(vs_base>=vs_top){vs_top=sup;goto T581;}
+	(void) (*Lnk104)();
+	if(vs_base>=vs_top){vs_top=sup;goto T599;}
 	V318= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T582;}
+	if(vs_base>=vs_top){vs_top=sup;goto T600;}
 	V319= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T583;}
+	if(vs_base>=vs_top){vs_top=sup;goto T601;}
 	V320= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T584;}
+	if(vs_base>=vs_top){vs_top=sup;goto T602;}
 	V321= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T585;}
+	if(vs_base>=vs_top){vs_top=sup;goto T603;}
 	V322= vs_base[0];
 	vs_top=sup;
-	goto T586;
-T581:;
+	goto T604;
+T599:;
 	V318= Cnil;
-T582:;
+T600:;
 	V319= Cnil;
-T583:;
+T601:;
 	V320= Cnil;
-T584:;
+T602:;
 	V321= Cnil;
-T585:;
+T603:;
 	V322= Cnil;
-T586:;
+T604:;
+	base[5]=symbol_function(VV[43]);
 	V327= append((V318),(V320));
 	V328= list(3,VV[88],base[2],(V322));
 	V329= make_cons(/* INLINE-ARGS */V328,Cnil);
@@ -1892,16 +1947,21 @@ T586:;
 	object V326= /* INLINE-ARGS */V330;
 	if(endp(V325)||endp(V326)){
 	V323= Cnil;
-	goto T587;}
+	goto T605;}
 	base[4]=V324=MMcons(Cnil,Cnil);
-T588:;
-	(V324->c.c_car)= list(2,(V325->c.c_car),(V326->c.c_car));
+T606:;
+	base[6]= (V325->c.c_car);
+	base[7]= (V326->c.c_car);
+	vs_top=(vs_base=base+6)+2;
+	(void) (*Lnk43)();
+	vs_top=sup;
+	(V324->c.c_car)= vs_base[0];
 	if(endp(V325=MMcdr(V325))||endp(V326=MMcdr(V326))){
 	V323= base[4];
-	goto T587;}
+	goto T605;}
 	V324=MMcdr(V324)=MMcons(Cnil,Cnil);
-	goto T588;}
-T587:;
+	goto T606;}
+T605:;
 	base[4]= list(3,VV[51],V323,(V321));
 	vs_top=(vs_base=base+4)+1;
 	return;}
@@ -1923,11 +1983,11 @@ static L24()
 	V331=V331->c.c_cdr;
 	base[4]= V331;}
 	if(!(type_of(base[3])==t_symbol)){
-	goto T590;}
+	goto T610;}
 	base[5]= list(3,VV[27],base[3],listA(4,VV[89],base[2],base[3],base[4]));
 	vs_top=(vs_base=base+5)+1;
 	return;
-T590:;
+T610:;
 	{object V332;
 	object V333;
 	object V334;
@@ -1936,34 +1996,35 @@ T590:;
 	base[5]= base[3];
 	base[6]= base[1];
 	vs_top=(vs_base=base+5)+2;
-	(void) (*Lnk97)();
-	if(vs_base>=vs_top){vs_top=sup;goto T596;}
+	(void) (*Lnk104)();
+	if(vs_base>=vs_top){vs_top=sup;goto T616;}
 	V332= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T597;}
+	if(vs_base>=vs_top){vs_top=sup;goto T617;}
 	V333= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T598;}
+	if(vs_base>=vs_top){vs_top=sup;goto T618;}
 	V334= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T599;}
+	if(vs_base>=vs_top){vs_top=sup;goto T619;}
 	V335= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T600;}
+	if(vs_base>=vs_top){vs_top=sup;goto T620;}
 	V336= vs_base[0];
 	vs_top=sup;
-	goto T601;
-T596:;
+	goto T621;
+T616:;
 	V332= Cnil;
-T597:;
+T617:;
 	V333= Cnil;
-T598:;
+T618:;
 	V334= Cnil;
-T599:;
+T619:;
 	V335= Cnil;
-T600:;
+T620:;
 	V336= Cnil;
-T601:;
+T621:;
+	base[6]=symbol_function(VV[43]);
 	V341= append((V332),(V334));
 	V342= listA(4,VV[89],base[2],(V336),base[4]);
 	V343= make_cons(/* INLINE-ARGS */V342,Cnil);
@@ -1973,16 +2034,21 @@ T601:;
 	object V340= /* INLINE-ARGS */V344;
 	if(endp(V339)||endp(V340)){
 	V337= Cnil;
-	goto T602;}
+	goto T622;}
 	base[5]=V338=MMcons(Cnil,Cnil);
-T603:;
-	(V338->c.c_car)= list(2,(V339->c.c_car),(V340->c.c_car));
+T623:;
+	base[7]= (V339->c.c_car);
+	base[8]= (V340->c.c_car);
+	vs_top=(vs_base=base+7)+2;
+	(void) (*Lnk43)();
+	vs_top=sup;
+	(V338->c.c_car)= vs_base[0];
 	if(endp(V339=MMcdr(V339))||endp(V340=MMcdr(V340))){
 	V337= base[5];
-	goto T602;}
+	goto T622;}
 	V338=MMcdr(V338)=MMcons(Cnil,Cnil);
-	goto T603;}
-T602:;
+	goto T623;}
+T622:;
 	base[5]= list(3,VV[51],V337,(V335));
 	vs_top=(vs_base=base+5)+1;
 	return;}
@@ -2001,10 +2067,10 @@ static L25()
 	V345=V345->c.c_cdr;
 	if(!endp(V345))invalid_macro_call();}
 	if(!(type_of(base[2])==t_symbol)){
-	goto T605;}
+	goto T627;}
 	{object V346;
 	vs_base=vs_top;
-	Lgensym();
+	(void) (*Lnk98)();
 	vs_top=sup;
 	V346= vs_base[0];
 	V347= list(2,(V346),list(2,VV[90],base[2]));
@@ -2012,7 +2078,7 @@ static L25()
 	base[3]= list(4,VV[36],/* INLINE-ARGS */V348,list(3,VV[27],base[2],list(2,VV[91],base[2])),(V346));
 	vs_top=(vs_base=base+3)+1;
 	return;}
-T605:;
+T627:;
 	{object V349;
 	object V350;
 	object V351;
@@ -2021,34 +2087,35 @@ T605:;
 	base[3]= base[2];
 	base[4]= base[1];
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk97)();
-	if(vs_base>=vs_top){vs_top=sup;goto T612;}
+	(void) (*Lnk104)();
+	if(vs_base>=vs_top){vs_top=sup;goto T634;}
 	V349= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T613;}
+	if(vs_base>=vs_top){vs_top=sup;goto T635;}
 	V350= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T614;}
+	if(vs_base>=vs_top){vs_top=sup;goto T636;}
 	V351= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T615;}
+	if(vs_base>=vs_top){vs_top=sup;goto T637;}
 	V352= vs_base[0];
 	vs_base++;
-	if(vs_base>=vs_top){vs_top=sup;goto T616;}
+	if(vs_base>=vs_top){vs_top=sup;goto T638;}
 	V353= vs_base[0];
 	vs_top=sup;
-	goto T617;
-T612:;
+	goto T639;
+T634:;
 	V349= Cnil;
-T613:;
+T635:;
 	V350= Cnil;
-T614:;
+T636:;
 	V351= Cnil;
-T615:;
+T637:;
 	V352= Cnil;
-T616:;
+T638:;
 	V353= Cnil;
-T617:;
+T639:;
+	base[4]=symbol_function(VV[43]);
 	V358= append((V349),(V351));
 	V359= list(2,VV[91],(V353));
 	V360= make_cons(/* INLINE-ARGS */V359,Cnil);
@@ -2058,24 +2125,39 @@ T617:;
 	object V357= /* INLINE-ARGS */V361;
 	if(endp(V356)||endp(V357)){
 	V354= Cnil;
-	goto T618;}
+	goto T640;}
 	base[3]=V355=MMcons(Cnil,Cnil);
-T619:;
-	(V355->c.c_car)= list(2,(V356->c.c_car),(V357->c.c_car));
+T641:;
+	base[5]= (V356->c.c_car);
+	base[6]= (V357->c.c_car);
+	vs_top=(vs_base=base+5)+2;
+	(void) (*Lnk43)();
+	vs_top=sup;
+	(V355->c.c_car)= vs_base[0];
 	if(endp(V356=MMcdr(V356))||endp(V357=MMcdr(V357))){
 	V354= base[3];
-	goto T618;}
+	goto T640;}
 	V355=MMcdr(V355)=MMcons(Cnil,Cnil);
-	goto T619;}
-T618:;
+	goto T641;}
+T640:;
 	base[3]= list(3,VV[51],V354,list(3,VV[92],list(2,VV[90],(V353)),(V352)));
 	vs_top=(vs_base=base+3)+1;
 	return;}
 }
-static object  LnkTLI100(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[100],&LnkLI100,2,ap);} /* SETF-EXPAND */
-static object  LnkTLI99(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[99],&LnkLI99,3,ap);} /* SETF-EXPAND-1 */
-static LnkT97(){ call_or_link(VV[97],&Lnk97);} /* GET-SETF-METHOD */
-static object  LnkTLI96(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[96],&LnkLI96,4,ap);} /* SETF-STRUCTURE-ACCESS */
-static LnkT95(){ call_or_link(VV[95],&Lnk95);} /* GET-SETF-METHOD-MULTIPLE-VALUE */
-static LnkT94(){ call_or_link(VV[94],&Lnk94);} /* GET-&ENVIRONMENT */
-static object  LnkTLI93(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[93],&LnkLI93,1,ap);} /* FIND-DOCUMENTATION */
+static LnkT109(){ call_or_link(VV[109],&Lnk109);} /* NCONC */
+static object  LnkTLI108(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[108],&LnkLI108,2,ap);} /* SETF-EXPAND */
+static object  LnkTLI107(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[107],&LnkLI107,3,ap);} /* SETF-EXPAND-1 */
+static LnkT43(){ call_or_link(VV[43],&Lnk43);} /* LIST */
+static LnkT105(){ call_or_link(VV[105],&Lnk105);} /* BUTLAST */
+static LnkT104(){ call_or_link(VV[104],&Lnk104);} /* GET-SETF-METHOD */
+static LnkT103(){ call_or_link(VV[103],&Lnk103);} /* LAST */
+static LnkT102(){ call_or_link(VV[102],&Lnk102);} /* MACRO-FUNCTION */
+static object  LnkTLI101(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[101],&LnkLI101,4,ap);} /* SETF-STRUCTURE-ACCESS */
+static LnkT100(){ call_or_link(VV[100],&Lnk100);} /* MACROEXPAND */
+static LnkT99(){ call_or_link(VV[99],&Lnk99);} /* GET-SETF-METHOD-MULTIPLE-VALUE */
+static LnkT98(){ call_or_link(VV[98],&Lnk98);} /* GENSYM */
+static LnkT97(){ call_or_link(VV[97],&Lnk97);} /* GET-&ENVIRONMENT */
+static object  LnkTLI96(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[96],&LnkLI96,1,ap);} /* FIND-DOCUMENTATION */
+static LnkT95(){ call_or_link(VV[95],&Lnk95);} /* LIST-LENGTH */
+static LnkT94(){ call_or_link(VV[94],&Lnk94);} /* ERROR */
+static LnkT93(){ call_or_link(VV[93],&Lnk93);} /* FUNCTIONP */
