@@ -44,6 +44,7 @@ init_system()
   init_or_load(init_cmputil,"../cmpnew/cmputil.o");
 
   init_or_load(init_debug,"../lsp/debug.o");
+  init_or_load(init_info,"../lsp/info.o");
 
   init_or_load(init_cmptype,"../cmpnew/cmptype.o");
   init_or_load(init_cmpbind,"../cmpnew/cmpbind.o");
@@ -68,7 +69,7 @@ init_system()
   init_or_load(init_cmpvs,"../cmpnew/cmpvs.o");
   init_or_load(init_cmpwt,"../cmpnew/cmpwt.o");
 	     
-  Vpackage->s.s_dbind = user_package;
+  sLApackageA->s.s_dbind = user_package;
     user_init();
   
 }
